@@ -102,21 +102,16 @@ SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
     actUnsetAutostart=NULL;
 }
 
+QWidget* SKGBookmarkPluginDockWidget::mainWidget() const
+{
+    return ui.kBookmarksList;
+}
+
 void SKGBookmarkPluginDockWidget::showMenu(const QPoint& pos)
 {
     if (mainMenu) mainMenu->popup(ui.kBookmarksList->mapToGlobal(pos));
 }
 
-int SKGBookmarkPluginDockWidget::getNbSelectedObjects()
-{
-    return ui.kBookmarksList->getNbSelectedObjects();
-}
-
-SKGObjectBase::SKGListSKGObjectBase SKGBookmarkPluginDockWidget::getSelectedObjects()
-{
-    return ui.kBookmarksList->getSelectedObjects();
-}
-
 void SKGBookmarkPluginDockWidget::onSetAutostart()
 {
     SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::onSetAutoStart");
