@@ -32,15 +32,20 @@
 
 #include <QDomDocument>
 #include <QSpacerItem>
+#include <QMouseEvent>
+
+#include <math.h>
 
 SKGDashboardPluginWidget::SKGDashboardPluginWidget ( SKGDocument* iDocument )
-        : SKGTabPage ( iDocument ), gridLayout ( NULL ), hSpacer ( NULL ), vSpacer ( NULL ), menu ( NULL ), addMenu ( NULL ), removeMenu ( NULL ),
-        col ( 0 ), row ( 0 ), nbMaxCol ( 3 )
+        : SKGTabPage ( iDocument ), flowLayout ( NULL ), menu ( NULL ), addMenu ( NULL ), removeMenu ( NULL )
 {
     SKGTRACEIN ( 1, "SKGDashboardPluginWidget::SKGDashboardPluginWidget" );
 
     ui.setupUi ( this );
 
+    //Drag and drop
+    clickedPoint=QPoint(-1, -1);
+
     const KAboutData* about=KCmdLineArgs::aboutData();
     if (about)
     {
@@ -70,10 +75,13 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget ( SKGDocument* iDocument )
                 {
                     //Create menu
                     QAction* act = addMenu->addAction ( plugin->getDashboardWidgetTitle ( j ) );
-                    act->setIcon ( KIcon ( plugin->icon() ) );
-                    act->setData ( plugin->objectName() +'-'+SKGServices::intToString ( j ) );
+                    if (act)
+                    {
+                        act->setIcon ( KIcon ( plugin->icon() ) );
+                        act->setData ( plugin->objectName() +'-'+SKGServices::intToString ( j ) );
 
-                    connect ( act, SIGNAL ( triggered ( bool ) ), this, SLOT ( onAddWidget() ) );
+                        connect ( act, SIGNAL ( triggered ( bool ) ), this, SLOT ( onAddWidget() ) );
+                    }
                 }
             }
             else index=-2;
@@ -84,17 +92,8 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget ( SKGDocument* iDocument )
     removeMenu=menu->addMenu ( KIcon ( "list-remove" ),  i18nc ( "Verb", "Remove" ) );
     previousMenu=menu->addMenu ( KIcon ( "arrow-left" ),  i18nc ( "Verb", "Move before" ) );
     nextMenu=menu->addMenu ( KIcon ( "arrow-right" ),  i18nc ( "Verb", "Move after" ) );
-    QMenu* colMenu=menu->addMenu ( KIcon ( "view-split-left-right" ), i18nc ( "Verb", "Number of columns" ) );
-    for ( int i=1; i<=5; ++i )
-    {
-        //Create menu
-        QAction* act = colMenu->addAction ( SKGServices::intToString ( i ) );
-        if ( act )
-        {
-            act->setData ( i );
-            connect ( act, SIGNAL ( triggered ( bool ) ), this, SLOT ( onColumnNbChanged() ) );
-        }
-    }
+    zoomInMenu=menu->addMenu ( KIcon ( "zoom-in" ),  i18nc ( "Verb", "Zoom in" ) );
+    zoomOutMenu=menu->addMenu ( KIcon ( "zoom-out" ),  i18nc ( "Verb", "Zoom out" ) );
 
     //Plug buttons with menus
     ui.kAddWidget->setIcon ( addMenu->icon() );
@@ -113,12 +112,17 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget ( SKGDocument* iDocument )
     ui.kNextWidget->setMenu ( nextMenu );
     ui.kNextWidget->setPopupMode ( QToolButton::InstantPopup );
 
-    ui.kNbColumns->setIcon ( colMenu->icon() );
-    ui.kNbColumns->setMenu ( colMenu );
-    ui.kNbColumns->setPopupMode ( QToolButton::InstantPopup );
+    ui.kZoomInWidget->setIcon ( zoomInMenu->icon() );
+    ui.kZoomInWidget->setMenu ( zoomInMenu );
+    ui.kZoomInWidget->setPopupMode ( QToolButton::InstantPopup );
+
+    ui.kZoomOutWidget->setIcon ( zoomOutMenu->icon() );
+    ui.kZoomOutWidget->setMenu ( zoomOutMenu );
+    ui.kZoomOutWidget->setPopupMode ( QToolButton::InstantPopup );
 
     //Build layout
-    gridLayout = new QGridLayout ( ui.kContent );
+    flowLayout = new SKGFlowLayout ( ui.kContent );
+    flowLayout->setSpacing(0);
 }
 
 SKGDashboardPluginWidget::~SKGDashboardPluginWidget()
@@ -129,9 +133,9 @@ SKGDashboardPluginWidget::~SKGDashboardPluginWidget()
     removeMenu=NULL;
     nextMenu=NULL;
     previousMenu=NULL;
-    gridLayout=NULL;
-    hSpacer=NULL;
-    vSpacer=NULL;
+    flowLayout=NULL;
+    zoomInMenu=NULL;
+    zoomOutMenu=NULL;
 }
 
 QString SKGDashboardPluginWidget::getState()
@@ -141,7 +145,6 @@ QString SKGDashboardPluginWidget::getState()
     QDomElement root = doc.createElement ( "parameters" );
     doc.appendChild ( root );
 
-    root.setAttribute ( "nbMaxCol", SKGServices::intToString ( nbMaxCol ) );
     root.setAttribute ( "zoomPosition", SKGServices::intToString(zoomPosition()) );
 
     int nb=items.count();
@@ -157,6 +160,7 @@ QString SKGDashboardPluginWidget::getState()
             element.setAttribute ( "name", param.at ( 0 ) );
             element.setAttribute ( "index", param.at ( 1 ) );
             element.setAttribute ( "state", item->getState() );
+            element.setAttribute ( "zoom", SKGServices::intToString(itemsSizes.at(i)) );
         }
     }
 
@@ -169,35 +173,26 @@ void SKGDashboardPluginWidget::setState ( const QString& iState )
 
     //Initialisation
     int nb=items.count();
-    for ( int i=0; gridLayout && i<nb; ++i )
+    for ( int i=0; flowLayout && i<nb; ++i )
     {
         SKGWidget* item=itemsPointers.at ( i );
         if ( item )
         {
-            gridLayout->removeWidget ( item );
+            flowLayout->removeWidget ( item );
             item->hide();
             delete item;
         }
     }
-    if ( hSpacer )
-    {
-        gridLayout->removeItem ( hSpacer );
-        delete hSpacer;
-        hSpacer=NULL;
-    }
-    if ( vSpacer )
-    {
-        gridLayout->removeItem ( vSpacer );
-        delete vSpacer;
-        vSpacer=NULL;
-    }
+
     removeMenu->clear ();
     nextMenu->clear();
     previousMenu->clear();
+    zoomInMenu->clear();
+    zoomOutMenu->clear();
+
     items.clear();
     itemsPointers.clear();
-    row=0;
-    col=0;
+    itemsSizes.clear();
 
     if ( iState.isEmpty() )
     {
@@ -223,9 +218,6 @@ void SKGDashboardPluginWidget::setState ( const QString& iState )
         doc.setContent ( iState );
         QDomElement root = doc.documentElement();
 
-        QString nbMaxColS=root.attribute ( "nbMaxCol" );
-        if ( !nbMaxColS.isEmpty() ) nbMaxCol=SKGServices::stringToInt ( nbMaxColS );
-
         QString zoomPositionS=root.attribute ( "zoomPosition" );
         if ( !zoomPositionS.isEmpty() ) setZoomPosition(SKGServices::stringToInt ( zoomPositionS ));
 
@@ -238,24 +230,14 @@ void SKGDashboardPluginWidget::setState ( const QString& iState )
                 SKGInterfacePlugin* plugin=SKGMainPanel::getMainPanel()->getPluginByName ( element.attribute ( "name" ) );
                 QString index=element.attribute ( "index" );
                 if ( index.isEmpty() ) index='0';
-                if ( plugin ) addItem ( plugin, SKGServices::stringToInt ( index ), element.attribute ( "state" ) );
+                QString zoom=element.attribute ( "zoom" );
+                if ( zoom.isEmpty() ) zoom='0';
+                if ( plugin ) addItem ( plugin, SKGServices::stringToInt ( index ), SKGServices::stringToInt ( zoom ), element.attribute ( "state" ) );
             }
             else index=-1;
             ++index;
         }
     }
-
-
-    //Add horizontal spacer
-    if ( items.count() <nbMaxCol )
-    {
-        hSpacer=new QSpacerItem ( 0, 0, QSizePolicy::Expanding );
-        gridLayout->addItem ( hSpacer, row, col, QSizePolicy::Expanding );
-    }
-
-    //Add vertical spacer
-    vSpacer=new QSpacerItem ( 0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding );
-    gridLayout->addItem ( vSpacer, row+1, 0, QSizePolicy::Minimum, QSizePolicy::Expanding );
 }
 
 QString SKGDashboardPluginWidget::getDefaultStateAttribute()
@@ -263,20 +245,129 @@ QString SKGDashboardPluginWidget::getDefaultStateAttribute()
     return "SKGDASHBOARD_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGDashboardPluginWidget::getWidgetForPrint()
-{
-    return this;
-}
-
 void SKGDashboardPluginWidget::refresh()
 {
     SKGTRACEIN ( 1, "SKGDashboardPluginWidget::refresh" );
 
 }
 
-QWidget* SKGDashboardPluginWidget::zoomableWidget() const
+bool SKGDashboardPluginWidget::eventFilter ( QObject* object, QEvent* event )
 {
-    return (QWidget*) this;
+    if ( event && object &&
+            (event->type() == QEvent::MouseButtonPress ||
+             event->type() == QEvent::DragEnter ||
+             event->type() == QEvent::DragMove ||
+             event->type() == QEvent::Drop ||
+             event->type() == QEvent::MouseMove ))
+    {
+        //Search SKGWidget corresponding to this widget
+        SKGWidget* toMove=NULL;
+        int toMoveIndex=-1;
+        int nb=itemsPointers.count();
+        for ( int i=0; toMove==NULL && i<nb; ++i )
+        {
+            SKGWidget* w=itemsPointers.at(i);
+            if (w && w->getDragWidget()==object)
+            {
+                toMove=w;
+                toMoveIndex=i;
+            }
+        }
+
+        if ( event->type() == QEvent::MouseButtonPress )
+        {
+            //Drag
+            QMouseEvent *mevent = ( QMouseEvent * ) event;
+            if ( mevent->button() == Qt::LeftButton )
+            {
+                clickedPoint=mevent->pos();
+
+                return true;
+            }
+        }
+        else if ( event->type() == QEvent::MouseMove )
+        {
+            //Drag
+            if (clickedPoint!=QPoint(-1, -1) && toMoveIndex!=-1)
+            {
+                QMouseEvent *mevent = ( QMouseEvent * ) event;
+                int distance = ( mevent->pos( ) - clickedPoint ).manhattanLength( );
+                if ( distance >= QApplication::startDragDistance( ))
+                {
+                    QMimeData *mimeData = new QMimeData;
+                    mimeData->setData("application/x-skgdashboardpluginwidget", SKGServices::intToString(toMoveIndex).toLatin1());
+
+                    QDrag *drag = new QDrag(this);
+                    drag->setMimeData(mimeData);
+                    drag->exec(); // krazy:exclude=crashy
+
+                    return true;
+                }
+            }
+        }
+        else if ( event->type() == QEvent::DragEnter )
+        {
+            //Drop move
+            QDragEnterEvent *devent = ( QDragEnterEvent * ) event;
+            if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
+                devent->accept();
+
+                return true;
+            }
+        }
+
+        else if ( event->type() == QEvent::DragMove )
+        {
+            //Drop move
+            QDragMoveEvent *devent = ( QDragMoveEvent * ) event;
+            if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
+                int oldPos=SKGServices::stringToInt(devent->mimeData()->data("application/x-skgdashboardpluginwidget"));
+                if (oldPos!=toMoveIndex) devent->accept();
+                else devent->ignore();
+
+                return true;
+            }
+        }
+
+        else if ( event->type() == QEvent::Drop )
+        {
+            //Drop
+            QDropEvent *devent = ( QDropEvent * ) event;
+            if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
+                int oldPos=SKGServices::stringToInt(devent->mimeData()->data("application/x-skgdashboardpluginwidget"));
+
+                if (oldPos+1==toMoveIndex) ++toMoveIndex;
+
+                //Get item
+                QString id=items.at ( oldPos );
+                SKGWidget* wgt=itemsPointers.at ( oldPos );
+                int s=itemsSizes.at(oldPos);
+
+                //Remove item
+                items.removeAt ( oldPos );
+                itemsPointers.removeAt ( oldPos );
+                itemsSizes.removeAt ( oldPos );
+                if (toMoveIndex>oldPos) --toMoveIndex;
+
+                //Add it after
+                items.insert ( toMoveIndex, id );
+                itemsPointers.insert ( toMoveIndex, wgt );
+                itemsSizes.insert ( toMoveIndex, s );
+
+                //Get new state
+                QString state=getState();
+
+                //Reset state
+                setState ( state );
+
+                clickedPoint=QPoint(-1, -1);
+
+                return true;
+            }
+        }
+    }
+
+    return false;
 }
 
 void SKGDashboardPluginWidget::showHeaderMenu ( const QPoint& pos )
@@ -302,6 +393,7 @@ void SKGDashboardPluginWidget::onAddWidget()
                 //Add
                 items.push_back ( id );
                 itemsPointers.push_back ( dbw );
+                itemsSizes.push_back(0);
 
                 //Get new state
                 QString state=getState();
@@ -309,6 +401,7 @@ void SKGDashboardPluginWidget::onAddWidget()
                 //Remove added item
                 items.pop_back();
                 itemsPointers.pop_back();
+                itemsSizes.pop_back();
 
                 //Reset state
                 setState ( state );
@@ -317,17 +410,6 @@ void SKGDashboardPluginWidget::onAddWidget()
     }
 }
 
-void SKGDashboardPluginWidget::onColumnNbChanged()
-{
-    QAction* sender=dynamic_cast<QAction*> ( this->sender() );
-    if ( sender )
-    {
-        nbMaxCol=sender->data().toInt();
-
-        setState ( getState() );
-    }
-}
-
 void SKGDashboardPluginWidget::onMoveAfterWidget()
 {
     QAction* sender=dynamic_cast<QAction*> ( this->sender() );
@@ -339,14 +421,17 @@ void SKGDashboardPluginWidget::onMoveAfterWidget()
             //Get item
             QString id=items.at ( pos );
             SKGWidget* wgt=itemsPointers.at ( pos );
+            int s=itemsSizes.at(pos);
 
             //Remove item
             items.removeAt ( pos );
             itemsPointers.removeAt ( pos );
+            itemsSizes.removeAt ( pos );
 
             //Add it after
             items.insert ( pos+1, id );
             itemsPointers.insert ( pos+1, wgt );
+            itemsSizes.insert ( pos+1, s );
 
             //Get new state
             QString state=getState();
@@ -368,14 +453,17 @@ void SKGDashboardPluginWidget::onMoveBeforeWidget()
             //Get item
             QString id=items.at ( pos );
             SKGWidget* wgt=itemsPointers.at ( pos );
+            int s=itemsSizes.at(pos);
 
             //Remove item
             items.removeAt ( pos );
             itemsPointers.removeAt ( pos );
+            itemsSizes.removeAt ( pos );
 
             //Add it after
             items.insert ( pos-1, id );
             itemsPointers.insert ( pos-1, wgt );
+            itemsSizes.insert ( pos-1, s );
 
             //Get new state
             QString state=getState();
@@ -397,10 +485,12 @@ void SKGDashboardPluginWidget::onRemoveWidget()
             //Get item
             QString id=items.at ( pos );
             SKGWidget* wgt=itemsPointers.at ( pos );
+            int s=itemsSizes.at(pos);
 
             //Remove item
             items.removeAt ( pos );
             itemsPointers.removeAt ( pos );
+            itemsSizes.removeAt ( pos );
 
             //Get new state
             QString state=getState();
@@ -408,6 +498,7 @@ void SKGDashboardPluginWidget::onRemoveWidget()
             //We add removed object to be sure that it will be removed
             items.push_back ( id );
             itemsPointers.push_back ( wgt );
+            itemsSizes.push_back ( s );
 
             //Reset state
             setState ( state );
@@ -415,37 +506,83 @@ void SKGDashboardPluginWidget::onRemoveWidget()
     }
 }
 
-void SKGDashboardPluginWidget::addItem ( SKGInterfacePlugin* iDashboard, int iIndex, const QString& iState )
+void SKGDashboardPluginWidget::onZoomInWidget()
 {
-    if ( iDashboard )
+    QAction* sender=dynamic_cast<QAction*> ( this->sender() );
+    if ( sender )
+    {
+        int pos=sender->data().toInt();
+        if ( pos>=0 )
+        {
+            //Get item
+            int s=itemsSizes.at(pos);
+
+            //Remove item
+            itemsSizes.removeAt ( pos );
+
+            //Add it after
+            itemsSizes.insert ( pos, s+1 );
+
+            //Get new state
+            QString state=getState();
+
+            //Reset state
+            setState ( state );
+        }
+    }
+}
+
+void SKGDashboardPluginWidget::onZoomOutWidget()
+{
+    QAction* sender=dynamic_cast<QAction*> ( this->sender() );
+    if ( sender )
+    {
+        int pos=sender->data().toInt();
+        if ( pos>=0 )
+        {
+            //Get item
+            int s=itemsSizes.at(pos);
+
+            //Remove item
+            itemsSizes.removeAt ( pos );
+
+            //Add it after
+            itemsSizes.insert ( pos, qMax(s-1, 0) );
+
+            //Get new state
+            QString state=getState();
+
+            //Reset state
+            setState ( state );
+        }
+    }
+}
+
+void SKGDashboardPluginWidget::addItem ( SKGInterfacePlugin* iDashboard, int iIndex, int iZoom, const QString& iState )
+{
+    if ( iDashboard && flowLayout)
     {
         SKGWidget* dbw=iDashboard->getDashboardWidget ( iIndex );
         if ( dbw )
         {
-            //Remove Spacer
-            if ( hSpacer )
-            {
-                delete hSpacer;
-                hSpacer=NULL;
-            }
-            if ( vSpacer )
-            {
-                delete vSpacer;
-                vSpacer=NULL;
-            }
-
             //Add widget
             dbw->setParent ( ui.kContent );
             dbw->setState ( iState );
-            gridLayout->addWidget ( dbw, row, col );
+            flowLayout->addWidget ( dbw);
 
-            ++col;
-            if ( col==nbMaxCol )
+            //Install filter
+            QWidget* drag=dbw->getDragWidget();
+            if (drag)
             {
-                ++row;
-                col=0;
+                drag->installEventFilter(this);
+                drag->setAcceptDrops(true);
             }
 
+            //Set size
+            QSize size=dbw->minimumSize();
+            QSize newSize(size.width()*pow(10,((qreal) iZoom+1)/10.0), size.height()*pow(10,((qreal) iZoom+1)/10.0));
+            dbw->setMinimumSize(newSize);
+
             //Add remove item in menu
             QString id=iDashboard->objectName() +'-'+SKGServices::intToString ( iIndex );
             {
@@ -480,8 +617,33 @@ void SKGDashboardPluginWidget::addItem ( SKGInterfacePlugin* iDashboard, int iIn
                 }
             }
 
+            //Add remove item in menu
+            if (size.height() && size.width())
+            {
+                QAction* act=zoomInMenu->addAction ( iDashboard->getDashboardWidgetTitle ( iIndex ) );
+                if ( act )
+                {
+                    act->setIcon ( KIcon ( iDashboard->icon() ) );
+                    act->setData ( items.count() );
+                    connect ( act, SIGNAL ( triggered ( bool ) ), this, SLOT ( onZoomInWidget() ) );
+                }
+            }
+
+            //Add remove item in menu
+            if (size.height() && size.width())
+            {
+                QAction* act=zoomOutMenu->addAction ( iDashboard->getDashboardWidgetTitle ( iIndex ) );
+                if ( act )
+                {
+                    act->setIcon ( KIcon ( iDashboard->icon() ) );
+                    act->setData ( items.count() );
+                    connect ( act, SIGNAL ( triggered ( bool ) ), this, SLOT ( onZoomOutWidget() ) );
+                }
+            }
+
             items.push_back ( id );
             itemsPointers.push_back ( dbw );
+            itemsSizes.push_back(iZoom);
         }
     }
 }
