@@ -26,7 +26,6 @@
 #include "skgerror.h"
 #include "skgmainpanel.h"
 #include "skgtransactionmng.h"
-#include "skgtipofdayboardwidget.h"
 
 #include <kactioncollection.h>
 #include <kstandardaction.h>
@@ -39,6 +38,7 @@
 #include <kaboutdata.h>
 #include <knewpassworddialog.h>
 #include <kpassworddialog.h>
+#include <kwallet.h>
 
 #include <QtGui/QWidget>
 #include <QFile>
@@ -65,7 +65,7 @@ SKGFilePlugin::~SKGFilePlugin()
     SKGTRACEIN ( 10, "SKGFilePlugin::~SKGFilePlugin" );
     if ( recentFiles ) recentFiles->saveEntries ( KConfigGroup ( KGlobal::config(), "RecentFiles" ) );
 
-    currentBankDocument=NULL;
+    currentDocument=NULL;
     recentFiles=NULL;
     saveAction=NULL;
     saveAsAction=NULL;
@@ -76,8 +76,8 @@ bool SKGFilePlugin::setupActions ( SKGDocument* iDocument, const QStringList& iA
 {
     SKGTRACEIN ( 10, "SKGFilePlugin::setupActions" );
 
-    currentBankDocument=iDocument;
-    if (currentBankDocument==NULL) return false;
+    currentDocument=iDocument;
+    if (currentDocument==NULL) return false;
 
     setComponentData ( SKGFilePluginFactory::componentData() );
     setXMLFile ( "skg_file.rc" );
@@ -116,7 +116,7 @@ bool SKGFilePlugin::setupActions ( SKGDocument* iDocument, const QStringList& iA
         openMode=2;
         QString filename=iArgument.at ( nbArg-1 );
         QString extension=QFileInfo ( filename ).suffix().toUpper();
-        QString extensionDocument=currentBankDocument->getFileExtension().toUpper();
+        QString extensionDocument=currentDocument->getFileExtension().toUpper();
         if ( QFile ( filename ).exists() && extension==extensionDocument )
         {
             processArguments ( iArgument );
@@ -139,7 +139,7 @@ bool SKGFilePlugin::setupActions ( SKGDocument* iDocument, const QStringList& iA
                     KSplashScreen* splashScreen=SKGMainPanel::getMainPanel()->splashScreen();
                     if ( splashScreen ) splashScreen->showMessage ( i18nc("Splash screen message",  "Opening file %1...", lastOpenedFile ), Qt::AlignLeft, QColor ( 221, 130, 8 ) ); // krazy:exclude=qmethods
                 }
-                emit loadFile ( lastOpenedFile );
+                Q_EMIT loadFile ( lastOpenedFile );
             }
             else openMode=2;
         }
@@ -160,11 +160,11 @@ void SKGFilePlugin::processArguments ( const QStringList& iArgument )
 {
     SKGTRACEIN ( 10, "SKGFilePlugin::processArguments" );
     int nbArg=iArgument.count();
-    if ( nbArg && currentBankDocument )
+    if ( nbArg && currentDocument )
     {
         QString filename=iArgument.at ( nbArg-1 );
         QString extension=QFileInfo ( filename ).suffix().toUpper();
-        QString extensionDocument=currentBankDocument->getFileExtension().toUpper();
+        QString extensionDocument=currentDocument->getFileExtension().toUpper();
         if ( QFile ( filename ).exists() && extension==extensionDocument )
         {
             if ( SKGMainPanel::getMainPanel() )
@@ -172,30 +172,11 @@ void SKGFilePlugin::processArguments ( const QStringList& iArgument )
                 KSplashScreen* splashScreen=SKGMainPanel::getMainPanel()->splashScreen();
                 if ( splashScreen ) splashScreen->showMessage ( i18nc("Splash screen message", "Opening file %1...", filename ), Qt::AlignLeft, QColor ( 221, 130, 8 ) ); // krazy:exclude=qmethods
             }
-            emit loadFile ( filename );
+            Q_EMIT loadFile ( filename );
         }
     }
 }
 
-int SKGFilePlugin::getNbDashboardWidgets()
-{
-    SKGTRACEIN ( 1, "SKGFilePlugin::getNbDashboardWidgets" );
-    return 1;
-}
-
-QString SKGFilePlugin::getDashboardWidgetTitle ( int iIndex )
-{
-    SKGTRACEIN ( 1, "SKGFilePlugin::getDashboardWidgetTitle" );
-    if ( iIndex==0 ) return i18nc ( "Noun, a list of items","Tip of the day" );
-    return "";
-}
-
-SKGWidget* SKGFilePlugin::getDashboardWidget ( int iIndex )
-{
-    if ( iIndex==0 ) return new SKGTipOfDayBoardWidget ( currentBankDocument );
-    return NULL;
-}
-
 QWidget* SKGFilePlugin::getPreferenceWidget()
 {
     SKGTRACEIN ( 10, "SKGFilePlugin::getPreferenceWidget" );
@@ -222,7 +203,7 @@ KConfigSkeleton* SKGFilePlugin::getPreferenceSkeleton()
 SKGError SKGFilePlugin::savePreferences() const
 {
     SKGError err;
-    if ( currentBankDocument )
+    if ( currentDocument )
     {
         //Read Setting
         QString prefix;
@@ -234,7 +215,7 @@ SKGError SKGFilePlugin::savePreferences() const
         }
 
         //Save setting in document
-        currentBankDocument->setBackupParameters ( prefix, suffix );
+        currentDocument->setBackupParameters ( prefix, suffix );
 
         //Set save on close mode
         SKGMainPanel::getMainPanel()->setSaveOnClose ( skgfile_settings::saveonclose() );
@@ -247,10 +228,10 @@ void SKGFilePlugin::refresh()
     SKGTRACEIN ( 10, "SKGFilePlugin::refresh" );
 
     //Refresh action status
-    if ( currentBankDocument )
+    if ( currentDocument )
     {
-        bool test= ( currentBankDocument->getDatabase() !=NULL );
-        if ( saveAction ) saveAction->setEnabled ( currentBankDocument->isFileModified() );
+        bool test= ( currentDocument->getDatabase() !=NULL );
+        if ( saveAction ) saveAction->setEnabled ( currentDocument->isFileModified() );
         if ( saveAsAction ) saveAsAction->setEnabled ( test );
         if ( passwordAction ) passwordAction->setEnabled ( test );
     }
@@ -294,16 +275,16 @@ void SKGFilePlugin::actionNew()
 {
     SKGError err;
     SKGTRACEINRC ( 10, "SKGFilePlugin::actionNew",err );
-    if ( SKGMainPanel::getMainPanel() && currentBankDocument && SKGMainPanel::getMainPanel()->queryFileClose() )
+    if ( SKGMainPanel::getMainPanel() && currentDocument && SKGMainPanel::getMainPanel()->queryFileClose() )
     {
         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
 
         SKGMainPanel::getMainPanel()->closeAllPages();
 
-        err=currentBankDocument->initialize();
+        err=currentDocument->initialize();
 
         KLocale* locale=KGlobal::locale();
-        if ( err.isSucceeded() ) err=currentBankDocument->setLanguage ( locale->language() );
+        if ( err.isSucceeded() ) err=currentDocument->setLanguage ( locale->language() );
         QApplication::restoreOverrideCursor();
 
         //status bar
@@ -319,13 +300,13 @@ void SKGFilePlugin::actionSave()
 {
     SKGError err;
     SKGTRACEINRC ( 10, "SKGFilePlugin::actionSave",err );
-    if ( currentBankDocument && SKGMainPanel::getMainPanel() )
+    if ( currentDocument && SKGMainPanel::getMainPanel() )
     {
-        if ( currentBankDocument->getCurrentFileName().length() ==0 ) actionSaveAs();
+        if ( currentDocument->getCurrentFileName().length() ==0 ) actionSaveAs();
         else
         {
             QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
-            err=currentBankDocument->save();
+            err=currentDocument->save();
             QApplication::restoreOverrideCursor();
 
             //Refresh
@@ -345,15 +326,15 @@ void SKGFilePlugin::actionSaveAs()
 {
     SKGError err;
     SKGTRACEINRC ( 10, "SKGFilePlugin::actionSaveAs",err );
-    if ( currentBankDocument && SKGMainPanel::getMainPanel() )
+    if ( currentDocument && SKGMainPanel::getMainPanel() )
     {
-        QString fileName=SKGMainPanel::getSaveFileName ( KUrl ( "kfiledialog:///"+currentBankDocument->objectName() ),
-                         "*."+currentBankDocument->getFileExtension()+'|'+i18nc ( "File format", "%1 document", KCmdLineArgs::aboutData()->programName() ) ,
+        QString fileName=SKGMainPanel::getSaveFileName ( KUrl ( "kfiledialog:///"+currentDocument->objectName() ),
+                         "*."+currentDocument->getFileExtension()+'|'+i18nc ( "File format", "%1 document", KCmdLineArgs::aboutData()->programName() ) ,
                          SKGMainPanel::getMainPanel() );
         if ( fileName.isEmpty() ) return;
 
         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
-        err=currentBankDocument->saveAs ( fileName, true );
+        err=currentDocument->saveAs ( fileName, true );
         QApplication::restoreOverrideCursor();
 
         //Refresh
@@ -386,12 +367,14 @@ void SKGFilePlugin::actionOpen ( const KUrl & iUrl )
 {
     SKGError err;
     SKGTRACEINRC ( 10, "SKGFilePlugin::actionOpen",err );
-    if ( SKGMainPanel::getMainPanel() && currentBankDocument && SKGMainPanel::getMainPanel()->queryFileClose() )
+    if ( SKGMainPanel::getMainPanel() && currentDocument && SKGMainPanel::getMainPanel()->queryFileClose() )
     {
-
+        bool useKWallet=skgfile_settings::storeInKdeWallet();
+        QString pwd;
+        QString programName=KCmdLineArgs::aboutData()->programName();
         QString fileName=iUrl.pathOrUrl();
-        if ( !fileName.length() ) fileName=KFileDialog::getOpenUrl ( KUrl ( "kfiledialog:///"+currentBankDocument->objectName() ),
-                                               "*."+currentBankDocument->getFileExtension()+'|'+i18nc ( "File format", "%1 document", KCmdLineArgs::aboutData()->programName() ) ,
+        if ( !fileName.length() ) fileName=KFileDialog::getOpenUrl ( KUrl ( "kfiledialog:///"+currentDocument->objectName() ),
+                                               "*."+currentDocument->getFileExtension()+'|'+i18nc ( "File format", "%1 document", programName ) ,
                                                SKGMainPanel::getMainPanel() ).pathOrUrl();
         if ( fileName.length() )
         {
@@ -411,38 +394,68 @@ void SKGFilePlugin::actionOpen ( const KUrl & iUrl )
             //Open
             QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
             SKGMainPanel::getMainPanel()->closeAllPages();
-            err=currentBankDocument->load ( fileName, "", restoreTmpFile );
+            err=currentDocument->load ( fileName, "", restoreTmpFile );
             QApplication::restoreOverrideCursor();
 
             if ( err.isFailed() && err.getReturnCode()!=ERR_WRITEACCESS )
             {
-                currentBankDocument->close();
+                currentDocument->close();
 
                 //Open failed
                 //Password must be asked
-                QString additionnalMessage;
+                QString additionalMessage;
                 do
                 {
+                    //Reset error
                     err=SKGError ( 0, "" );
-                    QPointer<KPasswordDialog> dlg=new KPasswordDialog(SKGMainPanel::getMainPanel());
-                    dlg->setPrompt(additionnalMessage+i18nc("Question", "This file seems to be protected.\nPlease enter the password." ));
-                    if ( dlg->exec() ==QDialog::Accepted )
+                    pwd="";
+
+                    //Get password
+                    if (useKWallet)
+                    {
+                        //Use KWallet
+                        KWallet::Wallet* w=KWallet::Wallet::openWallet("kdewallet", SKGMainPanel::getMainPanel()->winId());
+                        if (w)
+                        {
+                            //Change folder
+                            if (!w->hasFolder(programName)) w->createFolder(programName);
+                            w->setFolder(programName);
+
+                            //Read password
+                            w->readPassword(fileName, pwd);
+                            if (pwd.isEmpty()) useKWallet=false;
+
+                            delete w;
+                            w=NULL;
+                        }
+                    }
+
+                    if (!useKWallet)
+                    {
+                        //Use password dialog
+                        QPointer<KPasswordDialog> dlg=new KPasswordDialog(SKGMainPanel::getMainPanel());
+                        dlg->setPrompt(additionalMessage+i18nc("Question", "This file seems to be protected.\nPlease enter the password." ));
+                        if ( dlg->exec() ==QDialog::Accepted ) pwd=dlg->password();
+                        delete dlg;
+                    }
+
+                    //Load file
+                    if (!pwd.isEmpty())
                     {
                         KSplashScreen* splashScreen=SKGMainPanel::getMainPanel()->splashScreen();
                         if ( splashScreen ) splashScreen->hide();
 
                         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
-                        err=currentBankDocument->load ( fileName, dlg->password(), restoreTmpFile );
+                        err=currentDocument->load ( fileName, pwd, restoreTmpFile );
                         if ( err.isFailed() )
                         {
-                            additionnalMessage=i18nc ("Noun", "Wrong password.\n" );
+                            additionalMessage=i18nc ("Noun", "<b>Wrong password.</b>\n" );
+                            useKWallet=false;
                         }
                         QApplication::restoreOverrideCursor();
 
                         if ( splashScreen ) splashScreen->show();
                     }
-
-                    delete dlg;
                 }
                 while ( err.isFailed() );
             }
@@ -461,11 +474,30 @@ void SKGFilePlugin::actionOpen ( const KUrl & iUrl )
                 KSharedConfigPtr config=KSharedConfig::openConfig ();
                 KConfigGroup pref=config->group ( "File" );
                 pref.writePathEntry ( "lastfilepath",fileName );
+
+                //Store password if KDE wallet if needed
+                if (skgfile_settings::storeInKdeWallet() && !useKWallet)
+                {
+                    //Use KWallet
+                    KWallet::Wallet* w=KWallet::Wallet::openWallet("kdewallet", SKGMainPanel::getMainPanel()->winId());
+                    if (w)
+                    {
+                        //Change folder
+                        w->setFolder(programName);
+
+                        //Write password
+                        w->writePassword(fileName, pwd);
+
+                        delete w;
+                        w=NULL;
+                    }
+                }
             }
             else  err.addError ( ERR_FAIL, i18nc("Error message",  "Failed to open '%1'.", fileName ) );
 
             //Display error
             if ( SKGMainPanel::getMainPanel() ) SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
+
         }
     }
 }
@@ -474,16 +506,16 @@ void SKGFilePlugin::actionChangePassword()
 {
     SKGError err;
     SKGTRACEINRC ( 10, "SKGFilePlugin::actionChangePassword",err );
-    if ( currentBankDocument && SKGMainPanel::getMainPanel() )
+    if ( currentDocument && SKGMainPanel::getMainPanel() )
     {
         QPointer<KNewPasswordDialog> dlg=new KNewPasswordDialog( SKGMainPanel::getMainPanel() );
         dlg->setPrompt( i18n( "Take care, if you lose your <b>password</b> then it will be <u><b>impossible</b></u> to open your document." ));
         if ( !dlg->exec() ) err=SKGError(0, i18nc("Successful message after an user action", "Changing password was canceled." ) );
         else
         {
-            SKGBEGINTRANSACTION ( *currentBankDocument, i18nc("Noun, name of the user action", "Change password" ), err );
+            SKGBEGINTRANSACTION ( *currentDocument, i18nc("Noun, name of the user action", "Change password" ), err );
             QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
-            err=currentBankDocument->changePassword ( dlg->password() );
+            err=currentDocument->changePassword ( dlg->password() );
             QApplication::restoreOverrideCursor();
 
             //status
@@ -496,4 +528,20 @@ void SKGFilePlugin::actionChangePassword()
         SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
     }
 }
+
+QList< SKGInterfacePlugin::SKGAdvice > SKGFilePlugin::advices() const
+{
+    QList< SKGInterfacePlugin::SKGAdvice > output;
+
+    //Backup
+    SKGInterfacePlugin::SKGAdvice ad;
+    ad.uuid="skgfileplugin_notvalidated";
+    ad.priority=2;
+    ad.shortMessage=i18nc("Advice on making the best (short)", "Backup your document");
+    ad.longMessage=i18nc("Advice on making the best (long)", "Don't forget to backup your document on an other device.");
+    output.push_back(ad);
+
+    return output;
+}
+
 #include "skgfileplugin.moc"
