@@ -22,19 +22,21 @@
 #include "skgbkwidgetcollectiondesignerplugin.h"
 #include "skgquerycreatordesignerplugin.h"
 #include "skgpredicatcreatordesignerplugin.h"
+#include "skgunitcomboboxdesignerplugin.h"
 
 #include <QtPlugin>
 
 SKGBKWidgetCollectionDesignerPlugin::SKGBKWidgetCollectionDesignerPlugin(QObject *parent)
-                : QObject(parent)
+        : QObject(parent)
 {
-        widgets.append(new SKGQueryCreatorDesignerPlugin(this));
-        widgets.append(new SKGPredicatCreatorDesignerPlugin(this));
+    widgets.append(new SKGQueryCreatorDesignerPlugin(this));
+    widgets.append(new SKGPredicatCreatorDesignerPlugin(this));
+    widgets.append(new SKGUnitComboBoxDesignerPlugin(this));
 }
 
 QList<QDesignerCustomWidgetInterface*> SKGBKWidgetCollectionDesignerPlugin::customWidgets() const
 {
-        return widgets;
+    return widgets;
 }
 
 Q_EXPORT_PLUGIN2(skroogebkui, SKGBKWidgetCollectionDesignerPlugin)
