@@ -87,6 +87,14 @@ void SKGObjectModel::buidCache()
             cacheUnit.Value=1;
             cacheUnit.NbDecimal=parent.getNumberDecimal();
         }
+        else
+        {
+            cacheUnit.Name="";
+            cacheUnit.Symbol="";
+            cacheUnit.Value=1;
+            cacheUnit.NbDecimal=2;
+        }
+        if (cacheUnit.Symbol.isEmpty()) cacheUnit.Symbol=' ';
 
         //Bug 209672 vvvv
         if (unitObject.getType()==SKGUnitObject::INDEX) {
@@ -257,7 +265,7 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                 }
 
                 SKGServices::SKGUnitInfo unit;
-                unit.Symbol=QString(' ');
+                unit.Symbol="";
                 unit.NbDecimal=2;
                 if ( !att.contains("QUANTITY")) {
                     unit= static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
@@ -278,14 +286,16 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                 }
                 //Bug 209672 ^^^
 
-                if (att=="f_rate") {
+                if (QString::compare(att, "f_rate", Qt::CaseInsensitive)==0) {
                     unit.Symbol='%';
                     unit.NbDecimal=2;
                 } else if (att=="f_coef") {
-                    unit.Symbol=' ';
+                    unit.Symbol="";
                     unit.NbDecimal=2;
                 }
 
+                if (unit.Symbol.length()==0) unit.Symbol=' ';
+
                 return KGlobal::locale()->formatMoney ( dval, unit.Symbol, unit.NbDecimal );
             } else {
                 return dval;
@@ -564,7 +574,7 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
         QString toolTipStringBase=SKGObjectModelBase::data(index, role).toString();
         if (!toolTipStringBase.isEmpty())
         {
-            if (!toolTipString.isEmpty()) toolTipString+='\n';
+            if (!toolTipString.isEmpty()) toolTipString+="\n\n";
             toolTipString+=toolTipStringBase;
         }
         return toolTipString;
