@@ -121,7 +121,7 @@ public:
                               int row, int column,
                               const QModelIndex &parent);
 
-protected slots:
+protected Q_SLOTS:
     /**
      * This method is called by refresh to build the cache (to improve performance)
      */
