@@ -39,7 +39,7 @@ SKGQueryCreator::SKGQueryCreator ( QWidget *parent )
     ui.kList->setWordWrap ( false );
     ui.kList->horizontalHeader()->setMovable(true);
 
-    connect ( ui.kList, SIGNAL(removeSelectedItems()),this,SLOT(onRemove()));
+    connect ( ui.kList, SIGNAL(removeSelectedItems()),this,SLOT(onRemoveLine()));
 
 
     addNewLine();
@@ -50,15 +50,15 @@ SKGQueryCreator::~SKGQueryCreator()
     document=NULL;
 }
 
-void SKGQueryCreator::setParameters ( const SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute, bool iModeUpdate )
+void SKGQueryCreator::setParameters ( SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute, bool iModeUpdate )
 {
-    document= ( SKGDocument* ) iDocument;
+    document=iDocument;
     table=iTable;
     updateMode=iModeUpdate;
 
-    QString txt=(updateMode ? i18nc("Description", "Double click on a field name to add it to your modification definition.") : i18nc("Description", "Double click on a field name to add it to your search definition."))+'\n'+i18nc("Description", "Double click on a cell to modify it.");
-    ui.kLabel->setComment ( "<html><body><b>"+SKGServices::stringToHtml ( txt ) +"</b></body></html>" );
-    ui.kLabel->setPixmap ( KIcon ( updateMode ? "view-refresh" :"edit-find" ).pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
+//     QString txt=(updateMode ? i18nc("Description", "Double click on a field name to add it to your modification definition.") : i18nc("Description", "Double click on a field name to add it to your search definition."))+'\n'+i18nc("Description", "Double click on a cell to modify it.");
+//     ui.kLabel->setComment ( "<html><body><b>"+SKGServices::stringToHtml ( txt ) +"</b></body></html>" );
+//     ui.kLabel->setPixmap ( KIcon ( updateMode ? "view-refresh" :"edit-find" ).pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
 
     //Build list of attributes
     if ( document )
@@ -68,6 +68,7 @@ void SKGQueryCreator::setParameters ( const SKGDocument* iDocument, const QStrin
 
         ui.kList->setItemDelegate ( delegate );
 
+        //Keep only existing attribute
         SKGServices::SKGAttributesList listAtts;
         SKGServices::SKGAttributesList attributes;
         SKGServices::getAttributesDescription ( document, table, attributes );
@@ -76,6 +77,22 @@ void SKGQueryCreator::setParameters ( const SKGDocument* iDocument, const QStrin
             if ( iListAttribute.count() ==0 || iListAttribute.contains ( att.name ) ) listAtts.push_back ( att );
         }
 
+        //Adding properties
+        int nb=iListAttribute.count();
+        for (int i=0; i<nb; ++i)
+        {
+            QString att=iListAttribute.at(i);
+            if (att.startsWith(QLatin1String("p_")))
+            {
+                SKGServices::SKGAttributeInfo info;
+                info.name=att;
+                info.display=att.right(att.length()-2);
+                info.type=SKGServices::TEXT;
+                info.icon=iDocument->getIcon(att);
+                listAtts.push_back ( info );
+            }
+        }
+
         ui.kList->setRowCount ( 0 );
 
         int nbCol=listAtts.count();
@@ -86,7 +103,8 @@ void SKGQueryCreator::setParameters ( const SKGDocument* iDocument, const QStrin
             listItem->setData ( Qt::UserRole, listAtts.at ( i ).name );
         }
         ui.kListAtt->setModelColumn ( nbCol );
-        connect ( ui.kList->verticalHeader(),SIGNAL(sectionClicked(int)),this,SLOT(onRemove(int)));
+        connect ( ui.kList->verticalHeader(),SIGNAL(sectionClicked(int)),this,SLOT(onRemoveLine(int)));
+        connect ( ui.kList->horizontalHeader(),SIGNAL(sectionClicked(int)),this,SLOT(onRemoveColumn(int)));
 
         addNewLine();
     }
@@ -102,41 +120,41 @@ int SKGQueryCreator::getIndexQueryColumn ( const QString& iAttribute , int row)
         QTableWidgetItem* it_h=ui.kList->horizontalHeaderItem ( i );
         if ( it_h && iAttribute==it_h->data ( Qt::UserRole ).toString() )
         {
-	    if(row>=0)
-	    {
-	      //Check if the cell is empty
-	      QTableWidgetItem* it=ui.kList->item ( row, i );
-	      if ( it )
-	      {
-		if(it->text().isEmpty())
-		{
-		  output=i;
-		  break;
-		}
-	      }
-	    }
-	    else
-	    {
-	      output=i;
-	      break;
-	    }
+            if (row>=0)
+            {
+                //Check if the cell is empty
+                QTableWidgetItem* it=ui.kList->item ( row, i );
+                if ( it )
+                {
+                    if (it->text().isEmpty())
+                    {
+                        output=i;
+                        break;
+                    }
+                }
+            }
+            else
+            {
+                output=i;
+                break;
+            }
         }
     }
 
     //If not existing, we have to create it
-    if(output==-1)
+    if (output==-1)
     {
-      int nb=ui.kListAtt->count();
-      for ( int i=0; i<nb; ++i )
-      {
-	  QListWidgetItem* it=ui.kListAtt->item ( i );
-	  if ( it && iAttribute==it->data ( Qt::UserRole ).toString() )
-	  {
-	      addColumnFromAttribut(it);
-	      output=nbCol;
-	      break;
-	  }
-      }
+        int nb=ui.kListAtt->count();
+        for ( int i=0; i<nb; ++i )
+        {
+            QListWidgetItem* it=ui.kListAtt->item ( i );
+            if ( it && iAttribute==it->data ( Qt::UserRole ).toString() )
+            {
+                addColumnFromAttribut(it);
+                output=nbCol;
+                break;
+            }
+        }
     }
 
     return output;
@@ -213,62 +231,62 @@ QString SKGQueryCreator::getXMLCondition()
 {
     QString output;
     QHeaderView* hHeader=ui.kList->horizontalHeader();
-    if(hHeader)
+    if (hHeader)
     {
-      QDomDocument doc ( "SKGML" );
-      QDomElement element = doc.createElement ( "element" );
-      doc.appendChild ( element );
+        QDomDocument doc ( "SKGML" );
+        QDomElement element = doc.createElement ( "element" );
+        doc.appendChild ( element );
 
-      QDomComment com=doc.createComment ( "OR" );
-      element.appendChild ( com );
+        QDomComment com=doc.createComment ( "OR" );
+        element.appendChild ( com );
 
-      bool empty=true;
-      int nbRow=ui.kList->rowCount();
-      int nbCol=hHeader->count();
-      for ( int j=0; j<nbRow; ++j )
-      {
-	  QDomElement elementLine = doc.createElement ( "element" );
-	  element.appendChild ( elementLine );
+        bool empty=true;
+        int nbRow=ui.kList->rowCount();
+        int nbCol=hHeader->count();
+        for ( int j=0; j<nbRow; ++j )
+        {
+            QDomElement elementLine = doc.createElement ( "element" );
+            element.appendChild ( elementLine );
 
-	  QDomComment com=doc.createComment ( "AND" );
-	  elementLine.appendChild ( com );
+            QDomComment com=doc.createComment ( "AND" );
+            elementLine.appendChild ( com );
 
-	  bool atLeastOne=false;
-	  for ( int i=0; i<nbCol; ++i )
-	  {
-	      int iRealPos=hHeader->logicalIndex (i);
-	      QTableWidgetItem* it=ui.kList->item ( j, iRealPos );
-	      if ( it )
-	      {
-		  QString co=it->data ( Qt::UserRole ).toString();
-		  if ( !co.isEmpty() )
-		  {
-		      QDomElement elementElement = doc.createElement ( "element" );
-		      elementLine.appendChild ( elementElement );
+            bool atLeastOne=false;
+            for ( int i=0; i<nbCol; ++i )
+            {
+                int iRealPos=hHeader->logicalIndex (i);
+                QTableWidgetItem* it=ui.kList->item ( j, iRealPos );
+                if ( it )
+                {
+                    QString co=it->data ( Qt::UserRole ).toString();
+                    if ( !co.isEmpty() )
+                    {
+                        QDomElement elementElement = doc.createElement ( "element" );
+                        elementLine.appendChild ( elementElement );
 
-		      QTableWidgetItem* it_h=ui.kList->horizontalHeaderItem ( iRealPos );
-		      QString attname=it_h->data ( Qt::UserRole ).toString();
+                        QTableWidgetItem* it_h=ui.kList->horizontalHeaderItem ( iRealPos );
+                        QString attname=it_h->data ( Qt::UserRole ).toString();
 
-		      QDomDocument doc2 ( "SKGML" );
-		      doc2.setContent ( co );
-		      QDomElement root2 = doc2.documentElement();
+                        QDomDocument doc2 ( "SKGML" );
+                        doc2.setContent ( co );
+                        QDomElement root2 = doc2.documentElement();
 
-		      elementElement.setAttribute ( "attribute", attname );
-		      elementElement.setAttribute ( "operator", root2.attribute ( "operator" ) );
-		      if ( root2.hasAttribute ( "value" ) ) elementElement.setAttribute ( "value", root2.attribute ( "value" ) );
-		      if ( root2.hasAttribute ( "value2" ) ) elementElement.setAttribute ( "value2", root2.attribute ( "value2" ) );
-		      if ( root2.hasAttribute ( "att2" ) ) elementElement.setAttribute ( "att2", root2.attribute ( "att2" ) );
-		      if ( root2.hasAttribute ( "att2s" ) ) elementElement.setAttribute ( "att2s", root2.attribute ( "att2s" ) );
+                        elementElement.setAttribute ( "attribute", attname );
+                        elementElement.setAttribute ( "operator", root2.attribute ( "operator" ) );
+                        if ( root2.hasAttribute ( "value" ) ) elementElement.setAttribute ( "value", root2.attribute ( "value" ) );
+                        if ( root2.hasAttribute ( "value2" ) ) elementElement.setAttribute ( "value2", root2.attribute ( "value2" ) );
+                        if ( root2.hasAttribute ( "att2" ) ) elementElement.setAttribute ( "att2", root2.attribute ( "att2" ) );
+                        if ( root2.hasAttribute ( "att2s" ) ) elementElement.setAttribute ( "att2s", root2.attribute ( "att2s" ) );
 
-		      atLeastOne=true;
-		      empty=false;
-		  }
-	      }
-	  }
+                        atLeastOne=true;
+                        empty=false;
+                    }
+                }
+            }
 
-	  if ( !atLeastOne ) element.removeChild ( elementLine );
-      }
-      if ( !empty ) output=doc.toString();
+            if ( !atLeastOne ) element.removeChild ( elementLine );
+        }
+        if ( !empty ) output=doc.toString();
     }
 
     return output;
@@ -305,26 +323,26 @@ void SKGQueryCreator::onAddColumn()
 
 void SKGQueryCreator::addColumnFromAttribut(const QListWidgetItem* listItem)
 {
-    if(listItem)
+    if (listItem)
     {
-	bool previous=ui.kList->blockSignals ( true );
+        bool previous=ui.kList->blockSignals ( true );
 
-	int nb=ui.kList->columnCount();
-	ui.kList->setColumnCount ( nb+1 );
+        int nb=ui.kList->columnCount();
+        ui.kList->setColumnCount ( nb+1 );
 
-	//Create header
-	QTableWidgetItem* item=new QTableWidgetItem ( listItem->icon(), listItem->text() );
-	item->setData ( Qt::UserRole, listItem->data ( Qt::UserRole ) );
-	ui.kList->setHorizontalHeaderItem ( nb, item );
+        //Create header
+        QTableWidgetItem* item=new QTableWidgetItem (listItem->icon() , listItem->text() );
+        item->setData ( Qt::UserRole, listItem->data ( Qt::UserRole ) );
+        ui.kList->setHorizontalHeaderItem ( nb, item );
 
-	//Create items
-	int nbRows=ui.kList->rowCount();
-	for ( int i=0; i<nbRows; ++i )
-	{
-	    QTableWidgetItem* item = new QTableWidgetItem();
-	    ui.kList->setItem ( i, nb, item );
-	}
-	ui.kList->blockSignals ( previous );
+        //Create items
+        int nbRows=ui.kList->rowCount();
+        for ( int i=0; i<nbRows; ++i )
+        {
+            QTableWidgetItem* item = new QTableWidgetItem();
+            ui.kList->setItem ( i, nb, item );
+        }
+        ui.kList->blockSignals ( previous );
     }
 }
 
@@ -339,11 +357,11 @@ void SKGQueryCreator::addNewLine()
         int row=ui.kList->rowCount();
         ui.kList->insertRow ( row );
 
-	// Add a delete icon
-	if(!updateMode)
-	{
-	  ui.kList->setVerticalHeaderItem (row, new QTableWidgetItem( KIcon("edit-delete"),""));
-	}
+        // Add a delete icon
+        if (!updateMode)
+        {
+            ui.kList->setVerticalHeaderItem (row, new QTableWidgetItem( KIcon("edit-delete"),""));
+        }
 
         for ( int i=0; i<nbCol; ++i )
         {
@@ -356,30 +374,60 @@ void SKGQueryCreator::addNewLine()
     }
 }
 
-void SKGQueryCreator::onRemove(int iRow)
+void SKGQueryCreator::onRemoveColumn(int iColumn)
 {
-    QList<int> rowsToRemove;
-    if(iRow!=-1)
+    QList<int> colToRemove;
+    if (iColumn!=-1)
     {
-      if(!updateMode) rowsToRemove.append ( iRow );
+        colToRemove.append ( iColumn );
     }
     else
     {
-      QList<QTableWidgetItem*> selectedItems = ui.kList->selectedItems();
-      int nb=selectedItems.count();
-      for ( int i = 0; i < nb; ++i )
-      {
-	  QTableWidgetItem* item = selectedItems.at ( i );
-	  int row = item->row();
-	  if ( !rowsToRemove.contains ( row ) )
-	  {
-	      rowsToRemove.append ( row );
-	  }
-      }
+        QList<QTableWidgetItem*> selectedItems = ui.kList->selectedItems();
+        int nb=selectedItems.count();
+        for ( int i = 0; i < nb; ++i )
+        {
+            QTableWidgetItem* item = selectedItems.at ( i );
+            int row = item->row();
+            if ( !colToRemove.contains ( row ) )
+            {
+                colToRemove.append ( row );
+            }
+        }
+    }
+    for ( int j = colToRemove.count()-1; j >=0 ; --j )
+    {
+        ui.kList->removeColumn ( colToRemove.at ( j ) );
+    }
+
+    // To be sure that we have at least an empty line
+    onCloseEditor();
+}
+
+void SKGQueryCreator::onRemoveLine(int iRow)
+{
+    QList<int> rowsToRemove;
+    if (iRow!=-1)
+    {
+        if (!updateMode) rowsToRemove.append ( iRow );
+    }
+    else
+    {
+        QList<QTableWidgetItem*> selectedItems = ui.kList->selectedItems();
+        int nb=selectedItems.count();
+        for ( int i = 0; i < nb; ++i )
+        {
+            QTableWidgetItem* item = selectedItems.at ( i );
+            int row = item->row();
+            if ( !rowsToRemove.contains ( row ) )
+            {
+                rowsToRemove.append ( row );
+            }
+        }
     }
     for ( int j = rowsToRemove.count()-1; j >=0 ; --j )
     {
-	ui.kList->removeRow ( rowsToRemove.at ( j ) );
+        ui.kList->removeRow ( rowsToRemove.at ( j ) );
     }
 
     // To be sure that we have at least an empty line
