@@ -36,62 +36,63 @@ class SKGDocument;
  */
 class SKGBANKGUI_EXPORT SKGQueryCreator : public QWidget
 {
-        Q_OBJECT
+    Q_OBJECT
 
 public:
-        /**
-         * Default Constructor
-         * @param parent the parent
-         */
-        SKGQueryCreator(QWidget *parent = 0);
+    /**
+     * Default Constructor
+     * @param parent the parent
+     */
+    SKGQueryCreator(QWidget *parent = 0);
 
-        /**
-         * Default Destructor
-         */
-        virtual ~SKGQueryCreator();
+    /**
+     * Default Destructor
+     */
+    virtual ~SKGQueryCreator();
 
-        /**
-         * Set parameters
-         * @param iDocument the document
-         * @param iTable the table
-         * @param iListAttribute the list of attribute (empty means all attributes supported of the table)
-         * @param iModeUpdate to enable update mode
-         */
-        virtual void setParameters(const SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute=QStringList(), bool iModeUpdate=false);
+    /**
+     * Set parameters
+     * @param iDocument the document
+     * @param iTable the table
+     * @param iListAttribute the list of attribute (empty means all attributes supported of the table)
+     * @param iModeUpdate to enable update mode
+     */
+    virtual void setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute=QStringList(), bool iModeUpdate=false);
 
-        /**
-         * Set XML representing the query
-         * @param iXML the XML representing the query
-         */
-        virtual void setXMLCondition(const QString& iXML);
+    /**
+     * Set XML representing the query
+     * @param iXML the XML representing the query
+     */
+    virtual void setXMLCondition(const QString& iXML);
 
-        /**
-         * Get XML representing the query
-         * @return the XML representing the query
-         */
-        virtual QString getXMLCondition();
+    /**
+     * Get XML representing the query
+     * @return the XML representing the query
+     */
+    virtual QString getXMLCondition();
 
-public slots:
-        /**
-         * Clear table content
-         */
-        void clearContents();
+public Q_SLOTS:
+    /**
+     * Clear table content
+     */
+    void clearContents();
 
-private slots:
-        void onRemove(int iRow=-1);
-        void onCloseEditor();
-        void onAddColumn();
+private Q_SLOTS:
+    void onRemoveLine(int iRow=-1);
+    void onRemoveColumn(int iColumn=-1);
+    void onCloseEditor();
+    void onAddColumn();
 private:
-        Q_DISABLE_COPY(SKGQueryCreator);
+    Q_DISABLE_COPY(SKGQueryCreator);
 
-        void addNewLine();
-        int getIndexQueryColumn(const QString& iAttribute, int row=-1);
-	void addColumnFromAttribut(const QListWidgetItem* listItem);
+    void addNewLine();
+    int getIndexQueryColumn(const QString& iAttribute, int row=-1);
+    void addColumnFromAttribut(const QListWidgetItem* listItem);
 
-        Ui::skgquerycreator_base ui;
-        SKGDocument* document;
-        QString table;
-        bool updateMode;
+    Ui::skgquerycreator_base ui;
+    SKGDocument* document;
+    QString table;
+    bool updateMode;
 };
 
 #endif // SKGQUERYCREATOR_H
