@@ -32,54 +32,54 @@ class SKGDocument;
  */
 class SKGBANKGUI_EXPORT SKGQueryDelegate : public QItemDelegate
 {
-        Q_OBJECT
+    Q_OBJECT
 public:
-        /**
-         * Default Constructor
-         */
-        explicit SKGQueryDelegate(QObject* parent = 0, SKGDocument* iDoc=NULL, bool iModeUpdate=false, const QStringList& iListAtt=QStringList());
+    /**
+     * Default Constructor
+     */
+    explicit SKGQueryDelegate(QObject* parent = 0, SKGDocument* iDoc=NULL, bool iModeUpdate=false, const QStringList& iListAtt=QStringList());
 
-        /**
-         * Default Destructor
-         */
-        virtual ~SKGQueryDelegate();
+    /**
+     * Default Destructor
+     */
+    virtual ~SKGQueryDelegate();
 
-        /**
-         * Returns the widget used to edit the item specified by index for editing.
-         * The parent widget and style option are used to control how the editor widget appears.
-         * @param parent perant widget
-         * @param option options
-         * @param index index
-         * @return the widget
-         */
-        QWidget *createEditor(QWidget *parent,
-                              const QStyleOptionViewItem & option ,
-                              const QModelIndex & index ) const;
+    /**
+     * Returns the widget used to edit the item specified by index for editing.
+     * The parent widget and style option are used to control how the editor widget appears.
+     * @param parent perant widget
+     * @param option options
+     * @param index index
+     * @return the widget
+     */
+    QWidget *createEditor(QWidget *parent,
+                          const QStyleOptionViewItem & option ,
+                          const QModelIndex & index ) const;
 
-        /**
-         * Sets the data to be displayed and edited by the editor from the data model item specified by the model index.
-         * @param editor the editor
-         * @param index the index
-         */
-        virtual void setEditorData ( QWidget * editor, const QModelIndex & index ) const;
+    /**
+     * Sets the data to be displayed and edited by the editor from the data model item specified by the model index.
+     * @param editor the editor
+     * @param index the index
+     */
+    virtual void setEditorData ( QWidget * editor, const QModelIndex & index ) const;
 
-        /**
-         * Gets data from the editor widget and stores it in the specified model at the item inde
-         * @param editor the editor
-         * @param model the model
-         * @param index the index
-         */
-        virtual void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
+    /**
+     * Gets data from the editor widget and stores it in the specified model at the item inde
+     * @param editor the editor
+     * @param model the model
+     * @param index the index
+     */
+    virtual void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
 
-private slots:
-        void commitAndCloseEditor();
+private Q_SLOTS:
+    void commitAndCloseEditor();
 
 private:
-        Q_DISABLE_COPY(SKGQueryDelegate);
+    Q_DISABLE_COPY(SKGQueryDelegate);
 
-        SKGDocument* document;
-        bool updateMode;
-        QStringList listAtt;
+    SKGDocument* document;
+    bool updateMode;
+    QStringList listAtt;
 };
 
 #endif // SKGQUERYDELEGATE_H
