@@ -263,11 +263,29 @@ bool SKGAccountObject::isBookmarked() const
 
 SKGError SKGAccountObject::getUnit ( SKGUnitObject& oUnit ) const
 {
-    SKGObjectBase::SKGListSKGObjectBase units;
-    SKGError err=SKGObjectBase::getObjects ( getDocument(), "v_unit",
-                 "t_type IN ('1', '2', 'C') AND EXISTS(SELECT 1 FROM operation WHERE rc_unit_id=v_unit.id AND rd_account_id="+SKGServices::intToString ( getID() ) +") ORDER BY t_type", units );
-    int nb=units.count();
-    if ( nb ) oUnit=units.at ( 0 );
+    //Get initial amount
+    SKGStringListList listTmp;
+    SKGError err=SKGServices::executeSelectSqliteOrder ( getDocument(),"SELECT t_UNIT FROM  v_operation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id="+SKGServices::intToString ( getID() ), listTmp );
+    if ( err.isSucceeded() )
+    {
+        //Is initial amount existing ?
+        if ( listTmp.count() >1 )
+        {
+            //Yes ==> then the amount is the amount of the initial value
+            oUnit=SKGUnitObject(getDocument());
+            err=oUnit.setSymbol(listTmp.at(1).at(0));
+            if ( err.isSucceeded() ) err=oUnit.load();
+        }
+        else
+        {
+            //No ==> we get the preferred unit
+            SKGObjectBase::SKGListSKGObjectBase units;
+            err=SKGObjectBase::getObjects ( getDocument(), "v_unit",
+                                            "t_type IN ('1', '2', 'C') AND EXISTS(SELECT 1 FROM operation WHERE rc_unit_id=v_unit.id AND rd_account_id="+SKGServices::intToString ( getID() ) +") ORDER BY t_type", units );
+            int nb=units.count();
+            if ( nb ) oUnit=units.at ( 0 );
+        }
+    }
     return err;
 }
 
@@ -607,4 +625,76 @@ SKGError SKGAccountObject::computeInterestItems ( QList<SKGAccountObject::SKGInt
     return err;
 }
 
+SKGError SKGAccountObject::autoReconcile(double iBalance)
+{
+    SKGError err;
+    //
+    SKGDocumentBank* doc=(SKGDocumentBank*) getDocument();
+    if (doc)
+    {
+        //Get unit
+        SKGServices::SKGUnitInfo unit1=doc->getPrimaryUnit();
+        SKGUnitObject unitAccount;
+        if ( getUnit ( unitAccount ).isSucceeded() )
+        {
+            if ( !unitAccount.getSymbol().isEmpty() )
+            {
+                unit1.Symbol=unitAccount.getSymbol();
+                unit1.Value=SKGServices::stringToDouble ( unitAccount.getAttribute ( "f_CURRENTAMOUNT" ) );
+            }
+        }
+
+        //Get balance of checked operations
+        double balance=0;
+        SKGStringListList listTmp2;
+        err=SKGServices::executeSelectSqliteOrder ( getDocument(),
+                "SELECT TOTAL(f_CHECKED) from v_account_display WHERE id="+SKGServices::intToString(getID()),
+                listTmp2 );
+        if ( listTmp2.count() ==2 ) balance=SKGServices::stringToDouble ( listTmp2.at ( 1 ).at ( 0 ) ) /unit1.Value;
+
+
+        //Get all imported operation
+        double diff=balance-iBalance;
+        SKGObjectBase::SKGListSKGObjectBase operations;
+        if (err.isSucceeded()) err=SKGObjectBase::getObjects(getDocument(), "v_operation", "rd_account_id="+SKGServices::intToString(getID())+" AND t_status='N' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations);
+
+
+        //Comparison
+        QString zero=doc->formatMoney ( 0, unit1 );
+        QString negativezero=doc->formatMoney ( -0.00001, unit1 );
+
+        //Try to find the soluce
+        int nb=operations.count();
+
+        QString sdiff=doc->formatMoney ( diff, unit1 );
+        int limit=-1;
+        for (int i=0; sdiff!=zero && sdiff!=negativezero && err.isSucceeded() && i<nb; ++i)
+        {
+            SKGOperationObject op=operations.at(i);
+            double amount=op.getCurrentAmount();
+            diff+=amount;
+            sdiff=doc->formatMoney ( diff, unit1 );
+            SKGTRACEL(5) << (i+1) << "/"<< nb << ": Amount=" << amount << " / New diff=" << sdiff << endl;
+            if (sdiff==zero || sdiff==negativezero) limit=i;
+        }
+
+        //Check all
+        if (limit!=-1)
+        {
+            for (int i=0; err.isSucceeded() && i<=limit; ++i)
+            {
+                SKGOperationObject op=operations.at(i);
+                err=op.setStatus(SKGOperationObject::POINTED);
+                if (err.isSucceeded()) err=op.save(true, false);
+            }
+        }
+        else
+        {
+            err=SKGError(ERR_FAIL, i18nc("Error message",  "Can not find the imported operations for obtaining the expected final balance" ) );
+        }
+    }
+
+    return err;
+}
+
 #include "skgaccountobject.moc"
