@@ -154,5 +154,8 @@ protected:
      */
     virtual QString getWhereclauseId() const;
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGCategoryObject, Q_MOVABLE_TYPE );
 #endif
