@@ -24,13 +24,14 @@
 #include "skgsuboperationobject.h"
 #include "skgaccountobject.h"
 #include "skgunitobject.h"
+#include "skgpayeeobject.h"
 #include "skgservices.h"
 #include "skgdocument.h"
 #include "skgtraces.h"
 
 #include <klocale.h>
 
-SKGOperationObject::SKGOperationObject ( const SKGDocument* iDocument, int iID ) : SKGObjectBase ( iDocument, "v_operation", iID )
+SKGOperationObject::SKGOperationObject ( SKGDocument* iDocument, int iID ) : SKGObjectBase ( iDocument, "v_operation", iID )
 {
 }
 
@@ -51,7 +52,7 @@ SKGOperationObject::SKGOperationObject ( const SKGObjectBase& iObject )
     }
     else
     {
-        *this=SKGObjectBase::SKGObjectBase ( iObject.getDocument(), "v_operation", iObject.getID() );
+        *this=SKGObjectBase ( iObject.getDocument(), "v_operation", iObject.getID() );
     }
 }
 
@@ -177,14 +178,15 @@ QString SKGOperationObject::getMode() const
     return getAttribute ( "t_mode" );
 }
 
-SKGError SKGOperationObject::setPayee ( const QString& iPayee )
+SKGError SKGOperationObject::setPayee ( const SKGPayeeObject& iPayee )
 {
-    return setAttribute ( "t_payee", iPayee );
+    return setAttribute("r_payee_id", SKGServices::intToString(iPayee.getID()));
 }
 
-QString SKGOperationObject::getPayee() const
+SKGError SKGOperationObject::getPayee(SKGPayeeObject& oPayee) const
 {
-    return getAttribute ( "t_payee" );
+    SKGError err = getObject(getDocument(), "v_payee", "id=" + SKGServices::intToString(SKGServices::stringToInt(getAttribute("r_payee_id"))), oPayee);
+    return err;
 }
 
 SKGError SKGOperationObject::setComment ( const QString& iComment )
@@ -250,24 +252,24 @@ bool SKGOperationObject::isTransfer ( SKGOperationObject& oOperation ) const
 {
     SKGObjectBase::SKGListSKGObjectBase ops;
     getGroupedOperations(ops);
-    if(ops.count()==2)
+    if (ops.count()==2)
     {
-      //yes it is maybe a transfer
-      oOperation=(*this==SKGOperationObject(ops.at(0)) ? ops.at(1) : ops.at(0));
+        //yes it is maybe a transfer
+        oOperation=(*this==SKGOperationObject(ops.at(0)) ? ops.at(1) : ops.at(0));
 
-      //Is in same group ?
-      if ( getAttribute ( "i_group_id" ) !=oOperation.getAttribute ( "i_group_id" ) ) return false;
+        //Is in same group ?
+        if ( getAttribute ( "i_group_id" ) !=oOperation.getAttribute ( "i_group_id" ) ) return false;
 
-      //2 ops in the group ?
-      SKGListSKGObjectBase oGroupedOperations;
-      getGroupedOperations (oGroupedOperations);
-      if ( oGroupedOperations.count()!=2 ) return false;
+        //2 ops in the group ?
+        SKGListSKGObjectBase oGroupedOperations;
+        getGroupedOperations (oGroupedOperations);
+        if ( oGroupedOperations.count()!=2 ) return false;
 
-      //Check unit
-      if ( getAttribute ( "rc_unit_id" ) !=oOperation.getAttribute ( "rc_unit_id" ) ) return false;
+        //Check unit
+        if ( getAttribute ( "rc_unit_id" ) !=oOperation.getAttribute ( "rc_unit_id" ) ) return false;
 
-      //Check sum
-      if ( SKGServices::stringToDouble (getAttribute("f_QUANTITY")) !=-SKGServices::stringToDouble (oOperation.getAttribute("f_QUANTITY"))) return false;
+        //Check sum
+        if ( SKGServices::stringToDouble (getAttribute("f_QUANTITY")) !=-SKGServices::stringToDouble (oOperation.getAttribute("f_QUANTITY"))) return false;
     } else return false;
 
     return true;
@@ -368,7 +370,9 @@ bool SKGOperationObject::isImported() const
 
 SKGError SKGOperationObject::setImportID ( const QString& iImportID )
 {
-    return setAttribute ( "t_import_id", iImportID );
+    SKGError err=setAttribute ( "t_import_id", iImportID );
+    if (err.isSucceeded() && !iImportID.isEmpty()) err=setAttribute ( "t_imported", "T" );
+    return err;
 }
 
 QString SKGOperationObject::getImportID() const
@@ -488,10 +492,12 @@ SKGError SKGOperationObject::getRecurrentOperations ( SKGListSKGObjectBase& oRec
 SKGError SKGOperationObject::merge(const SKGOperationObject& iDeletedOne)
 {
     SKGError err=setDate(iDeletedOne.getDate());
-    if (err.isSucceeded()) err=setAttribute("t_imported", iDeletedOne.getAttribute ( "t_imported" ));
     if (err.isSucceeded()) err=setImportID(iDeletedOne.getImportID());
+    if (err.isSucceeded()) err=setAttribute("t_imported", iDeletedOne.getAttribute ( "t_imported" ));
     if (err.isSucceeded() && getComment().isEmpty()) err=setComment(iDeletedOne.getComment());
-    if (err.isSucceeded() && getPayee().isEmpty()) err=setPayee(iDeletedOne.getPayee());
+    SKGPayeeObject payee;
+    getPayee(payee);
+    if (err.isSucceeded()) err=setPayee(payee);
     if (err.isSucceeded() && getMode().isEmpty()) err=setMode(iDeletedOne.getMode());
     if (err.isSucceeded() && !isBookmarked()) err=bookmark(iDeletedOne.isBookmarked());
     if (err.isSucceeded() && !getNumber()) err=setNumber(iDeletedOne.getNumber());
