@@ -370,5 +370,8 @@ public:
      */
     virtual SKGError merge(const SKGOperationObject& iDeletedOne);
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGOperationObject, Q_MOVABLE_TYPE );
 #endif
