@@ -264,5 +264,8 @@ public:
      */
     static SKGError process(SKGDocument* iDocument, int& oNbInserted, const QDate& iDate=QDate::currentDate());
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGRecurrentOperationObject, Q_MOVABLE_TYPE );
 #endif
