@@ -102,10 +102,17 @@ double SKGSubOperationObject::getQuantity() const
 SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker)
 {
     SKGError err;
-    if (iTracker.isClosed()) {
-        err=SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add an operation in a closed tracker"));
-    } else {
-        err=setAttribute("r_refund_id", SKGServices::intToString(iTracker.getID()));
+    SKGTrackerObject previous;
+    getTracker(previous);
+    if (iTracker!=previous)
+    {
+        if (previous.isClosed()) {
+            err=SKGError(ERR_FAIL, i18nc("Error message", "Impossible to remove an operation from a closed tracker"));
+        } else if (iTracker.isClosed()) {
+            err=SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add an operation in a closed tracker"));
+        } else {
+            err=setAttribute("r_refund_id", SKGServices::intToString(iTracker.getID()));
+        }
     }
     return err;
 }
