@@ -105,7 +105,7 @@ QStringList SKGUnitObject::getListofKnownCurrencies(bool iIncludingObsolete)
     int nb=units.count();
     for (int i=0; i<nb; ++i)
     {
-        output << KCurrencyCode::currencyCodeToName(units.at(i), KGlobal::locale()==NULL ? "en" : "")+" ("+units.at(i)+")";
+        output << KCurrencyCode::currencyCodeToName(units.at(i), KGlobal::locale()==NULL ? "en" : "")+" ("+units.at(i)+')';
     }
     output.sort();
 
@@ -145,7 +145,7 @@ SKGServices::SKGUnitInfo SKGUnitObject::getUnitInfo ( const QString& iUnitName )
     if (KCurrencyCode::isValid(isoCode))
     {
         KCurrencyCode unitCode(isoCode, KGlobal::locale()==NULL ? "en" : "");
-        info.Name=unitCode.name()+" ("+unitCode.isoCurrencyCode()+")";;
+        info.Name=unitCode.name()+" ("+unitCode.isoCurrencyCode()+')';;
         info.Symbol=unitCode.unambiguousSymbol();
         if (info.Symbol.isEmpty()) info.Symbol=unitCode.name();
         QStringList counties=unitCode.countriesUsingCurrency();
@@ -363,7 +363,7 @@ SKGError SKGUnitObject::getUnit ( SKGUnitObject& oUnit ) const
 SKGError SKGUnitObject::setUnit ( const SKGUnitObject& iUnit )
 {
     SKGError err;
-    if ( *this==iUnit ) err=SKGError ( ERR_INVALIDARG, i18nc ( "Error message", "Reference unit of a unit cannot be itself." ) );
+    if ( *this==iUnit && iUnit.getID()!=0 ) err=SKGError ( ERR_INVALIDARG, i18nc ( "Error message", "Reference unit of a unit cannot be itself." ) );
     else
     {
         err=setAttribute ( "rd_unit_id", SKGServices::intToString ( iUnit.getID() ) );
@@ -478,7 +478,7 @@ double SKGUnitObject::getDailyChange ( const QDate& iDate ) const
         QDate d2=SKGServices::stringToTime ( result.at ( 1 ).at ( 0 ) ).date();
         QDate d1=SKGServices::stringToTime ( result.at ( 2 ).at ( 0 ) ).date();
 
-        output=100* ( exp ( log ( v2/v1 ) / ( d1.daysTo ( d2 ) ) )-1 );
+        output=100* ( exp ( log ( v2/v1 ) / ( SKGServices::nbWorkingDays(d1, d2) ) )-1 );
     }
     return output;
 }
@@ -498,7 +498,7 @@ SKGError SKGUnitObject::split ( double iRatio ) const
     return err;
 }
 
-SKGError SKGUnitObject::downloadUnitValue ( UnitDownloadMode iMode, int nbMaxValues ) const
+SKGError SKGUnitObject::downloadUnitValue ( UnitDownloadMode iMode, int nbMaxValues, bool iAdditionalInfo ) const
 {
     SKGError err;
     SKGTRACEINRC ( 10, "SKGUnitObject::downloadUnitValue",err );
@@ -606,11 +606,190 @@ SKGError SKGUnitObject::downloadUnitValue ( UnitDownloadMode iMode, int nbMaxVal
         }
         if ( err.isSucceeded() )
         {
+            //Build list of additional download information
             //http://www.etraderzone.com/free-scripts/50-yahoo-stock-quotes.html?catid=34%3Aexcel-script
-            QString path="http://download.finance.yahoo.com/d/quotes.csv?s="+code+"&f=l1d1&e=.csv";//l1=val d1=date
+            QStringList unitYahooCode;
+            QStringList unitYahooTitle;
+            QString yahooString;
+            if (iAdditionalInfo)
+            {
+                unitYahooCode.push_back("a");//1
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Ask"));
+                unitYahooCode.push_back("a2");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Average Daily Volume"));
+                //Sometimes contains a , ==> KO: unitYahooCode.push_back("a5");
+                //Sometimes contains a , ==> KO: unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Ask Size"));
+                unitYahooCode.push_back("b");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Bid"));
+                unitYahooCode.push_back("b4");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Book Value"));
+                //Can block due to , unitYahooCode.push_back("b6");
+                //Can block due to , unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Bid Size"));
+                //unitYahooCode.push_back("c");
+                //unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "% Change"));
+                unitYahooCode.push_back("c1");//10
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change"));
+                unitYahooCode.push_back("c3");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Commission"));
+                unitYahooCode.push_back("d");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Dividend/Share"));
+                unitYahooCode.push_back("d2");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Trade Date"));
+                unitYahooCode.push_back("e");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Earning/Share"));
+                //unitYahooCode.push_back("e1");
+                //unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Error Indication"));
+                unitYahooCode.push_back("e7");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "EPS Estimate Current Year"));
+                unitYahooCode.push_back("e8");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "EPS Estimate Next Year"));
+                unitYahooCode.push_back("e9");//20
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "EPS Estimate Next Quarter"));
+                //unitYahooCode.push_back("f6");
+                //unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Float Shares"));
+                unitYahooCode.push_back("g1");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Gain %"));
+                unitYahooCode.push_back("g3");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Annualized Gain"));
+                unitYahooCode.push_back("g4");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Gain"));
+                unitYahooCode.push_back("i");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "More Info"));
+                unitYahooCode.push_back("j1");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Market Capitalization"));
+                unitYahooCode.push_back("j4");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "EBITDA"));
+                unitYahooCode.push_back("j5");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change from 52 weeks Low"));
+                unitYahooCode.push_back("j6");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share",
+                                               // xgettext: no-c-format
+                                               "% Change from 52 weeks Low"));
+                unitYahooCode.push_back("k3");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Last Trade Size"));
+                unitYahooCode.push_back("k4");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change from 52 weeks High"));
+                unitYahooCode.push_back("k5");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share",
+                                               // xgettext: no-c-format
+                                               "% Change from 52 weeks"));
+                //unitYahooCode.push_back("l");
+                //unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Last Trade with Time"));
+                unitYahooCode.push_back("l2");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "High Limit"));
+                unitYahooCode.push_back("l3");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Low Limit"));
+                unitYahooCode.push_back("m");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Day's Range"));
+                unitYahooCode.push_back("m3");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "50 days MA"));
+                unitYahooCode.push_back("m4");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "200 days MA"));
+                unitYahooCode.push_back("m5");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change from 200 days MA"));
+                unitYahooCode.push_back("m6");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share",
+                                               // xgettext: no-c-format
+                                               "% Change from 200 days MA"));
+                unitYahooCode.push_back("m7");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change from 50 days MA"));
+                unitYahooCode.push_back("m8");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share",
+                                               // xgettext: no-c-format
+                                               "% Change from 50 days MA"));
+                unitYahooCode.push_back("n4");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Notes"));
+                unitYahooCode.push_back("o");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Open"));
+                unitYahooCode.push_back("p");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Previous Close"));
+                unitYahooCode.push_back("p1");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price Paid"));
+                unitYahooCode.push_back("p2");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change in %"));
+                unitYahooCode.push_back("p5");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price/Sales"));
+                unitYahooCode.push_back("p6");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price/Book"));
+                unitYahooCode.push_back("q");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Ex-Dividend Date"));
+                unitYahooCode.push_back("r");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "P/E Ratio"));
+                unitYahooCode.push_back("r1");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Dividend Pay Date"));
+                unitYahooCode.push_back("r5");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "PEG Ratio"));
+                unitYahooCode.push_back("r6");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price/EPS Estimate Current Year"));
+                unitYahooCode.push_back("r7");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price/EPS Estimate Next Year"));
+                //unitYahooCode.push_back("s");
+                //unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Symbol"));
+                unitYahooCode.push_back("s1");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Shares Owned"));
+                unitYahooCode.push_back("s7");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Short Ratio"));
+                unitYahooCode.push_back("t1");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Last Trade Time"));
+                unitYahooCode.push_back("t8");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "1 Year Target"));
+                unitYahooCode.push_back("v");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Volume"));
+                unitYahooCode.push_back("v1");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Value"));
+                unitYahooCode.push_back("w");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "52 weeks Range"));
+                unitYahooCode.push_back("w1");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Day's Value Change"));
+                unitYahooCode.push_back("x");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Stock Exchange"));
+                unitYahooCode.push_back("y");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Dividend Yield"));
+                unitYahooCode.push_back("n"); //Must be the last
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Name"));
+
+                /*unitYahooCode.push_back("c6");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change (RT)"));
+                unitYahooCode.push_back("c8");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "After Hour Change (RT)"));
+                unitYahooCode.push_back("g5");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Gain % (RT)"));
+                unitYahooCode.push_back("g6");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Gain (RT)"));
+                unitYahooCode.push_back("i5");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Order Book (RT)"));
+                unitYahooCode.push_back("j3");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Market Cap (RT)"));
+                unitYahooCode.push_back("k1");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Last Trade with Time (RT)"));
+                unitYahooCode.push_back("k2");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change % (RT)"));
+                unitYahooCode.push_back("r2");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "P/E Ratio (RT)"));
+                unitYahooCode.push_back("b2");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Ask (RT)"));
+                unitYahooCode.push_back("b3");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Bid (RT)"));
+                unitYahooCode.push_back("v7");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Value (RT)"));
+                unitYahooCode.push_back("m2");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Day's Range (RT)"));
+                unitYahooCode.push_back("w4");
+                unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Day's Value Change (RT)"));*/
+
+                foreach(const QString& key, unitYahooCode)
+                {
+                    yahooString+=key;
+                }
+
+                //Add yahoo url
+                err=setProperty(i18nc("Yahoo title for a downloaded information of a share", "Yahoo page"), "http://finance.yahoo.com/q?s="+code);
+            }
+
+            QString path="http://download.finance.yahoo.com/d/quotes.csv?s="+code+"&f=l1d1"+yahooString;//l1=val d1=date
             KUrl url ( path );
             QString tmpFile;
-            if ( KIO::NetAccess::download ( url, tmpFile, NULL ) )
+            if ( err.isSucceeded() && KIO::NetAccess::download ( url, tmpFile, NULL ) )
             {
 
                 //Open file
@@ -625,18 +804,33 @@ SKGError SKGUnitObject::downloadUnitValue ( UnitDownloadMode iMode, int nbMaxVal
 
                     //Read line
                     QString line=stream.readLine().trimmed();
-                    line.remove ( '"' );
                     QStringList fields=SKGServices::splitCSVLine ( line, ',' );
                     QDate ds;
-                    if ( fields.count()==2 && ( ds=QDate::fromString ( fields[1], "M/d/yyyy" ) ).isValid() )
+                    int nb=fields.count();
+                    if (nb!=unitYahooTitle.count()+2)
                     {
-                        double val=SKGServices::stringToDouble ( fields[0] );
-                        err=doc->addOrModifyUnitValue ( unitname, ds , invert && val!=0 ? 1/val : val);
+                        err.setReturnCode ( ERR_ABORT );
+                        err.setMessage ( i18nc ( "An error message", "Invalid number of fields (found=%1, expected=%2) for %3 in following string:\n%4",SKGServices::intToString(nb), SKGServices::intToString(unitYahooTitle.count()+2), unitname, line) );
+
                     }
                     else
                     {
-                        err.setReturnCode ( ERR_ABORT );
-                        err.setMessage ( i18nc ( "An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2",line, path ) );
+                        if (( ds=QDate::fromString ( fields[1], "M/d/yyyy" ) ).isValid() )
+                        {
+                            double val=SKGServices::stringToDouble ( fields[0] );
+                            err=doc->addOrModifyUnitValue ( unitname, ds , invert && val!=0 ? 1/val : val);
+                        }
+                        else
+                        {
+                            err.setReturnCode ( ERR_ABORT );
+                            err.setMessage ( i18nc ( "An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2",line, path ) );
+                        }
+
+                        for (int j=2; err.isSucceeded() && j<nb; ++j)
+                        {
+                            QString val=fields[j];
+                            if (!val.contains("N/A") && val!="-" && val!="- - -" && val!="0" && val!="0.00") err=setProperty(unitYahooTitle[j-2], val);
+                        }
                     }
 
                     //close file
