@@ -248,11 +248,12 @@ public:
     /**
      * Download values
      * @param iMode download mode
-     * @param nbMaxValues nb max of values to download
+     * @param iNbMaxValues nb max of values to download
+     * @param iAdditionalInfo to download additional information as property of the unit
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError downloadUnitValue(UnitDownloadMode iMode=LAST, int nbMaxValues=50) const;
+    virtual SKGError downloadUnitValue(UnitDownloadMode iMode=LAST, int iNbMaxValues=50, bool iAdditionalInfo=false) const;
 
     /**
      * Get amount of the unit at a date
@@ -309,5 +310,8 @@ protected:
      */
     virtual QString getWhereclauseId() const;
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGUnitObject, Q_MOVABLE_TYPE );
 #endif
