@@ -313,8 +313,7 @@ int main ( int argc, char** argv )
             SKGAccountObject account ( &document1 );
             SKGTESTERROR ( "QIF.setName", account.setName ( "ACTIF Moto" ), true );
             SKGTESTERROR ( "QIF.load", account.load(), true );
-            SKGTEST ( "QIF:getValue", SKGServices::doubleToString ( account.getCurrentAmount() ), "5010" );
-
+            SKGTEST ( "QIF:getValue", SKGServices::doubleToString ( (int) account.getCurrentAmount() ), "5009" );
         }
     }
 
@@ -754,6 +753,21 @@ int main ( int argc, char** argv )
         }
     }
 
+    {
+        //Quicken
+        SKGDocumentBank document1;
+        SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
+        SKGError err;
+        {
+            //Scope of the transaction
+            SKGBEGINTRANSACTION ( document1, "IMPORT", err );
+
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/quicken.qif" );
+            SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
+
+        }
+    }
+
     //End test
     SKGENDTEST();
 }
