@@ -24,25 +24,6 @@
 
 #include "skgdocumentbank.h"
 
-/**
- * The full test
- * @param  iMode the database mode
- * @param  nberror the variable containing number of errors
- * @param  nbcheck the variable containing number of checks
- * @param  showonlyfailures the variable containing number of showonlyfailures
- */
-void fileTest(SKGDocument::DatabaseMode iMode, int& nberror, int& nbcheck, bool showonlyfailures)
-{
-        //Test load old version of files
-        {
-                SKGDocumentBank document1(iMode);
-                SKGTESTERROR("DOC:load", document1.load(getTestPath("IN")+"/skgtestmigration/version_0.1.skg"), true);
-        }
-        {
-                SKGDocumentBank document1(iMode);
-                SKGTESTERROR("DOC:load", document1.load(getTestPath("IN")+"/skgtestmigration/version_0.3.skg"), true);
-        }
-}
 /**
  * The main function of the unit test
  * @param argc the number of arguments
@@ -50,15 +31,23 @@ void fileTest(SKGDocument::DatabaseMode iMode, int& nberror, int& nbcheck, bool
  */
 int main(int argc, char** argv)
 {
-        Q_UNUSED(argc);
-        Q_UNUSED(argv);
+    Q_UNUSED(argc);
+    Q_UNUSED(argv);
 
-        //Init test
-        SKGINITTEST(true);
-        //MUST BE DONE: fileTest(SKGDocument::CopiedInMemory, nberror, nbcheck, showonlyfailures);
-        fileTest(SKGDocument::CopiedInFile, nberror, nbcheck, showonlyfailures);
-        //MUST BE DONE: fileTest(SKGDocument::DirectAccess, nberror, nbcheck, showonlyfailures);
+    //Init test
+    SKGINITTEST(true);
+    {
+        //Test load old version of files
+        {
+            SKGDocumentBank document1;
+            SKGTESTERROR("DOC:load", document1.load(getTestPath("IN")+"/skgtestmigration/version_0.1.skg"), true);
+        }
+        {
+            SKGDocumentBank document1;
+            SKGTESTERROR("DOC:load", document1.load(getTestPath("IN")+"/skgtestmigration/version_0.3.skg"), true);
+        }
+    }
 
-        //End test
-        SKGENDTEST();
+    //End test
+    SKGENDTEST();
 }
