@@ -98,12 +98,32 @@ int main(int argc, char** argv)
 
             SKGTEST("REF:isClosed", tracker.isClosed(), false);
             SKGTESTERROR("OPE:setClosed",tracker.setClosed(true), true);
-            SKGTEST("REF:isClosed", tracker.isClosed(), true);
+            SKGTEST("REF:isClosed", tracker.isClosed(), true)
             SKGTESTERROR("OPE:setClosed",tracker.setClosed(false), true);
             SKGTEST("REF:isClosed", tracker.isClosed(), false);
 
             SKGTESTERROR("OPE:setTracker",subop1.setTracker(tracker), true);
             SKGTESTERROR("OPE:save", subop1.save(), true);
+
+            SKGTESTERROR("OPE:setClosed",tracker.setClosed(true), true);
+            SKGTESTERROR("OPE:save", tracker.save(), true);
+
+            //BUG 250350 vvv
+            SKGTESTERROR("OPE:setTracker",subop1.setTracker(tracker), true);
+            SKGTESTERROR("OPE:setTracker",subop1.setTracker(tracker), true);
+
+            SKGTrackerObject trackerclose(&document1);
+            SKGTESTERROR("REF:setName",trackerclose.setName("trackerclose"), true);
+            SKGTESTERROR("OPE:setClosed",trackerclose.setClosed(true), true);
+            SKGTESTERROR("REF:save", trackerclose.save(), true);
+            SKGTESTERROR("OPE:setTracker",subop1.setTracker(trackerclose), false);
+
+            SKGTrackerObject trackeropen(&document1);
+            SKGTESTERROR("REF:setName",trackeropen.setName("trackeropen"), true);
+            SKGTESTERROR("OPE:setClosed",trackerclose.setClosed(true), true);
+            SKGTESTERROR("OPE:setTracker",subop1.setTracker(trackeropen), false);
+            //BUG 250350 ^^^
+
             SKGTrackerObject tracker2;
             SKGTESTERROR("OPE:getTracker",subop1.getTracker(tracker2), true);
             SKGTEST("OPE:compare", (tracker==tracker2), true);
@@ -119,6 +139,7 @@ int main(int argc, char** argv)
         }
     }
 
+
     //End test
     SKGENDTEST();
 }
