@@ -221,7 +221,7 @@ bool SKGGraphicsView::eventFilter ( QObject *object, QEvent *event )
     }
     else if ( object==graphicsView() &&  event && event->type()==QEvent::Resize )
     {
-        emit resized();
+        Q_EMIT resized();
         if (ui.kZoomOriginal->isChecked() && timer) timer->start(300 );
     }
     return QWidget::eventFilter ( object, event );
