@@ -106,7 +106,7 @@ public:
      */
     virtual KMenu* getContextualMenu() const;
 
-public slots:
+public Q_SLOTS:
     /**
      * Set the zoom
      */
@@ -162,7 +162,7 @@ public slots:
      */
     virtual void onSwitchAntialiasing();
 
-  signals:
+Q_SIGNALS:
     /**
      * View is resized
      */
@@ -177,7 +177,7 @@ protected:
      */
     virtual bool eventFilter ( QObject *object, QEvent *event );
 
-private slots:
+private Q_SLOTS:
     void showMenu ( const QPoint& pos );
 
 private:
