@@ -39,6 +39,16 @@ class SKGBASEGUI_EXPORT SKGInterfacePlugin : public KParts::Plugin
 {
     Q_OBJECT ;
 public:
+    /**
+     * Describe a modification of an object
+     */
+    struct SKGAdvice {
+        QString uuid; 				/**< The uuid of the advice */
+        int priority; 				/**< The priority of the advice (0=low, 10=high) */
+        QString shortMessage;			/**< The short message of the advice */
+        QString longMessage;			/**< The long message of the advice */
+        QStringList autoCorrection;		/**< The message in case of this advice could be auto cleaned. One line per possible solutions */
+    } ;
 
     /**
      * Default constructor
@@ -175,6 +185,21 @@ public:
      */
     virtual bool isEnabled() const;
 
+    /**
+     * The advice list of the plugin.
+     * @return The advice list of the plugin
+     */
+    virtual QList<SKGInterfacePlugin::SKGAdvice> advices() const;
+
+    /**
+     * Must be implemented to execute the automatic correction for the advice.
+     * @param iAdviceIdentifier the identifier of the advice
+     * @param iSolution the identifier of the possible solution
+     * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
+     *   @see SKGError
+     */
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+
 private:
     Q_DISABLE_COPY(SKGInterfacePlugin);
 
@@ -183,6 +208,9 @@ private:
  * This plugin interface definition.
  */
 Q_DECLARE_INTERFACE(SKGInterfacePlugin, "skrooge.com.SKGInterfacePlugin/1.0");
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGInterfacePlugin::SKGAdvice, Q_PRIMITIVE_TYPE );
 
 #endif // SKGINTERFACEPLUGIN_H
