@@ -73,6 +73,12 @@ public:
      */
     virtual ~SKGMainPanel();
 
+    /**
+     * Return the document of the main panel
+     * @return document of the main panel
+     */
+    virtual SKGDocument* getDocument() const;
+
     /**
      * Creates a modal file dialog and returns the selected filename or an empty string if none was chosen.
      * A confirmation message is displayed if needed
@@ -120,7 +126,7 @@ public:
      */
     static KConfigGroup getMainConfigGroup();
 
-public slots:
+public Q_SLOTS:
     /**
      * This function is called when the application is launched again with new arguments
      * @param iArgument the arguments
@@ -278,7 +284,13 @@ public slots:
      */
     virtual void notify ( int iTransaction=0 );
 
-signals:
+    /**
+     * Open settings panel on dedicated page.
+     * @param iPluginName the name of the plugin (pluginInterface->objectName())
+     */
+    virtual void optionsPreferences(const QString& iPluginName="");
+
+Q_SIGNALS:
     /**
      * This signal is sent when the current page change.
      */
@@ -298,15 +310,14 @@ protected:
      */
     virtual bool eventFilter ( QObject *object, QEvent *event );
 
-private slots:
-    void optionsPreferences();
+private Q_SLOTS:
     void onSettingsChanged();
     void onCancelCurrentAction();
     void onQuitAction();
 
     void addTab();
     void onBeforeOpenContext();
-    void onOpenContext();
+    void onOpenContext(Qt::MouseButtons iMouse=Qt::LeftButton, Qt::KeyboardModifiers iKeyboard=Qt::NoModifier);
     void onTipOfDay();
     void onTrayActivated ( QSystemTrayIcon::ActivationReason reason );
     void saveDefaultState();
@@ -316,6 +327,7 @@ private slots:
 
     void actionPrevious();
     void actionNext();
+    void actionFullScreen();
 
     void onShowPreviousMenu();
     void onShowNextMenu();
@@ -335,10 +347,11 @@ private:
     SKGTabWidget *tabWidget;
     KSplashScreen* spScreen;
 
-    SKGDocument* currentBankDocument;
+    SKGDocument* currentDocument;
 
     QList<SKGInterfacePlugin *> pluginsList;
     QMap<QString, KAction*> registeredGlogalAction;
+    QList<QWidget*> hiddenWidgets;
 
     KAction *addTabAction;
     KAction *tipOfDayAction;
@@ -350,6 +363,7 @@ private:
     KAction *overwriteBookmarkStateAction;
     KAction *configureAction;
     KAction *enableEditorAction;
+    KAction* fullScreenAction;
     KTemporaryFile tipsFile;
     static bool currentActionCanceled;
     KPushButton *kCancelButton;
