@@ -33,8 +33,8 @@
 
 #include <QApplication>
 #include <QMimeData>
-#include <qcolor.h>
-#include <assert.h>
+#include <QDir>
+#include <QColor>
 
 SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
                                        const QString& iTable,
@@ -102,15 +102,17 @@ void SKGObjectModelBase::setSupportedAttributes ( const QStringList & iListAttri
     listSize.clear();
 
     QStringList l=iListAttribute;
-    if (l.count()==0 && listSchema.count())  l=SKGServices::splitCSVLine(listSchema.at(0).schema);
+    if (listSchema.count())  l+=SKGServices::splitCSVLine(listSchema.at(0).schema);
 
     int nb=l.count();
     for (int i=0; i<nb; ++i) {
         QStringList values = l.at(i).split('|');
         int nbValues=values.count();
 
-        if (nbValues>0) {
-            listSupported.push_back(values.at(0));
+        QString att=values.at(0);
+
+        if (nbValues>0 && !listSupported.contains(att)) {
+            listSupported.push_back(att);
             bool visible=true;
             if (nbValues>1) visible=(values.at(1)=="Y");
             listVisibility.push_back(visible);
@@ -118,6 +120,7 @@ void SKGObjectModelBase::setSupportedAttributes ( const QStringList & iListAttri
             else listSize.push_back(-1);
         }
     }
+
     isResetRealyNeeded=true;
 }
 
@@ -179,7 +182,7 @@ void SKGObjectModelBase::refresh()
     SKGTRACEIN(1, "SKGObjectModelBase::refresh");
     SKGTRACEL(1) << "Table:" << getTable() << endl;
     QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
-    emit beforeReset();
+    Q_EMIT beforeReset();
     {
         _SKGTRACEIN(10, "QAbstractItemModel::refresh-remove");
         clear();
@@ -203,9 +206,9 @@ void SKGObjectModelBase::refresh()
                 }
                 for (int i=0 ; i<nb ; ++i) {
                     QString att=listSupported[i];
-                    if (listAttibutesTmp.contains(att)) {
+                    if (listAttibutesTmp.contains(att) || att.startsWith(QLatin1String("p_"))) {
                         listAttibutes.push_back(att);
-                        if (att.startsWith(QLatin1String("t_"))) listAttributeTypes.push_back(SKGServices::TEXT);
+                        if (att.startsWith(QLatin1String("t_")) || att.startsWith(QLatin1String("p_"))) listAttributeTypes.push_back(SKGServices::TEXT);
                         else if (att.startsWith(QLatin1String("f_"))) listAttributeTypes.push_back(SKGServices::FLOAT);
                         else if (att.startsWith(QLatin1String("i_"))) listAttributeTypes.push_back(SKGServices::INTEGER);
                         else if (att.startsWith(QLatin1String("d_"))) listAttributeTypes.push_back(SKGServices::DATE);
@@ -275,7 +278,7 @@ void SKGObjectModelBase::refresh()
             QAbstractItemModel::reset();
         }
     }
-    emit afterReset();
+    Q_EMIT afterReset();
     QApplication::restoreOverrideCursor();
 }
 
@@ -410,7 +413,18 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
     case Qt::UserRole: {
         SKGObjectBase* obj = getObjectPointer(index);
         QString att=listAttibutes[index.column()];
-        QString val=obj->getAttribute(att);
+        QString val;
+
+        if (att.startsWith(QLatin1String("p_")))
+        {
+            //This is a property
+            val=obj->getProperty(att.right(att.count()-2));
+        }
+        else
+        {
+            //This is a real attribute
+            val=obj->getAttribute(att);
+        }
 
         switch ( getAttributeType(index.column()) ) {
         case SKGServices::FLOAT: {
@@ -455,33 +469,49 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
     case Qt::DecorationRole: {
         //Decoration
         SKGObjectBase* obj = getObjectPointer(index);
+        QString att=listAttibutes[index.column()];
         if (index.column() == 0 && nodeTable) {
             SKGNodeObject node =*obj;
-            QStringList data=SKGServices::splitCSVLine(node.getData());
-            QIcon icon=KIcon("folder");
-            if (data.count()>2)  icon=(QIcon) KIcon(data.at(2));
-
-            if (node.isAutoStart()) {
-                //Modify icon
-                QStringList overlay;
-                overlay.push_back("user-online");
-                if (data.count()>2)  icon=(QIcon) KIcon(data.at(2), NULL, overlay);
-                else icon=(QIcon) KIcon("folder", NULL, overlay);
-            }
-            return qVariantFromValue(icon);
+            return qVariantFromValue(node.getIcon());
         } else if (index.column() == 0 && doctransactionTable) {
             return qVariantFromValue((QIcon) KIcon(obj->getAttribute("t_mode")=="U" ? "edit-undo" :"edit-redo"));
-        } else if (doctransactionTable && listAttibutes[index.column()]=="t_savestep") {
+        } else if (doctransactionTable && att=="t_savestep") {
             if (obj->getAttribute("t_savestep")=="Y") return qVariantFromValue((QIcon) KIcon("document-save"));
         }
+        /*TODO else if (att.startsWith(QLatin1String("p_")))
+        {
+            //This attribute is a property
+            QVariant blob=obj->getPropertyBlob(att.right(att.count()-2));
+            //Is it a file ?
+            if (!blob.isNull()) {
+                //Yes, this is a file
+                QByteArray blob_bytes=blob.toByteArray();
+
+                //Save temporary file
+                QString fileName=QDir::tempPath ()+'/'+obj->getAttribute("t_value");
+
+                QFile file(fileName);
+                if (file.open(QIODevice::WriteOnly))
+                {
+                    file.write(blob_bytes);
+                    file.flush();
+                    file.close();
+
+                    ui.kPicture->show();
+                     ui.kOpenBtn->show();
+                     ui.kPicture->showPreview(KUrl(fileName));
+                }
+            }
+        }*/
         break;
     }
     case Qt::ToolTipRole: {
         //Tooltip
         QString toolTipString;
-        if (doctransactionTable) {
-            SKGObjectBase* obj = getObjectPointer(index);
-            if (obj && document) {
+        SKGObjectBase* obj = getObjectPointer(index);
+
+        if (obj && document) {
+            if (doctransactionTable) {
                 QStringList msg;
                 document->getMessages(obj->getID(), msg);
                 int nbMessages=msg.count();
@@ -491,10 +521,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
                         toolTipString+=msg.at(i);
                     }
                 }
-            }
-        } else if (getAttributeType(index.column())==SKGServices::DATE) {
-            SKGObjectBase* obj = getObjectPointer(index);
-            if (obj) {
+            } else if (getAttributeType(index.column())==SKGServices::DATE) {
                 QString att=listAttibutes[index.column()];
                 QString val=obj->getAttribute(att);
 
@@ -505,22 +532,17 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
 
                 if (shortDate!=fancyDate) toolTipString=shortDate;
             }
-        }
 
-        //Add properties
-        SKGObjectBase* obj = getObjectPointer(index);
-        if (obj) {
+            //Add properties
             QStringList props=obj->getProperties();
+            if (props.count()>0 && !toolTipString.isEmpty()) toolTipString+='\n';
             foreach(const QString& prop, props) {
                 if (!toolTipString.isEmpty()) toolTipString+='\n';
                 toolTipString+=i18nc("To display a property and its value", "%1=%2", prop, obj->getProperty(prop));
             }
-        }
 
-        //Add UUID
-        IFSKGTRACEL(1) {
-            SKGObjectBase* obj = getObjectPointer(index);
-            if (obj) {
+            //Add UUID
+            IFSKGTRACEL(1) {
                 toolTipString+='\n'+obj->getUniqueID();
             }
         }
@@ -543,12 +565,11 @@ Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex &index) const
 {
     _SKGTRACEIN(10, "SKGObjectModelBase::flags");
 
-    Qt::ItemFlags flags=QAbstractItemModel::flags(index);
+    Qt::ItemFlags flags=QAbstractItemModel::flags(index)| Qt::ItemIsDropEnabled;
 
     if (nodeTable) {
         flags|=Qt::ItemIsEditable;
-        if (index.isValid()) flags|=Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
-        else flags|=Qt::ItemIsDropEnabled;
+        if (index.isValid()) flags|=Qt::ItemIsDragEnabled;
     }
     if (index.column() == 0) flags|=Qt::ItemIsUserCheckable;
     return flags;
@@ -582,13 +603,14 @@ Qt::DropActions SKGObjectModelBase::supportedDragActions() const
 
 Qt::DropActions SKGObjectModelBase::supportedDropActions() const
 {
-    return (nodeTable ? Qt::MoveAction : Qt::IgnoreAction);
+    return Qt::MoveAction;
 }
 
 QStringList SKGObjectModelBase::mimeTypes() const
 {
     QStringList types;
     types << "application/skg."+getRealTable()+".ids";
+    types << "text/uri-list";
     return types;
 }
 
@@ -620,65 +642,90 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData *data,
 {
     Q_UNUSED(row);
     if (action == Qt::IgnoreAction) return true;
-    if (!data || !data->hasFormat("application/skg.node.ids")) return false;
+    if (!data || !(data->hasFormat("application/skg.node.ids") || data->hasUrls())) return false; //TODO: accept all
     if (column > 0) return false;
 
-    QByteArray encodedData = data->data("application/skg.node.ids");
-    QDataStream stream(&encodedData, QIODevice::ReadOnly);
-    QStringList newItems;
-
     SKGError err;
-    SKGNodeObject parentNode;
-    if (parent.isValid())
+    //Drop files
+    if (data->hasUrls() && parent.isValid() && getRealTable()!="node")
     {
-        parentNode=getObject(parent);
-        if (!parentNode.getData().isEmpty())
+        QList<QUrl> urls=data->urls();
+        int nb=urls.count();
         {
-            //The parent is not a directory
-            parentNode.getParentNode(parentNode);
+            SKGObjectBase obj=getObject(parent);
+
+            SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Property creation"), err, nb);
+            for (int i=0; err.isSucceeded() && i<nb; ++i)
+            {
+                QString name=i18n("File");
+                int index=1;
+                while ( err.isSucceeded() && !obj.getProperty(name).isEmpty() ) {
+                    index++;
+                    name=i18n("File")+" ("+SKGServices::intToString(index)+')';
+                }
+                err=obj.setProperty(name, urls.at(i).toLocalFile(), urls.at(i).toLocalFile());
+                if (err.isSucceeded()) err=getDocument()->stepForward(i+1);
+            }
         }
     }
+    //Drop nodes
+    else if (data->hasFormat ( "application/skg.node.ids" ))
     {
-        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Move bookmark"), err);
+        QByteArray encodedData = data->data("application/skg.node.ids");
+        QDataStream stream(&encodedData, QIODevice::ReadOnly);
+        QStringList newItems;
 
-        double min=0;
-        double max=0;
-        if (row>=1) {
-            QModelIndex previousIndex=SKGObjectModelBase::index (row-1, 0, parent);
-            SKGNodeObject previousObject = getObject(previousIndex);
-            min=previousObject.getOrder();
+        SKGNodeObject parentNode;
+        if (parent.isValid())
+        {
+            parentNode=getObject(parent);
+            if (!parentNode.getData().isEmpty())
+            {
+                //The parent is not a directory
+                parentNode.getParentNode(parentNode);
+            }
         }
+        {
+            SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Move bookmark"), err);
 
-        if (row>=rowCount(parent)) max=min+1;
-        else {
-            QModelIndex nextIndex=SKGObjectModelBase::index (row, 0, parent);
-            SKGNodeObject nextObject = getObject(nextIndex);
-            max=nextObject.getOrder();
-        }
-        if (max<=min) max=min+1;
-
-        while (!stream.atEnd() && err.isSucceeded()) {
-            int o_id;
-            QString o_table;
-            stream >> o_table;
-            stream >> o_id;
-
-            //Set parent
-            SKGNodeObject child(getDocument(), o_id);
-            err=child.load();
-            if (err.isSucceeded()) {
-                if (parent.isValid()) err=child.setParentNode(parentNode);
-                else err=child.removeParentNode();
+            double min=0;
+            double max=0;
+            if (row>=1) {
+                QModelIndex previousIndex=SKGObjectModelBase::index (row-1, 0, parent);
+                SKGNodeObject previousObject = getObject(previousIndex);
+                min=previousObject.getOrder();
             }
 
-            //Set order
-            if (err.isSucceeded())  err=child.setOrder((min+max)/2.0);
+            if (row>=rowCount(parent)) max=min+1;
+            else {
+                QModelIndex nextIndex=SKGObjectModelBase::index (row, 0, parent);
+                SKGNodeObject nextObject = getObject(nextIndex);
+                max=nextObject.getOrder();
+            }
+            if (max<=min) max=min+1;
 
-            //Save
-            if (err.isSucceeded()) err=child.save();
+            while (!stream.atEnd() && err.isSucceeded()) {
+                int o_id;
+                QString o_table;
+                stream >> o_table;
+                stream >> o_id;
+
+                //Set parent
+                SKGNodeObject child(getDocument(), o_id);
+                err=child.load();
+                if (err.isSucceeded()) {
+                    if (parent.isValid()) err=child.setParentNode(parentNode);
+                    else err=child.removeParentNode();
+                }
+
+                //Set order
+                if (err.isSucceeded())  err=child.setOrder((min+max)/2.0);
+
+                //Save
+                if (err.isSucceeded()) err=child.save();
+            }
         }
     }
-
     SKGMainPanel::displayErrorMessage(err);
     return err.isSucceeded();
 }
@@ -705,6 +752,5 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
     }
 }
 
-
 #include "skgobjectmodelbase.moc"
 
