@@ -278,7 +278,7 @@ public:
                               Qt::DropAction action,
                               int row, int column,
                               const QModelIndex &parent);
-signals:
+Q_SIGNALS:
     /**
      * Emitted before reset
      */
@@ -289,7 +289,7 @@ signals:
      */
     void afterReset();
 
-protected slots:
+protected Q_SLOTS:
     /**
      * This method is called by refresh to build the cache (to improve performance)
      */
