@@ -44,7 +44,7 @@ public:
      */
     virtual ~SKGTableWidget();
 
-signals:
+Q_SIGNALS:
     /**
      * Selected items must be removed
      */
