@@ -144,7 +144,7 @@ public:
      * Get the mode for the additional display
      * @return the mode
      */
-    virtual SKGTableWithGraph::DisplayAdditionalFlag getAdditionnalDisplayMode() const;
+    virtual SKGTableWithGraph::DisplayAdditionalFlag getAdditionalDisplayMode() const;
 
     /**
      * Get the table content
@@ -243,7 +243,7 @@ public:
      */
     virtual int getNbColumns(bool iWithComputed=false) const;
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted when a cell is double clicked
      * @param row row of the cell
@@ -251,7 +251,7 @@ signals:
      */
     void cellDoubleClicked ( int row, int column );
 
-private slots:
+private Q_SLOTS:
     void showTable();
     void showGraph();
     void showTableAndGraph();
