@@ -59,17 +59,23 @@ bool SKGTabPage::close()
 SKGObjectBase::SKGListSKGObjectBase SKGTabPage::getSelectedObjects()
 {
     SKGObjectBase::SKGListSKGObjectBase selection;
+
+    QWidget* widget=zoomableWidget();
+    SKGTreeView* treeView=dynamic_cast<SKGTreeView*>(widget);
+    if (treeView) selection=treeView->getSelectedObjects();
+
     return selection;
 }
 
 int SKGTabPage::getNbSelectedObjects()
 {
-    return getSelectedObjects().count();
-}
+    int output=0;
+    QWidget* widget=zoomableWidget();
+    SKGTreeView* treeView=dynamic_cast<SKGTreeView*>(widget);
+    if (treeView) output=treeView->getNbSelectedObjects();
+    else output=getSelectedObjects().count();
 
-QWidget* SKGTabPage::getWidgetForPrint()
-{
-    return this;
+    return output;
 }
 
 void SKGTabPage::setBookmarkID(const QString& iId)
@@ -220,9 +226,14 @@ bool SKGTabPage::isEditor()
 
 void SKGTabPage::activateEditor() {}
 
+QWidget* SKGTabPage::mainWidget() const
+{
+    return (QWidget*) this;
+}
+
 QWidget* SKGTabPage::zoomableWidget() const
 {
-    return NULL;
+    return mainWidget();
 }
 
 bool SKGTabPage::isZoomable() const
@@ -240,7 +251,7 @@ void SKGTabPage::setZoomPosition(int iValue)
         QWebView* webView=dynamic_cast<QWebView*>(widget);
         if (webView)
         {
-            webView->setZoomFactor(pow10(((qreal) iValue)/30.0));
+            webView->setZoomFactor(pow(10,((qreal) iValue)/30.0));
         }
         else if (widget)
         {
