@@ -76,12 +76,6 @@ public:
      */
     virtual int getNbSelectedObjects();
 
-    /**
-     * Get the widget must be printed
-     * @return a widget
-     */
-    virtual QWidget* getWidgetForPrint();
-
     /**
      * Set the bookmark id
      * @param iId bookmark id
@@ -141,6 +135,12 @@ public:
      */
     virtual void activateEditor();
 
+    /**
+     * Get the main widget
+     * @return a widget
+     */
+    virtual QWidget* mainWidget() const;
+
     /**
      * Get the zoomable widget. MUST BE OVERWRITTEN
      * By Overwritting this function, you don't have to implement following ones.
@@ -166,13 +166,13 @@ public:
      */
     virtual void setZoomPosition ( int iValue );
 
-signals:
+Q_SIGNALS:
     /**
      * This signal must be launched when the selection is modified
      */
     void selectionChanged();
 
-public slots:
+public Q_SLOTS:
     /**
      * Closes this widget
      * @return true if the widget was closed; otherwise returns false.
@@ -187,5 +187,9 @@ private:
     QList<SKGTabPage::SKGPageHistoryItem> nextPages;
     int fontOriginalPointSize;
 };
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGTabPage::SKGPageHistoryItem, Q_PRIMITIVE_TYPE );
 
 #endif // SKGTABPAGE_H
