@@ -50,14 +50,14 @@ public:
      */
     virtual ~SKGTabWidget();
 
-public slots:
+public Q_SLOTS:
     /**
      * Remove a tab
      * @param index the tab index
      */
     virtual void removeTab( int index );
 
-private slots:
+private Q_SLOTS:
     void onCurrentChanged();
     void onRefreshSaveIcon();
     void onSaveRequested();
