@@ -29,6 +29,7 @@
 #include "skgobjectbase.h"
 #include "skgmainpanel.h"
 
+#include <ksavefile.h>
 #include <kicon.h>
 #include <kmenu.h>
 #include <klocale.h>
@@ -50,8 +51,7 @@
 SKGTreeView::SKGTreeView ( QWidget *parent )
         : QTreeView ( parent ),
         autoResize ( true ), actAutoResize ( NULL ),
-        smoothScrolling ( false ), actSmoothScrolling ( NULL ),
-        document ( NULL )
+        document ( NULL ), textResizable(true)
 {
     //Delayed resize
     timerDelayedResize = new QTimer ( this );
@@ -81,13 +81,26 @@ SKGTreeView::SKGTreeView ( QWidget *parent )
     header()->setResizeMode ( QHeaderView::Fixed );
     setWordWrap ( false );
 
-    //By default Smooth scrolling is activated
-    switchSmoothScrolling();
-
     connect ( header(), SIGNAL ( sectionMoved ( int, int, int ) ), this, SLOT ( moveSection() ), Qt::QueuedConnection );
 
     connect ( this, SIGNAL ( collapsed ( QModelIndex ) ), this, SLOT ( onCollapse ( QModelIndex ) ), Qt::QueuedConnection );
     connect ( this, SIGNAL ( expanded ( QModelIndex ) ), this, SLOT ( onExpand ( QModelIndex ) ), Qt::QueuedConnection );
+
+    QAbstractScrollArea *scrollArea = dynamic_cast<QAbstractScrollArea*> ( this );
+    if ( scrollArea )
+    {
+        QWidget *viewport = scrollArea->viewport();
+        if ( viewport )
+        {
+            viewport->installEventFilter ( this );
+            scrollArea->installEventFilter ( this );
+        }
+    }
+
+    //Save original size
+    fontOriginalPointSize=this->font().pointSize();
+    iconOriginalSize=this->iconSize().height();
+    if (iconOriginalSize<=0) iconOriginalSize=16;
 }
 
 SKGTreeView::~SKGTreeView()
@@ -104,11 +117,6 @@ bool SKGTreeView::isAutoResized()
     return autoResize;
 }
 
-bool SKGTreeView::isSmoothScrolling()
-{
-    return smoothScrolling;
-}
-
 QString SKGTreeView::getState()
 {
     SKGTRACEIN ( 10, "SKGTreeView::getState" );
@@ -153,10 +161,10 @@ QString SKGTreeView::getState()
             if ( !autoResize ) root.setAttribute ( "columnsSize", columnsSize );
             root.setAttribute ( "columnsVisibility", columnsVisibility );
             root.setAttribute ( "columnsAutoResize", autoResize ? "Y" : "N" );
-            root.setAttribute ( "smoothScrolling", smoothScrolling ? "Y" : "N" );
         }
     }
     root.setAttribute ( "alternatingRowColors", alternatingRowColors() ? "Y" : "N" );
+    root.setAttribute ( "zoomPosition", SKGServices::intToString(zoomPosition()) );
     return doc.toString();
 }
 
@@ -178,6 +186,7 @@ void SKGTreeView::setState ( const QString& iState )
     QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> ( model );
     if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
 
+    Qt::SortOrder qtsortorder=Qt::AscendingOrder;
     if ( doc.setContent ( viewState ) )
     {
         QDomElement root = doc.documentElement();
@@ -188,8 +197,8 @@ void SKGTreeView::setState ( const QString& iState )
         QString columnsSize=root.attribute ( "columnsSize" );
         QString columnsVisibility=root.attribute ( "columnsVisibility" );
         QString columnsAutoResize=root.attribute ( "columnsAutoResize" );
-        QString smoothScrollings=root.attribute ( "smoothScrolling" );
         QString alternatingRowColors=root.attribute ( "alternatingRowColors" );
+        QString zoomPosition=root.attribute ( "zoomPosition" );
 
         //Set column order
         QStringList listAtt;
@@ -228,38 +237,50 @@ void SKGTreeView::setState ( const QString& iState )
             header()->setResizeMode ( autoResize ? QHeaderView::Fixed : QHeaderView::Interactive );
         }
 
-        //Set smoothScrolling
-        if ( !smoothScrollings.isEmpty() )
-        {
-            smoothScrolling= ( smoothScrollings=="N" ); //The next line will set the right value
-            switchSmoothScrolling();
-        }
-
         //Set sort
         if ( model && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty() )
         {
             int index=SKGServices::splitCSVLine ( columns, ';' ).indexOf ( sortColumn );
             if ( index==-1 ) index=model->getIndexAttribute ( sortColumn );
             if ( index==-1 ) index=0;
-            this->sortByColumn ( index, ( Qt::SortOrder ) SKGServices::stringToInt ( sortOrder ) );
+            qtsortorder=( Qt::SortOrder ) SKGServices::stringToInt ( sortOrder );
+            this->sortByColumn ( index, qtsortorder );
         }
 
         //Set alternatingRowColors
         if ( !alternatingRowColors.isEmpty() ) setAlternatingRowColors ( alternatingRowColors=="Y" );
+        if ( !zoomPosition.isEmpty() ) setZoomPosition(SKGServices::stringToInt(zoomPosition));
     }
     else
     {
-        QStringList listAtt;
         if ( model )
         {
-            model->setSupportedAttributes ( listAtt );
+            model->setSupportedAttributes ( QStringList() );
             model->refresh();
         }
 
-        this->sortByColumn ( 0, Qt::AscendingOrder );
+        this->sortByColumn ( 0, qtsortorder);
     }
 
     setupHeaderMenu();
+
+    if (qtsortorder==Qt::AscendingOrder) scrollToBottom();
+    else scrollToTop();
+}
+
+void SKGTreeView::insertGlobalAction(const QString& iRegisteredAction)
+{
+    if (iRegisteredAction.isEmpty())
+    {
+        QAction* sep=new QAction ( this );
+        sep->setSeparator ( true );
+        this->insertAction ( 0, sep );
+    }
+    else
+    {
+        KAction* act=SKGMainPanel::getMainPanel()->getGlobalAction ( iRegisteredAction );
+        this->insertAction ( 0, act );
+    }
 }
 
 void SKGTreeView::resizeColumnsToContentsDelayed()
@@ -272,10 +293,8 @@ void SKGTreeView::resizeColumnsToContents()
 {
     SKGTRACEIN ( 10, "SKGTreeView::resizeColumnsToContents" );
     int nb=header()->count();
-    for ( int i=0; i<nb; ++i )
-    {
+    for ( int i=nb-1; i>=0; --i )
         resizeColumnToContents ( i );
-    }
 }
 
 void SKGTreeView::showHeaderMenu ( const QPoint& pos )
@@ -283,9 +302,9 @@ void SKGTreeView::showHeaderMenu ( const QPoint& pos )
     if ( header_menu ) header_menu->popup ( header()->mapToGlobal ( pos ) );
 }
 
-void SKGTreeView::setDefaultSaveParameters ( const SKGDocument* iDocument, const QString& iParameterName )
+void SKGTreeView::setDefaultSaveParameters ( SKGDocument* iDocument, const QString& iParameterName )
 {
-    document= ( SKGDocument* ) iDocument;
+    document= iDocument;
     parameterName=iParameterName;
 }
 
@@ -339,20 +358,6 @@ void SKGTreeView::setupHeaderMenu ( bool iRefreshColumnSize )
         actAutoResize->setChecked ( autoResize );
         connect ( actAutoResize, SIGNAL ( triggered ( bool ) ), this, SLOT ( switchAutoResize() ) );
 
-        if ( model && model->supportedDragActions() ==Qt::IgnoreAction )
-        {
-            actSmoothScrolling = header_menu->addAction ( i18nc ("Noun, user action", "Smooth scrolling" ) );
-            actSmoothScrolling->setCheckable ( true );
-            actSmoothScrolling->setChecked ( smoothScrolling );
-            connect ( actSmoothScrolling, SIGNAL ( triggered ( bool ) ), this, SLOT ( switchSmoothScrolling() ) );
-        }
-        else
-        {
-            //Disable smooth scrolling
-            smoothScrolling=true;
-            switchSmoothScrolling();
-        }
-
         QAction* actAlternatingRowColors = header_menu->addAction ( i18nc ("Noun, user action", "Alternate row colors" ) );
         if ( actAlternatingRowColors )
         {
@@ -431,9 +436,9 @@ void SKGTreeView::onSelectionChanged()
 
 void SKGTreeView::saveDefaultClicked()
 {
-    SKGError err;
     if ( document )
     {
+        SKGError err;
         SKGBEGINTRANSACTION ( *document, i18nc("Noun, name of the user action", "Save default parameters" ), err );
         err=document->setParameter ( parameterName, getState() );
     }
@@ -446,39 +451,6 @@ void SKGTreeView::switchAutoResize()
     if ( autoResize ) resizeColumnsToContentsDelayed();
 }
 
-void SKGTreeView::switchSmoothScrolling()
-{
-    if ( actSmoothScrolling ) smoothScrolling=actSmoothScrolling->isChecked();
-    else smoothScrolling=!smoothScrolling;
-
-    QAbstractScrollArea *scrollArea = dynamic_cast<QAbstractScrollArea*> ( this );
-    if ( scrollArea )
-    {
-        QWidget *viewport = scrollArea->viewport();
-        if ( viewport )
-        {
-            if ( smoothScrolling )
-            {
-                viewport->installEventFilter ( this );
-                scrollArea->installEventFilter ( this );
-
-                state = SKGTreeView::Steady;
-
-                setVerticalScrollMode ( QAbstractItemView::ScrollPerPixel );
-                setHorizontalScrollMode ( QAbstractItemView::ScrollPerPixel );
-            }
-            else
-            {
-                viewport->removeEventFilter ( this );
-                scrollArea->removeEventFilter ( this );
-
-                setVerticalScrollMode ( QAbstractItemView::ScrollPerItem );
-                setHorizontalScrollMode ( QAbstractItemView::ScrollPerItem );
-            }
-        }
-    }
-}
-
 void SKGTreeView::showHideColumn()
 {
     QAction* sender=static_cast<QAction*> ( this->sender() );
@@ -488,6 +460,7 @@ void SKGTreeView::showHideColumn()
 
         int idx=sender->data().toInt();
         hHeader->setSectionHidden ( idx, !hHeader->isSectionHidden ( idx ) );
+        resizeColumnToContents ( idx );
     }
 }
 
@@ -579,6 +552,7 @@ void SKGTreeView::saveSelection()
             selection.push_back ( id );
         }
     }
+    SKGTRACEL(10) << selection.count() << " objects saved" << endl;
 }
 
 void SKGTreeView::selectObject ( const QString& iUniqueID )
@@ -592,6 +566,7 @@ void SKGTreeView::selectObject ( const QString& iUniqueID )
 void SKGTreeView::selectObjects ( const QStringList& iUniqueIDs, bool iFocusOnFirstOne )
 {
     SKGTRACEIN ( 10, "SKGTreeView::selectObjects" );
+    int nbset=0;
     QItemSelectionModel *selModel=selectionModel();
     if ( selModel )
     {
@@ -605,19 +580,19 @@ void SKGTreeView::selectObjects ( const QStringList& iUniqueIDs, bool iFocusOnFi
 
         if ( model )
         {
-	    //Get all indexes
-	    QList<QModelIndex> items;
-	    items.push_back(QModelIndex());
-	    for(int i=0; i<items.count(); ++i) //Dynamic size because the list is modified
-	    {
-	      QModelIndex mi=items.at(i);
-	      int nbRows=model->rowCount (mi  );
-	      for ( int j=0; j<nbRows; ++j )
-	      {
-		items.push_back(model->index ( j, 0, mi ));
-	      }
-	    }
-	    items.removeAt(0);
+            //Get all indexes
+            QList<QModelIndex> items;
+            items.push_back(QModelIndex());
+            for (int i=0; i<items.count(); ++i) //Dynamic size because the list is modified
+            {
+                QModelIndex mi=items.at(i);
+                int nbRows=model->rowCount (mi  );
+                for ( int j=0; j<nbRows; ++j )
+                {
+                    items.push_back(model->index ( j, 0, mi ));
+                }
+            }
+            items.removeAt(0);
 
             int nbRows=items.count();
             if ( nbRows )
@@ -639,7 +614,7 @@ void SKGTreeView::selectObjects ( const QStringList& iUniqueIDs, bool iFocusOnFi
                 }
 
                 //Set selection
-		bool focusDone=false;
+                bool focusDone=false;
                 foreach ( const QString& sel, iUniqueIDs )
                 {
                     for ( int i=0; i<nbRows; ++i )
@@ -650,6 +625,7 @@ void SKGTreeView::selectObjects ( const QStringList& iUniqueIDs, bool iFocusOnFi
                         {
                             QModelIndex idxs= ( proxyModel ? proxyModel->mapFromSource ( index ) : index );
                             selModel->select ( idxs, QItemSelectionModel::Select|QItemSelectionModel::Rows );
+                            ++nbset;
                             if ( iFocusOnFirstOne && !focusDone )
                             {
                                 scrollTo ( idxs );
@@ -662,8 +638,10 @@ void SKGTreeView::selectObjects ( const QStringList& iUniqueIDs, bool iFocusOnFi
             }
         }
         selModel->blockSignals ( previous );
-        // selModel->emit selectionChanged ( QItemSelection(), QItemSelection() );
     }
+
+    SKGTRACEL(10) << iUniqueIDs.count() << " objects to select" << endl;
+    SKGTRACEL(10) << nbset << " objects selected" << endl;
 }
 
 void SKGTreeView::resetSelection()
@@ -675,7 +653,7 @@ void SKGTreeView::resetSelection()
 
 void SKGTreeView::onSortChanged ()
 {
-      if ( timerScrollSelection ) timerScrollSelection->start ( 300 );
+    if ( timerScrollSelection ) timerScrollSelection->start ( 300 );
 }
 
 void SKGTreeView::scroolOnSelection ()
@@ -691,7 +669,7 @@ void SKGTreeView::scroolOnSelection ()
         if ( model )
         {
             QModelIndexList indexes=selModel->selectedRows();
-	    if(indexes.count()) scrollTo ( indexes.at(0) );
+            if (indexes.count()) scrollTo ( indexes.at(0) );
         }
     }
 }
@@ -701,13 +679,13 @@ void SKGTreeView::onExpand ( const QModelIndex & index )
     SKGObjectModelBase* model= ( SKGObjectModelBase* ) this->model();
     QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> ( model );
     if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
-    if(model)
+    if (model)
     {
-      QModelIndex idxs= ( proxyModel ? proxyModel->mapToSource ( index ) : index );
+        QModelIndex idxs= ( proxyModel ? proxyModel->mapToSource ( index ) : index );
 
-      SKGObjectBase obj=model->getObject ( idxs );
-      QString id=obj.getUniqueID();
-      expandedNodes.push_back ( id );
+        SKGObjectBase obj=model->getObject ( idxs );
+        QString id=obj.getUniqueID();
+        expandedNodes.push_back ( id );
     }
 }
 
@@ -716,64 +694,41 @@ void SKGTreeView::onCollapse ( const QModelIndex & index )
     SKGObjectModelBase* model= ( SKGObjectModelBase* ) this->model();
     QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> ( model );
     if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
-    if(model)
+    if (model)
     {
-      QModelIndex idxs= ( proxyModel ? proxyModel->mapToSource ( index ) : index );
+        QModelIndex idxs= ( proxyModel ? proxyModel->mapToSource ( index ) : index );
 
-      SKGObjectBase obj=model->getObject ( idxs );
+        SKGObjectBase obj=model->getObject ( idxs );
 
-      QString id=obj.getUniqueID();
-      expandedNodes.removeOne ( id );
+        QString id=obj.getUniqueID();
+        expandedNodes.removeOne ( id );
     }
 }
 
-/**
- * Get scroll offset
- * @param widget the widget
- * @return the offset
- */
-static QPoint scrollOffset ( QWidget *widget )
+void SKGTreeView::setZoomPosition(int iZoomPosition)
 {
-    int x = 0, y = 0;
-
-    QAbstractScrollArea *scrollArea = dynamic_cast<QAbstractScrollArea*> ( widget );
-    if ( scrollArea )
+    int newZoomPos=qMax(qMin(iZoomPosition, 10), -10);
+    if (newZoomPos!=zoomPosition() && fontOriginalPointSize+newZoomPos>1)
     {
-        x = scrollArea->horizontalScrollBar()->value();
-        y = scrollArea->verticalScrollBar()->value();
-    }
+        QFont font = this->font();
+        font.setPointSize( fontOriginalPointSize+newZoomPos);
+        int iconSize=qMax(iconOriginalSize + newZoomPos, 1);
 
-    return QPoint ( x, y );
-}
-/**
- * Set scroll offset
- * @param widget the widget
- * @param p the point
- */
-static void setScrollOffset ( QWidget *widget, const QPoint &p )
-{
-    QAbstractScrollArea *scrollArea = dynamic_cast<QAbstractScrollArea*> ( widget );
-    if ( scrollArea )
-    {
-        scrollArea->horizontalScrollBar()->setValue ( p.x() );
-        scrollArea->verticalScrollBar()->setValue ( p.y() );
+        this->setFont( font );
+        this->setIconSize(QSize(iconSize, iconSize));
+        this->header()->setIconSize(QSize(iconSize, iconSize));
+
+        if ( autoResize ) resizeColumnsToContentsDelayed();
+
+        Q_EMIT zoomChanged(newZoomPos);
     }
 }
-/**
- * Deaccelerate
- * @param speed speed
- * @param a a
- * @param max max speed
- * @return point
- */
-static QPoint deaccelerate ( const QPoint &speed, int a = 1, int max = 64 )
+
+int SKGTreeView::zoomPosition() const
 {
-    int x = qBound ( -max, speed.x(), max );
-    int y = qBound ( -max, speed.y(), max );
-    x = ( x == 0 ) ? x : ( x > 0 ) ? qMax ( 0, x - a ) : qMin ( 0, x + a );
-    y = ( y == 0 ) ? y : ( y > 0 ) ? qMax ( 0, y - a ) : qMin ( 0, y + a );
-    return QPoint ( x, y );
+    return this->font().pointSize()-fontOriginalPointSize;
 }
+
 /**
  * Event filter
  * @param object object
@@ -782,149 +737,40 @@ static QPoint deaccelerate ( const QPoint &speed, int a = 1, int max = 64 )
  */
 bool SKGTreeView::eventFilter ( QObject *object, QEvent *event )
 {
-    if ( !event || !object ) return false;
-    QEvent::Type type = event->type();
-    if ( type != QEvent::MouseButtonPress &&
-         type != QEvent::MouseButtonRelease &&
-         type != QEvent::MouseMove )
-        return false;
-
-    QMouseEvent *mouseEvent = dynamic_cast<QMouseEvent*> ( event );
-    if ( !mouseEvent || mouseEvent->modifiers() != Qt::NoModifier )
-        return false;
-
-    QWidget *viewport = dynamic_cast<QWidget*> ( object );
-    if ( !viewport || this->ignored.removeAll ( event ) )
-        return false;
-
-    bool consumed = false;
-    switch ( this->state )
+    QWheelEvent* e=dynamic_cast<QWheelEvent*> ( event );
+    if ( textResizable && e && e->orientation() == Qt::Vertical && QApplication::keyboardModifiers() &Qt::ControlModifier )
     {
+        int numDegrees = e->delta() / 8;
+        int numTicks = numDegrees / 15;
 
-    case SKGTreeView::Steady:
-        if ( mouseEvent->type() == QEvent::MouseButtonPress )
-            if ( mouseEvent->buttons() == Qt::LeftButton )
-            {
-                consumed = true;
-                this->state = SKGTreeView::Pressed;
-                this->pressPos = mouseEvent->pos();
-                this->offset = scrollOffset ( this );
-            }
-        break;
-
-    case SKGTreeView::Pressed:
-        if ( mouseEvent->type() == QEvent::MouseButtonRelease )
-        {
-            consumed = true;
-            this->state = SKGTreeView::Steady;
-
-            QMouseEvent *event1 = new QMouseEvent ( QEvent::MouseButtonPress,
-                                                    this->pressPos, Qt::LeftButton,
-                                                    Qt::LeftButton, Qt::NoModifier );
-            QMouseEvent *event2 = new QMouseEvent ( *mouseEvent );
-
-            this->ignored << event1;
-            this->ignored << event2;
-            QApplication::postEvent ( object, event1 );
-            QApplication::postEvent ( object, event2 );
-        }
-        if ( mouseEvent->type() == QEvent::MouseMove )
-        {
-            consumed = true;
-            this->state = SKGTreeView::ManualScroll;
-            this->dragPos = QCursor::pos();
-            if ( !this->ticker.isActive() )
-                this->ticker.start ( 20, this );
-        }
-        break;
-
-    case SKGTreeView::ManualScroll:
-        if ( mouseEvent->type() == QEvent::MouseMove )
-        {
-            consumed = true;
-            QPoint delta = mouseEvent->pos() - this->pressPos;
-            setScrollOffset ( this, this->offset - delta );
-        }
-        if ( mouseEvent->type() == QEvent::MouseButtonRelease )
-        {
-            consumed = true;
-            this->state = SKGTreeView::AutoScroll;
-        }
-        break;
-
-    case SKGTreeView::AutoScroll:
-        if ( mouseEvent->type() == QEvent::MouseButtonPress )
-        {
-            consumed = true;
-            this->state = SKGTreeView::Stop;
-            this->speed = QPoint ( 0, 0 );
-        }
-        if ( mouseEvent->type() == QEvent::MouseButtonRelease )
-        {
-            consumed = true;
-            this->state = SKGTreeView::Steady;
-            this->speed = QPoint ( 0, 0 );
-        }
-        break;
-
-    case SKGTreeView::Stop:
-        if ( mouseEvent->type() == QEvent::MouseButtonRelease )
-        {
-            consumed = true;
-            this->state = SKGTreeView::Steady;
-        }
-        if ( mouseEvent->type() == QEvent::MouseMove )
-        {
-            consumed = true;
-            this->state = SKGTreeView::ManualScroll;
-            this->dragPos = QCursor::pos();
-            if ( !this->ticker.isActive() )
-                this->ticker.start ( 20, this );
-        }
-        break;
-
-    default:
-        break;
+        setZoomPosition(zoomPosition()+( numTicks >0 ? 1 : -1));
+        e->setAccepted ( true );
+        return true;
     }
 
-    return consumed;
-}
-
-void SKGTreeView::timerEvent ( QTimerEvent *event )
-{
-    int count = 0;
-    if ( this->state == SKGTreeView::ManualScroll )
-    {
-        count++;
-        this->speed = QCursor::pos() - this->dragPos;
-        this->dragPos = QCursor::pos();
-    }
-
-    if ( this->state == SKGTreeView::AutoScroll )
-    {
-        count++;
-        this->speed = deaccelerate ( this->speed );
-        QPoint p = scrollOffset ( this );
-        setScrollOffset ( this, p - this->speed );
-        if ( this->speed == QPoint ( 0, 0 ) )
-            this->state = SKGTreeView::Steady;
-    }
-
-    if ( !count ) this->ticker.stop();
-
-    QTreeView::timerEvent ( event );
+    return QTreeView::eventFilter(object, event);
 }
 
 void SKGTreeView::mousePressEvent ( QMouseEvent * event )
 {
     if ( event && event->button() ==Qt::LeftButton && ! ( this->indexAt ( event->pos() ).isValid() ) )
     {
-        emit clickEmptyArea();
+        Q_EMIT clickEmptyArea();
         clearSelection();
     }
     QTreeView::mousePressEvent ( event );
 }
 
+bool SKGTreeView::isTextResizable() const
+{
+    return textResizable;
+}
+
+void SKGTreeView::setTextResizable(bool resizable)
+{
+    textResizable=resizable;
+}
+
 SKGStringListList SKGTreeView::getTable()
 {
     //Build table
@@ -934,30 +780,30 @@ SKGStringListList SKGTreeView::getTable()
     SKGObjectModelBase* model= ( SKGObjectModelBase* ) this->model();
     QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> ( model );
     if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
-    if(model)
+    if (model)
     {
-      int nb=model->columnCount();
-      QStringList cols;
-      for ( int i=0; i<nb; i++ )
-      {
-	  cols.append ( model->headerData ( i,Qt::Horizontal, Qt::UserRole ).toString().split ( '|' ).at ( 0 ) );
-      }
-      table.append ( cols );
+        int nb=model->columnCount();
+        QStringList cols;
+        for ( int i=0; i<nb; i++ )
+        {
+            cols.append ( model->headerData ( i,Qt::Horizontal, Qt::UserRole ).toString().split ( '|' ).at ( 0 ) );
+        }
+        table.append ( cols );
 
-      //Get content
-      int nb2=model->rowCount();
-      for ( int i=0; i<nb2; i++ )
-      {
-	  QStringList row;
-	  for ( int j=0; j<nb; j++ )
-	  {
-	      //We have to check the type for 214849
-	      SKGServices::AttributeType type=model->getAttributeType (j);
-	      QString display=model->data ( model->index ( i,j ), type==SKGServices::FLOAT ?  Qt::DisplayRole : Qt::UserRole ).toString();
-	      row.append ( display );
-	  }
-	  table.append ( row );
-      }
+        //Get content
+        int nb2=model->rowCount();
+        for ( int i=0; i<nb2; i++ )
+        {
+            QStringList row;
+            for ( int j=0; j<nb; j++ )
+            {
+                //We have to check the type for 214849
+                SKGServices::AttributeType type=model->getAttributeType (j);
+                QString display=model->data ( model->index ( i,j ), type==SKGServices::FLOAT ?  Qt::DisplayRole : Qt::UserRole ).toString();
+                row.append ( display );
+            }
+            table.append ( row );
+        }
     }
     return table;
 }
@@ -971,11 +817,11 @@ void SKGTreeView::onExportCSV()
         SKGError err;
 
         //Write file
-        QFile file ( fileName );
-        if ( !file.open ( QIODevice::WriteOnly | QIODevice::Text ) )
+        KSaveFile file ( fileName );
+        if ( !file.open () )
         {
             err.setReturnCode ( ERR_INVALIDARG );
-            err.setMessage ( i18nc("Error message",  "Save file [%1] failed" , fileName ) );
+            err.setMessage ( i18nc("Error message",  "Save file '%1' failed" , fileName ) );
         }
         else
         {
@@ -989,9 +835,10 @@ void SKGTreeView::onExportCSV()
         }
 
         //Close file
-        file.flush();
+        file.finalize();
         file.close();
 
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
     }
     QDesktopServices::openUrl ( QUrl ( fileName ) );
 }
@@ -1001,31 +848,33 @@ void SKGTreeView::onExportTXT()
     _SKGTRACEIN ( 10, "SKGTreeView::onExportTXT" );
     QString fileName=SKGMainPanel::getSaveFileName ( KUrl ( "kfiledialog:///IMPEXP" ), "*.txt|"+i18nc ("File format", "Text document" ) , this );
     if ( fileName.isEmpty() ) return;
-
-    SKGError err;
-
-    //Write file
-    QFile file ( fileName );
-    if ( !file.open ( QIODevice::WriteOnly | QIODevice::Text ) )
     {
-        err.setReturnCode ( ERR_INVALIDARG );
-        err.setMessage ( i18nc("Error message",  "Save file [%1] failed" , fileName ) );
-    }
-    else
-    {
-        QTextStream out ( &file );
-        QStringList dump=SKGServices::tableToDump ( getTable(), SKGServices::DUMP_TEXT );
-        int nbl=dump.count();
-        for ( int i=0; i<nbl; ++i )
+        SKGError err;
+
+        //Write file
+        KSaveFile file ( fileName );
+        if ( !file.open () )
         {
-            out << dump[i] << endl;
+            err.setReturnCode ( ERR_INVALIDARG );
+            err.setMessage ( i18nc("Error message",  "Save file '%1' failed" , fileName ) );
         }
+        else
+        {
+            QTextStream out ( &file );
+            QStringList dump=SKGServices::tableToDump ( getTable(), SKGServices::DUMP_TEXT );
+            int nbl=dump.count();
+            for ( int i=0; i<nbl; ++i )
+            {
+                out << dump[i] << endl;
+            }
+        }
+
+        //Close file
+        file.finalize();
+        file.close();
+
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
     }
-
-    //Close file
-    file.flush();
-    file.close();
-
     QDesktopServices::openUrl ( QUrl ( fileName ) );
 }
 
