@@ -119,13 +119,13 @@ public:
     virtual void setSelectionModel ( QItemSelectionModel * selectionModel );
 
     /**
-     * Insert a registed action
+     * Insert a registered action
      * @see SKGMainPanel::registedGlobalAction
-     * @param iRegisteredAction the registed action. "" means separator
+     * @param iRegisteredAction the registered action. "" means separator
      */
     virtual void insertGlobalAction(const QString& iRegisteredAction="");
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted when the empty area
      */
@@ -151,7 +151,7 @@ protected:
      */
     virtual void mousePressEvent ( QMouseEvent * event );
 
-public slots:
+public Q_SLOTS:
     /**
      * This property holds whether to autorize text size modification by CTRL+wheel.
      * @param resizable true of false
@@ -235,7 +235,7 @@ protected:
       */
     virtual bool eventFilter ( QObject *object, QEvent *event );
 
-private slots:
+private Q_SLOTS:
     void onExportPDF();
     void onExportCSV();
     void onExportTXT();
