@@ -55,4 +55,11 @@ void SKGWidget::setState(const QString& /*iState*/ )
 {
 }
 
+QWidget* SKGWidget::getDragWidget()
+{
+    QWidget* w=this->findChild<QWidget*>("kGroup");
+    if (!w) w=this;
+    return w;
+}
+
 #include "skgwidget.moc"
