@@ -29,7 +29,7 @@
 class SKGTESTDateEdit: public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void Test();
     void Test_data();
 };
