@@ -28,8 +28,8 @@
  */
 class SKGTESTWidgetCollection: public QObject
 {
-        Q_OBJECT
-private slots:
-        void Test();
+    Q_OBJECT
+private Q_SLOTS:
+    void Test();
 };
 #endif
