@@ -27,7 +27,7 @@
 
 #include <klocale.h>
 #include <kicon.h>
-#include <kio/netaccess.h>
+#include <kurl.h>
 
 #include <QSqlDatabase>
 #include <QSqlQuery>
@@ -294,17 +294,17 @@ SKGError SKGDocument::endTransaction(bool succeedded)
                     //Emit modification events
                     QStringList tablesRefreshed;
                     foreach (const QString& table, listModifiedTables) {
-                        emit tableModified(table, getCurrentTransaction());
+                        Q_EMIT tableModified(table, getCurrentTransaction());
                         tablesRefreshed.push_back(table);
                     }
-                    emit tableModified("doctransaction", getCurrentTransaction());
-                    emit tableModified("doctransactionitem", getCurrentTransaction());
+                    Q_EMIT tableModified("doctransaction", getCurrentTransaction());
+                    Q_EMIT tableModified("doctransactionitem", getCurrentTransaction());
 
                     //WARNING: list is modified during treatement
                     for (int i=0; i<listModifiedTables.count(); ++i) {
                         QString table=listModifiedTables[i];
                         if (!tablesRefreshed.contains(table)) {
-                            emit tableModified(table, 0);
+                            Q_EMIT tableModified(table, 0);
                             tablesRefreshed.push_back(table);
                         }
 
@@ -316,7 +316,7 @@ SKGError SKGDocument::endTransaction(bool succeedded)
                         }
                     }
 
-                    emit transactionSuccessfullyEnded(getCurrentTransaction());
+                    Q_EMIT transactionSuccessfullyEnded(getCurrentTransaction());
 
                     //Remove temporary transaction if needed
                     err = SKGServices::executeSqliteOrder(this, "delete from doctransaction where id="+currentTransactionString+" and t_name='#INTERNAL#';");
@@ -734,9 +734,35 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
             //Temporary file
             temporaryFile=SKGDocument::getTemporaryFile(name);
             if (!restoreTmpFile) {
-                KIO::NetAccess::del(KUrl(temporaryFile), NULL); //Must must remove it to be able to copy
+                QFile::remove(temporaryFile); //Must must remove it to be able to copy
                 err=SKGServices::cryptFile(name, temporaryFile, password, false, getDocumentHeader());
             }
+            else
+            {
+                //BUG 249955: Check if password protected vvv
+                //Temporary file will be loaded but first we must check if original document is password protected
+                QString temporaryFile2=temporaryFile+'2';
+                err=SKGServices::cryptFile(name, temporaryFile2, password, false, getDocumentHeader());
+
+                //Try an open to check if well descrypted
+                if (err.isSucceeded())
+                {
+                    QSqlDatabase tryOpen(QSqlDatabase::addDatabase("QSQLITE", "tryOpen"));
+                    tryOpen.setDatabaseName(temporaryFile2);
+                    if (!tryOpen.open()) {
+                        //Set error message
+                        QSqlError sqlErr=currentDatabase->lastError();
+                        err = SKGError(SQLLITEERROR + sqlErr.number(), sqlErr.text());
+                    }
+                    if (err.isSucceeded()) err = SKGServices::executeSqliteOrder(&tryOpen, "PRAGMA synchronous = OFF");
+                }
+                QSqlDatabase::removeDatabase("tryOpen");
+                QFile::remove(temporaryFile2);
+
+                //To avoid deletion of temporary file during next try
+                if (err.isFailed()) temporaryFile="";
+                //BUG 249955: Check if password protected ^^^
+            }
 
             //Create file database
             if (err.isSucceeded())
@@ -862,7 +888,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
     } else {
         //Send event
         uniqueIdentifier=QUuid::createUuid ().toString();
-        emit tableModified("", 0);
+        Q_EMIT tableModified("", 0);
     }
 
     return err;
@@ -921,7 +947,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                                                   "NOT EXISTS(select 1 from doctransaction B where B.i_parent=A.id) "
                                                   "and A.t_mode='U')");
         }
-        emit tableModified("doctransaction", 0);
+        Q_EMIT tableModified("doctransaction", 0);
 
         //Optimization
         if (err.isSucceeded()) {
@@ -956,7 +982,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
 
                         //Copy memory to tmp db
                         if (!directAccessDb && err.isSucceeded()) {
-                            KIO::NetAccess::del(KUrl(temporaryFile), NULL);
+                            QFile::remove(temporaryFile);
                             QSqlDatabase* fileDb=new QSqlDatabase(QSqlDatabase::addDatabase("QSQLITE", databaseIdentifier+"_tmp"));
                             fileDb->setDatabaseName(temporaryFile);
                             if (!fileDb->open()) {
@@ -1030,8 +1056,8 @@ SKGError SKGDocument::close()
 
     //Send event
     if (emitEvent) {
-        emit tableModified("", 0);
-        emit transactionSuccessfullyEnded(0);
+        Q_EMIT tableModified("", 0);
+        Q_EMIT transactionSuccessfullyEnded(0);
     }
 
     return err;
@@ -1451,11 +1477,13 @@ SKGError SKGDocument::createUndoRedoTemporaryTriggers()
     return err;
 }
 
-QStringList SKGDocument::getParameters(const QString& iParentUUID)
+QStringList SKGDocument::getParameters(const QString& iParentUUID, const QString& iWhereClause)
 {
     SKGTRACEIN(10, "SKGDocument::getParameters");
     QStringList output;
-    SKGServices::getDistinctValues(this, "parameters", "t_name", "t_uuid_parent='"+SKGServices::stringToSqlString(iParentUUID)+'\'', output);
+    QString wc="t_uuid_parent='"+SKGServices::stringToSqlString(iParentUUID)+'\'';
+    if (!iWhereClause.isEmpty()) wc+=" AND ("+iWhereClause+')';
+    SKGServices::getDistinctValues(this, "parameters", "t_name", wc, output);
     return output;
 }
 
@@ -1497,12 +1525,52 @@ QVariant SKGDocument::getParameterBlob(const QString& iName, const QString& iPar
     return output;
 }
 
+SKGError SKGDocument::setParameter(const QString& iName, const QString& iValue, const QString& iFileName, const QString& iParentUUID, SKGPropertyObject* oObjectCreated)
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGDocument::setParameter", err);
+    SKGTRACEL(10) << "Input parameter [iName]    =[" << iName << ']' << endl;
+    SKGTRACEL(10) << "Input parameter [iValue]   =[" << iValue << ']' << endl;
+    SKGTRACEL(10) << "Input parameter [iFileName]=[" << iFileName << ']' << endl;
+    QVariant blob;
+    QString value=iValue;
+    QFile file(iFileName);
+    if (file.exists()) {
+        QFileInfo fileInfo(iFileName);
+        if (fileInfo.isDir())
+        {
+            value="file://"+iFileName;
+        }
+        else
+        {
+            //Open file
+            if (!file.open(QIODevice::ReadOnly)) {
+                err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Open file '%1' failed", iFileName));
+            } else {
+                QByteArray blob_bytes=file.readAll();
+                if (!blob_bytes.count()) {
+                    err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Open file '%1' failed", iFileName));
+                } else {
+                    blob=blob_bytes;
+                    value=fileInfo.fileName();
+                }
+
+                //close file
+                file.close();
+            }
+        }
+    }
+
+    if (err.isSucceeded()) err=setParameter(iName, value, blob, iParentUUID, oObjectCreated);
+    return err;
+}
+
 SKGError SKGDocument::setParameter(const QString& iName, const QString& iValue, const QVariant& iBlob, const QString& iParentUUID, SKGPropertyObject* oObjectCreated)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGDocument::setParameter", err);
-    SKGTRACEL(10) << "Input parameter [iName]=[" << iName << ']' << endl;
-    SKGTRACEL(10) << "Input parameter [iValue]=[" << iValue << ']' << endl;
+    SKGTRACEL(10) << "Input parameter [iName]    =[" << iName << ']' << endl;
+    SKGTRACEL(10) << "Input parameter [iValue]   =[" << iValue << ']' << endl;
 
     SKGPropertyObject param(this);
     if (err.isSucceeded()) err = param.setName(iName);
