@@ -41,7 +41,7 @@ class SKGPropertyObject;
 class SKGBASEMODELER_EXPORT SKGDocument : public QObject
 {
     Q_OBJECT;
-    Q_CLASSINFO("D-Bus Interface", "org.skg.SKGDocument")
+    Q_CLASSINFO("D-Bus Interface", "org.skg.SKGDocument");
 
     /**
      * This enumerate defines a type of modification
@@ -126,7 +126,7 @@ public:
      */
     virtual SKGError setProgressCallback(int (*iProgressFunction)(int, void*), void* iData=NULL);
 
-public slots:
+public Q_SLOTS:
     /**
      * Get unique identifier
      * @return the unique identifier
@@ -343,9 +343,10 @@ public slots:
     /**
      * Get the list of parameters
      * @param iParentUUID the unique identifier of the object owning parameters.
+     * @param iWhereClause the additional where clause.
      * @return the list of parameters.
      */
-    virtual QStringList getParameters(const QString& iParentUUID);
+    virtual QStringList getParameters(const QString& iParentUUID, const QString& iWhereClause="");
 
     /**
      * Get a parameter value
@@ -363,6 +364,21 @@ public slots:
      */
     virtual QVariant getParameterBlob(const QString& iName, const QString& iParentUUID="document");
 
+    /**
+     * Set a parameter.
+     * WARNING: This method must be used in a transaction.
+     * @see beginTransaction
+     * @param iName the parameter unique identifier.
+     * @param iValue the parameter value.
+     * @param iFileName the file name.
+     * @param iParentUUID the unique identifier of the object owning this parameter.
+     * @param oObjectCreated the parameter object created
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError setParameter(const QString& iName, const QString& iValue, const QString& iFileName,
+                                  const QString& iParentUUID="document", SKGPropertyObject* oObjectCreated=NULL);
+
     /**
      * Set a parameter.
      * WARNING: This method must be used in a transaction.
@@ -503,7 +519,7 @@ public slots:
      */
     virtual QString getDocumentHeader() const;
 
-signals:
+Q_SIGNALS:
     /**
      * This signal is launched by endTransaction on all tables modified when a huge modification occures on the model
      * @param iTableName the name of the modified table. iTableName="" if all tables must be refreshed
@@ -598,5 +614,8 @@ private:
     QString backupSuffix;
     bool directAccessDb;
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGDocument::SKGModelTemplate, Q_PRIMITIVE_TYPE );
 #endif
