@@ -21,25 +21,25 @@
  */
 #include "skgnamedobject.h"
 
-SKGNamedObject::SKGNamedObject(const SKGDocument* iDocument, const QString& iTable, int iID)
-                : SKGObjectBase(iDocument, iTable, iID)
+SKGNamedObject::SKGNamedObject(SKGDocument* iDocument, const QString& iTable, int iID)
+        : SKGObjectBase(iDocument, iTable, iID)
 {
 }
 
 SKGNamedObject::SKGNamedObject(const SKGNamedObject& iObject)
-                : SKGObjectBase(iObject)
+        : SKGObjectBase(iObject)
 {
 }
 
 SKGNamedObject::SKGNamedObject(const SKGObjectBase& iObject)
-                : SKGObjectBase(iObject)
+        : SKGObjectBase(iObject)
 {
 }
 
 const SKGNamedObject& SKGNamedObject::operator= (const SKGObjectBase& iObject)
 {
-		copyFrom(iObject);
-		return *this;
+    copyFrom(iObject);
+    return *this;
 }
 
 SKGNamedObject::~SKGNamedObject()
@@ -48,31 +48,31 @@ SKGNamedObject::~SKGNamedObject()
 
 SKGError SKGNamedObject::setName(const QString& iName)
 {
-        return setAttribute("t_name", iName);
+    return setAttribute("t_name", iName);
 }
 
 QString SKGNamedObject::getName() const
 {
-        return getAttribute("t_name");
+    return getAttribute("t_name");
 }
 
 QString SKGNamedObject::getWhereclauseId() const
 {
-        //Could we use the id
-        QString output = SKGObjectBase::getWhereclauseId();
-        if (output.isEmpty()) {
-                //No, so we use the name
-                QString name = SKGServices::stringToSqlString(getName());
-                if (!name.isEmpty()) {
-                        output = "t_name='"+name+'\'';
-                }
+    //Could we use the id
+    QString output = SKGObjectBase::getWhereclauseId();
+    if (output.isEmpty()) {
+        //No, so we use the name
+        QString name = SKGServices::stringToSqlString(getName());
+        if (!name.isEmpty()) {
+            output = "t_name='"+name+'\'';
         }
-        return output;
+    }
+    return output;
 }
 
-SKGError SKGNamedObject::getObjectByName(const SKGDocument* iDocument, const QString& iTable, const QString& iName, SKGObjectBase& oObject)
+SKGError SKGNamedObject::getObjectByName(SKGDocument* iDocument, const QString& iTable, const QString& iName, SKGObjectBase& oObject)
 {
-        return getObject(iDocument, iTable, "t_name='"+SKGServices::stringToSqlString(iName)+'\'', oObject);
+    return getObject(iDocument, iTable, "t_name='"+SKGServices::stringToSqlString(iName)+'\'', oObject);
 }
 
 #include "skgnamedobject.moc"
