@@ -106,5 +106,8 @@ protected:
      */
     virtual QString getWhereclauseId() const;
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGNamedObject, Q_MOVABLE_TYPE );
 #endif
