@@ -24,6 +24,7 @@
 #include "skgdefine.h"
 
 #include <klocale.h>
+#include <kicon.h>
 
 SKGNodeObject::SKGNodeObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, "v_node", iID)
 {
@@ -87,6 +88,27 @@ QString SKGNodeObject::getData() const
     return getAttribute("t_data");
 }
 
+bool SKGNodeObject::isFolder() const
+{
+    return (SKGServices::splitCSVLine(getData()).count()<=2);
+}
+
+QIcon SKGNodeObject::getIcon() const
+{
+    QStringList data=SKGServices::splitCSVLine(getData());
+    QIcon icon=KIcon("folder");
+    if (data.count()>2)  icon=(QIcon) KIcon(data.at(2));
+
+    if (isAutoStart()) {
+        //Modify icon
+        QStringList overlay;
+        overlay.push_back("user-online");
+        if (data.count()>2)  icon=(QIcon) KIcon(data.at(2), NULL, overlay);
+        else icon=(QIcon) KIcon("folder", NULL, overlay);
+    }
+    return icon;
+}
+
 SKGError SKGNodeObject::setAutoStart(bool iAutoStart)
 {
     return setAttribute("t_autostart", iAutoStart ? "Y" : "N");
