@@ -180,6 +180,18 @@ public:
      */
     virtual QString getData() const;
 
+    /**
+     * To know if the node is a folder or not
+     * @return true of false
+     */
+    virtual bool isFolder() const;
+
+    /**
+     * Get icon of this node
+     * @return the icon
+     */
+    virtual QIcon getIcon() const;
+
     /**
      * Set autostart mode of this node
      * @param iAutoStart the autostart mode
@@ -202,5 +214,8 @@ protected:
      */
     virtual QString getWhereclauseId() const;
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGNodeObject, Q_MOVABLE_TYPE );
 #endif
