@@ -450,7 +450,12 @@ QVariant SKGObjectBase::getPropertyBlob(const QString& iName) const
     return getDocument()->getParameterBlob(iName, getUniqueID());
 }
 
-SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob, SKGPropertyObject* oObjectCreated)
+SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QString& iFileName, SKGPropertyObject* oObjectCreated) const
+{
+    return getDocument()->setParameter(iName, iValue, iFileName, getUniqueID(), oObjectCreated);
+}
+
+SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob, SKGPropertyObject* oObjectCreated) const
 {
     return getDocument()->setParameter(iName, iValue, iBlob, getUniqueID(), oObjectCreated);
 
