@@ -275,6 +275,17 @@ public:
      */
     virtual QVariant getPropertyBlob(const QString& iName) const;
 
+    /**
+     * Set the value for a property
+     * @param iName the property name
+     * @param iValue the property value
+     * @param iFileName the file name.
+     * @param oObjectCreated the property object created
+     * @return an object managing the property
+     *   @see SKGError
+     */
+    virtual SKGError setProperty(const QString& iName, const QString& iValue, const QString& iFileName, SKGPropertyObject* oObjectCreated=NULL) const;
+
     /**
      * Set the value for a property
      * @param iName the property name
@@ -284,7 +295,7 @@ public:
      * @return an object managing the property
      *   @see SKGError
      */
-    virtual SKGError setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob=QVariant(), SKGPropertyObject* oObjectCreated=NULL);
+    virtual SKGError setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob=QVariant(), SKGPropertyObject* oObjectCreated=NULL) const;
 
     /**
      * To know if an object exists or not
@@ -360,5 +371,8 @@ private:
      */
     SKGQStringQStringMap attributes;
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO ( SKGObjectBase, Q_MOVABLE_TYPE );
 #endif
