@@ -178,6 +178,20 @@ QString SKGServices::dateToSqlString(const QDateTime& iDateTime)
     return iDateTime.toString("yyyy-MM-dd");
 }
 
+int SKGServices::nbWorkingDays(const QDate& iFrom, const QDate& iTo)
+{
+    int nb=0;
+    QDate min=(iFrom<iTo ? iFrom : iTo);
+    QDate max=(iFrom<iTo ? iTo : iFrom);
+
+    while (min!=max)
+    {
+        if (min.dayOfWeek()<=5) ++nb;
+        min=min.addDays(1);
+    }
+    return nb;
+}
+
 QDateTime SKGServices::stringToTime(const QString& iDateString)
 {
     QDateTime output=QDateTime::fromString (iDateString, "yyyy-MM-dd HH:mm:ss");
@@ -524,11 +538,11 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
     SKGTRACEL(10) << "Input parameter [iHeaderFile]=[" << iHeaderFile << ']' << endl;
 
     QCA::Initializer init;
-    if (!iPassword.isEmpty() && !QCA::isSupported("aes128-ecb"))
+    if (!QCA::isSupported("aes128-ecb"))
     {
         //Set error message
         err.setReturnCode(ERR_WRITEACCESS); //To avoid password request
-        err.setMessage(i18nc("An error message", "AES128 encryption is not supported. Please install libqca2-plugin-ossl"));
+        err.setMessage(i18nc("An error message", "AES128 encryption is not supported. Please install qca-ossl."));
     }
     else
     {
@@ -542,7 +556,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
         QCA::InitializationVector iv(iPassword.toAscii());
 
         // create a 128 bit AES cipher object using Cipher Block Chaining (CBC) mode
-        QCA::Cipher cipher(QString("aes128"),QCA::Cipher::CBC,
+        QCA::Cipher cipher("aes128",QCA::Cipher::CBC,
                            // use Default padding, which is equivalent to PKCS7 for CBC
                            QCA::Cipher::DefaultPadding,
                            iEncrypt ? QCA::Encode : QCA::Decode,
@@ -559,6 +573,9 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                 //Read document
                 QByteArray input = fileInput.readAll();
                 QByteArray h=(iHeaderFile+(iPassword.isEmpty() ? SKG_HEADER_DECRYPTED : SKG_HEADER_ENCRYPTED)).toLatin1();
+                //BUG 249955 vvv
+                if (iPassword.isEmpty() && input.startsWith(QByteArray((iHeaderFile+SKG_HEADER_ENCRYPTED).toLatin1()))) err=SKGError(ERR_UNEXPECTED, i18nc("Error message", "Encryption failed"));
+                //BUG 249955 ^^^
                 if (!iEncrypt && h.count() && input.startsWith(h)) input=input.right(input.length()-h.length());
 
                 // we use the cipher object to encrypt the argument we passed in
@@ -566,12 +583,12 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                 // 16 bytes (1 block), then nothing will be returned - it is buffered
                 // update() can be called as many times as required.
                 QCA::SecureArray u;
-                if (!iPassword.isEmpty())
+                if (err.isSucceeded() && !iPassword.isEmpty())
                 {
                     u= cipher.update(input);
 
                     // We need to check if that update() call worked.
-                    if (!cipher.ok()) err=SKGError(ERR_WRITEACCESS, i18nc("Error message", "Encryption failed"));
+                    if (!cipher.ok()) err=SKGError(ERR_UNEXPECTED, i18nc("Error message", "Encryption failed"));
                 }
 
                 // output the results of that stage
@@ -593,7 +610,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                             QCA::SecureArray f = cipher.final();
 
                             // Check if the final() call worked
-                            if (!cipher.ok()) err=SKGError(ERR_WRITEACCESS, i18nc("Error message", "Encryption failed"));
+                            if (!cipher.ok()) err=SKGError(ERR_UNEXPECTED, i18nc("Error message", "Encryption failed"));
 
                             // and output the resulting block. The ciphertext is the results of update()
                             // and the result of final()
