@@ -64,7 +64,9 @@ int main(int argc, char** argv)
             SKGTEST("NOD:getFullName", nod1.getFullName(), "root1");
             SKGTEST("NOD:getData", nod1.getData(), "data1");
             SKGTEST("NOD:getOrder", nod1.getOrder(), 12);
+            SKGTEST("NOD:isFolder", nod1.isFolder(), true);
             SKGTEST("NOD:isAutoStart", nod1.isAutoStart(), true);
+            nod1.getIcon();
 
             //Update with bad name
             SKGTESTERROR("NOD:setName", nod1.setName("root1"OBJECTSEPARATOR"A"), false);
