@@ -44,7 +44,7 @@ public:
      */
     virtual ~SKGBankBoardWidget();
 
-private slots:
+private Q_SLOTS:
     void dataModified(const QString& iTableName="", int iIdTransaction=0);
     void onOpen(const QString& iLink);
 
