@@ -22,10 +22,12 @@
 #include "skgbankplugin.h"
 #include "skgbankpluginwidget.h"
 #include "skgbankboardwidget.h"
+#include "skgaccountboardwidget.h"
 #include "skgbank_settings.h"
 #include "skgmainpanel.h"
 #include "skgaccountobject.h"
 #include "skgtraces.h"
+#include "skgdocumentbank.h"
 
 #include <kactioncollection.h>
 
@@ -51,12 +53,12 @@ SKGBankPlugin::~SKGBankPlugin()
     reconciliateAction=NULL;
 }
 
-void SKGBankPlugin::setupActions ( SKGDocument* iDocument, const QStringList& iArgument )
+bool SKGBankPlugin::setupActions ( SKGDocument* iDocument, const QStringList& iArgument )
 {
     SKGTRACEIN ( 10, "SKGBankPlugin::setupActions" );
     Q_UNUSED ( iArgument );
-
-    currentBankDocument=iDocument;
+    currentBankDocument=dynamic_cast<SKGDocumentBank*>(iDocument);
+    if (currentBankDocument==NULL) return false;
 
     setComponentData ( SKGBankPluginFactory::componentData() );
     setXMLFile ( "skrooge_bank.rc" );
@@ -65,9 +67,10 @@ void SKGBankPlugin::setupActions ( SKGDocument* iDocument, const QStringList& iA
     reconciliateAction = new KAction ( KIcon ( "skrooge_duplicate" ), i18nc ("Verb", "Reconcile..." ), this );
     connect ( reconciliateAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionReconciliate() ) );
     actionCollection()->addAction ( QLatin1String ( "edit_reconciliate" ), reconciliateAction );
-    reconciliateAction->setShortcut ( Qt::META+Qt::Key_R );
+    reconciliateAction->setShortcut ( Qt::ALT+Qt::Key_R );
 
     if ( SKGMainPanel::getMainPanel() ) SKGMainPanel::getMainPanel()->registedGlobalAction ( "edit_reconciliate", reconciliateAction );
+    return true;
 }
 
 void SKGBankPlugin::close()
@@ -77,25 +80,27 @@ void SKGBankPlugin::close()
 
 int SKGBankPlugin::getNbDashboardWidgets()
 {
-    return 1;
+    return 2;
 }
 
 QString SKGBankPlugin::getDashboardWidgetTitle ( int iIndex )
 {
     if ( iIndex==0 ) return i18nc ( "Noun, a list of items","Accounts" );
+    else if ( iIndex==1 ) return i18nc ( "Noun, a list of items","Banks" );
     return "";
 }
 
 SKGWidget* SKGBankPlugin::getDashboardWidget ( int iIndex )
 {
-    if ( iIndex==0 ) return new SKGBankBoardWidget ( currentBankDocument );
+    if ( iIndex==0 ) return new SKGAccountBoardWidget ( currentBankDocument );
+    else if ( iIndex==1 ) return new SKGBankBoardWidget ( currentBankDocument );
     return NULL;
 }
 
 SKGTabPage* SKGBankPlugin::getWidget()
 {
     SKGTRACEIN ( 10, "SKGBankPlugin::getWidget" );
-    return new SKGBankPluginWidget ( ( SKGDocumentBank* ) currentBankDocument );
+    return new SKGBankPluginWidget ( currentBankDocument );
 }
 
 QWidget* SKGBankPlugin::getPreferenceWidget()
@@ -167,30 +172,30 @@ void SKGBankPlugin::actionReconciliate()
 {
     if ( currentBankDocument && SKGMainPanel::getMainPanel() )
     {
-      QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
+        QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
 
-      //Open in operation plugin
-      SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
-      int nb=selection.count();
-      for ( int i=0; i<nb; ++i )
-      {
-	  SKGAccountObject accountObj=selection[i];
+        //Open in operation plugin
+        SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
+        int nb=selection.count();
+        for ( int i=0; i<nb; ++i )
+        {
+            SKGAccountObject accountObj=selection[i];
 
-	  QDomDocument doc ( "SKGML" );
-	  doc.setContent ( currentBankDocument->getParameter ( "SKGOPERATION_DEFAULT_PARAMETERS" ) );
-	  QDomElement root = doc.documentElement();
-	  if ( root.isNull() )
-	  {
-	      root=doc.createElement ( "parameters" );
-	      doc.appendChild ( root );
-	  }
+            QDomDocument doc ( "SKGML" );
+            doc.setContent ( currentBankDocument->getParameter ( "SKGOPERATION_DEFAULT_PARAMETERS" ) );
+            QDomElement root = doc.documentElement();
+            if ( root.isNull() )
+            {
+                root=doc.createElement ( "parameters" );
+                doc.appendChild ( root );
+            }
 
-	  root.setAttribute ( "account", accountObj.getName() );
-	  root.setAttribute ( "modeInfoZone", "1" );
-	  root.setAttribute ( "currentPage", "-1" );
-	  SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
-      }
-      QApplication::restoreOverrideCursor();
+            root.setAttribute ( "account", accountObj.getName() );
+            root.setAttribute ( "modeInfoZone", "1" );
+            root.setAttribute ( "currentPage", "-1" );
+            SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
+        }
+        QApplication::restoreOverrideCursor();
     }
 }
 
