@@ -29,6 +29,7 @@
 #include <kgenericfactory.h>
 
 class SKGMainPanel;
+class SKGDocumentBank;
 
 /**
  * This file is Skrooge plugin for bank management
@@ -51,10 +52,11 @@ public:
 
     /**
      * Called to initialise the plugin
-     * @param iDocument the SKGDocumentBank main document
+     * @param iDocument the main document
      * @param iArgument the arguments
+     * @return true if the plugin is compatible with the document
      */
-    virtual void setupActions ( SKGDocument* iDocument, const QStringList& iArgument );
+    virtual bool setupActions ( SKGDocument* iDocument, const QStringList& iArgument );
 
     /**
      * Must be modified to close properly the plugin.
@@ -140,13 +142,13 @@ public:
      */
     virtual bool isInContext() const;
 
-private slots:
+private Q_SLOTS:
     void actionReconciliate();
 
 private:
     Q_DISABLE_COPY ( SKGBankPlugin );
 
-    SKGDocument* currentBankDocument;
+    SKGDocumentBank* currentBankDocument;
 
     Ui::skgbankplugin_pref ui;
     KAction* reconciliateAction;
