@@ -93,9 +93,13 @@ SKGBankPluginWidget::SKGBankPluginWidget ( SKGDocumentBank* iDocument )
 
     ui.kAccountTableViewEdition->sortByColumn ( 0, Qt::AscendingOrder );
 
+    //Search file list
+    QString listIconFile=KStandardDirs::locate ( "data", "skrooge/images/logo/l10n/"+KGlobal::locale()->country()+"/list_bank.txt" );
+    if (listIconFile.isEmpty()) listIconFile=KStandardDirs::locate ( "data", "skrooge/images/logo/list_bank.txt" );
+
     //Logo for banks
     ui.kAccountCreatorIcon->addItem ( "" );
-    QFile file ( KStandardDirs::locate ( "data", QString::fromLatin1 ( "skrooge/images/logo/list_bank.txt" ) ) );
+    QFile file(listIconFile);
     if ( file.open ( QIODevice::ReadOnly | QIODevice::Text ) )
     {
         QDir dirLogo ( KStandardDirs::locate ( "data", QString::fromLatin1 ( "skrooge/images/logo/" ) ) );
@@ -231,7 +235,7 @@ void SKGBankPluginWidget::onSelectionChanged()
         }
 
         onAccountCreatorModified();
-        emit selectionChanged();
+        Q_EMIT selectionChanged();
     }
 }
 
@@ -395,16 +399,6 @@ void SKGBankPluginWidget::onAddAccountClicked()
     SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
 }
 
-SKGObjectBase::SKGListSKGObjectBase SKGBankPluginWidget::getSelectedObjects()
-{
-    return ui.kAccountTableViewEdition->getSelectedObjects();
-}
-
-int SKGBankPluginWidget::getNbSelectedObjects()
-{
-    return ui.kAccountTableViewEdition->getNbSelectedObjects();
-}
-
 void SKGBankPluginWidget::onModifyAccountClicked()
 {
     SKGError err;
@@ -455,7 +449,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                     if ( err.isSucceeded() && accounts.count() >1 )
                     {
                         QApplication::setOverrideCursor ( QCursor ( Qt::ArrowCursor ) );
-                        code=KMessageBox::questionYesNo ( this, i18nc ( "Question", "You are trying to modify bank name of account named \"%1\".\nDo you want to do this modification for all accounts of this bank ?",  accountObj.getName() ) );
+                        code=KMessageBox::questionYesNo ( this, i18nc ( "Question", "You are trying to modify bank name of account named '%1'.\nDo you want to do this modification for all accounts of this bank ?",  accountObj.getName() ) );
                         QApplication::restoreOverrideCursor();
                     }
                 }
@@ -709,7 +703,7 @@ void SKGBankPluginWidget::refreshInfoZone()
     }
 }
 
-QWidget* SKGBankPluginWidget::getWidgetForPrint()
+QWidget* SKGBankPluginWidget::mainWidget() const
 {
     return ui.kAccountTableViewEdition;
 }
@@ -725,9 +719,4 @@ bool SKGBankPluginWidget::isEditor()
     return true;
 }
 
-QWidget* SKGBankPluginWidget::zoomableWidget() const
-{
-    return ui.kAccountTableViewEdition;
-}
-
 #include "skgbankpluginwidget.moc"
