@@ -25,6 +25,7 @@
 #include "skginterestboardwidget.h"
 #include "skgtraces.h"
 #include "skgdocumentbank.h"
+#include "skgaccountobject.h"
 
 #include <kactioncollection.h>
 #include <kstandardaction.h>
@@ -146,5 +147,51 @@ bool SKGCalculatorPlugin::isInContext() const
 {
     return true;
 }
+QList< SKGInterfacePlugin::SKGAdvice > SKGCalculatorPlugin::advices() const
+{
+    QList< SKGInterfacePlugin::SKGAdvice > output;
 
+    //Search investment accounts without interest rate
+    SKGObjectBase::SKGListSKGObjectBase accounts;
+    SKGObjectBase::getObjects(currentBankDocument, "account", "t_type='I' AND NOT EXISTS (SELECT 1 FROM interest WHERE interest.rd_account_id=account.id)", accounts);
+    int nb=accounts.count();
+    for (int i=0; i<nb; ++i)
+    {
+        SKGAccountObject account=accounts.at(i);
+        SKGInterfacePlugin::SKGAdvice ad;
+        ad.uuid="skgcalculatorplugin_nointerest_"+account.getName();
+        ad.priority=3;
+        ad.shortMessage=i18nc("Advice on making the best (short)", "No interest rate defined for account '%1'", account.getName());
+        ad.longMessage=i18nc("Advice on making the best (long)", "Your investment account '%1' doesn't have interest rate defined", account.getName());
+        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Open interest page"));
+        output.push_back(ad);
+    }
+    return output;
+}
+
+SKGError SKGCalculatorPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+{
+    if (currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgcalculatorplugin_nointerest_")))
+    {
+        //Get parameters
+        QString account=iAdviceIdentifier.right(iAdviceIdentifier.length()-31);
+
+        //Call operation plugin
+        QDomDocument doc ( "SKGML" );
+        doc.setContent ( currentBankDocument->getParameter ( "SKGCALCULATOR_DEFAULT_PARAMETERS" ) );
+        QDomElement root = doc.documentElement();
+        if ( root.isNull() )
+        {
+            root=doc.createElement ( "parameters" );
+            doc.appendChild ( root );
+        }
+
+        root.setAttribute ( "currentPage", "0" );
+        root.setAttribute ( "account", account );
+        SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge calculator plugin" ), -1, doc.toString() );
+        return SKGError();
+    }
+
+    return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
+}
 #include "skgcalculatorplugin.moc"
