@@ -150,7 +150,23 @@ public:
      */
     virtual bool isInContext() const;
 
-private slots:
+    /**
+     * The advice list of the plugin.
+     * @return The advice list of the plugin
+     */
+    virtual QList<SKGInterfacePlugin::SKGAdvice> advices() const;
+
+    /**
+     * Must be implemented to execute the automatic correction for the advice.
+     * @param iAdviceIdentifier the identifier of the advice
+     * @param iSolution the identifier of the possible solution
+     * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
+     *   @see SKGError
+     */
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+
+
+private Q_SLOTS:
 
 private:
     Q_DISABLE_COPY(SKGCalculatorPlugin);
