@@ -27,25 +27,43 @@
 #include "skginterestobject.h"
 #include "skgaccountobject.h"
 #include "skgtransactionmng.h"
+#include "skgunitobject.h"
 
 #include <kstandarddirs.h>
+#include <klocale.h>
 
 #include <QDomDocument>
 #include <QDir>
 #include <QKeyEvent>
 
-SKGCalculatorPluginWidget::SKGCalculatorPluginWidget ( SKGDocument* iDocument )
+#include <math.h>
+
+SKGCalculatorPluginWidget::SKGCalculatorPluginWidget ( SKGDocumentBank* iDocument )
         :SKGTabPage ( iDocument )
 {
     SKGTRACEIN ( 1, "SKGCalculatorPluginWidget::SKGCalculatorPluginWidget" );
 
+    timer = new QTimer ( this );
+    timer->setSingleShot ( true );
+    connect ( timer, SIGNAL ( timeout() ), this, SLOT ( onAmortizationComputation() ) );
+
     ui.setupUi ( this );
+    ui.kUnitEdit->setDocument(iDocument);
+    ui.kUnitEdit->setWhereClauseCondition("t_type IN ('1','2','C')");
 
     ui.kUpdate->setIcon ( KIcon ( "dialog-ok-apply" ) );
     ui.kAdd->setIcon ( KIcon ( "list-add" ) );
 
-//         ui.kCalculatorBtn->setIcon(KIcon("accessories-calculator"));
-//         ui.kInterestBtn->setIcon(KIcon("skrooge_more"));
+    ui.kLoadSummaryTitle->setPixmap(KIcon("configure").pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
+    ui.kPaymentSummaryTitle->setPixmap(KIcon("rating").pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
+    ui.kAmortizationTableTitle->setPixmap(KIcon("view-pim-calendar").pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
+
+    ui.kInterestResultsTitle->setPixmap(KIcon("rating").pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
+    ui.kInterestValuesTitle->setPixmap(KIcon("configure").pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
+    ui.kDefineValueTitle->setPixmap(KIcon("configure").pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
+
+    ui.kAmortizationBtn->setIcon(KIcon("accessories-calculator"));
+    ui.kInterestBtn->setIcon(KIcon("skrooge_more"));
 
     ui.kCreditValueDate->addItem ( i18nc ( "Noun",  "Fifteen" ) );
     ui.kCreditValueDate->addItem ( i18nc ( "Noun",  "Day +0" ) );
@@ -67,11 +85,13 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget ( SKGDocument* iDocument )
     ui.kMode->addItem ( i18nc ( "Noun",  "360 days" ) );
     ui.kMode->addItem ( i18nc ( "Noun",  "365 days" ) );
 
+    ui.kAmortizationTable->verticalHeader()->setDefaultSectionSize ( ui.kAmortizationTable->verticalHeader()->minimumSectionSize() );
+
     //Bind account creation view
-    objectModel = new SKGObjectModel ( ( SKGDocumentBank* ) getDocument(), "v_interest", "", this, "", false );
+    objectModel = new SKGObjectModel ( static_cast<SKGDocumentBank*>(getDocument()), "v_interest", "", this, "", false );
     ui.kInterestView->setModel ( objectModel );
 
-    SKGObjectModel* resultModel = new SKGObjectModel ( ( SKGDocumentBank* ) getDocument(), "interest_result", "", this, "", false );
+    SKGObjectModel* resultModel = new SKGObjectModel ( static_cast<SKGDocumentBank*>(getDocument()), "interest_result", "", this, "", false );
     ui.kInterestResultTable->setModel ( resultModel );
 
     connect ( ui.kInterestView, SIGNAL ( selectionChangedDelayed() ), this, SLOT ( onSelectionChanged() ) );
@@ -79,7 +99,7 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget ( SKGDocument* iDocument )
     connect ( objectModel, SIGNAL ( afterReset() ), ui.kInterestView, SLOT ( resetSelection() ) );
 
     //Build you panel here
-//         setCurrentMode(-1);
+    setCurrentMode ( -1 );
 
     //Refresh
     connect ( ui.kDisplayAccountCombo, SIGNAL ( currentIndexChanged ( int ) ), this, SLOT ( onFilterChanged() ), Qt::QueuedConnection );
@@ -90,12 +110,17 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget ( SKGDocument* iDocument )
 
     //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter ( this );
+
+    //Synchronize zooms of both tables
+    connect ( ui.kInterestResultTable, SIGNAL ( zoomChanged(int)), ui.kInterestView, SLOT ( setZoomPosition(int)) );
+    connect ( ui.kInterestView, SIGNAL ( zoomChanged(int)), ui.kInterestResultTable, SLOT ( setZoomPosition(int)) );
 }
 
 SKGCalculatorPluginWidget::~SKGCalculatorPluginWidget()
 {
     SKGTRACEIN ( 1, "SKGCalculatorPluginWidget::~SKGCalculatorPluginWidget" );
     objectModel=NULL;
+    timer=NULL;
 }
 
 bool SKGCalculatorPluginWidget::eventFilter ( QObject *object, QEvent *event )
@@ -119,44 +144,57 @@ bool SKGCalculatorPluginWidget::eventFilter ( QObject *object, QEvent *event )
     return false;
 }
 
-// /*int SKGCalculatorPluginWidget::getCurrentMode()
-// {
-//         return mode;
-// }*/
+int SKGCalculatorPluginWidget::getCurrentMode()
+{
+    return mode;
+}
 
-// void SKGCalculatorPluginWidget::onBtnModeClicked()
-// {
-//         QWidget* sender=static_cast<QWidget*> ( this->sender() );
-//
-//         int currentMode=getCurrentMode();
-//         int newMode=0;
-//
-// //         if (sender==ui.kCalculatorBtn) newMode=0;
-// //         else if (sender==ui.kInterestBtn) newMode=1;
-//
-//         if (currentMode==newMode) newMode=-1;
-//         setCurrentMode(newMode);
-// }
-//
-// void SKGCalculatorPluginWidget::setCurrentMode(int iMode)
-// {
-//         mode=iMode;
-//         if (mode==-1) mode=0;
-//
-//         ui.kCalculatorFrm->hide();
-//         ui.kInterestFrm->hide();
-//
-// //         ui.kCalculatorBtn->setChecked(false);
-// //         ui.kInterestBtn->setChecked(false);
-//
-//         if (mode==0) {
-//                 ui.kCalculatorFrm->show();
-// //                 ui.kCalculatorBtn->setChecked(true);
-//         } else if (mode==1) {
-//                 ui.kInterestFrm->show();
-// //                 ui.kInterestBtn->setChecked(true);
-//         }
-// }
+void SKGCalculatorPluginWidget::onBtnModeClicked()
+{
+    QWidget* sender=static_cast<QWidget*> ( this->sender() );
+
+    int currentMode=getCurrentMode();
+    int newMode=0;
+
+    if ( sender==ui.kInterestBtn ) newMode=0;
+    else if ( sender==ui.kAmortizationBtn ) newMode=1;
+
+    if ( currentMode==newMode ) newMode=-1;
+    setCurrentMode ( newMode );
+}
+
+void SKGCalculatorPluginWidget::setCurrentMode ( int iMode )
+{
+    //Save zoom position of previous page
+    int zoom=zoomPosition();
+
+    mode=iMode;
+    if ( mode==-1 ) mode=0;
+
+    //Save zoom position on new page
+    setZoomPosition(zoom);
+
+    ui.kInterestFrm->hide();
+    ui.kAmortizationFrm->hide();
+    ui.kBtnFrm->hide();
+
+    ui.kInterestBtn->setChecked ( false );
+    ui.kAmortizationBtn->setChecked ( false );
+
+    if ( mode==0 )
+    {
+        ui.kInterestFrm->show();
+        ui.kBtnFrm->show();
+        ui.kInterestBtn->setChecked ( true );
+    }
+    else if ( mode==1 )
+    {
+        ui.kAmortizationFrm->show();
+        ui.kAmortizationBtn->setChecked ( true );
+    }
+
+    Q_EMIT selectionChanged();
+}
 
 QString SKGCalculatorPluginWidget::getState()
 {
@@ -165,10 +203,17 @@ QString SKGCalculatorPluginWidget::getState()
     QDomElement root = doc.createElement ( "parameters" );
     doc.appendChild ( root );
 
-//         root.setAttribute ( "currentPage", SKGServices::intToString(getCurrentMode()) );
+    root.setAttribute ( "currentPage", SKGServices::intToString ( getCurrentMode() ) );
     root.setAttribute ( "account", ui.kDisplayAccountCombo->currentText() );
     root.setAttribute ( "year", ui.KYearEdit->text() );
 
+    root.setAttribute ( "amortizationLoan", ui.kLoanEdit->text() );
+    root.setAttribute ( "amortizationUnit", ui.kUnitEdit->text() );
+    root.setAttribute ( "amortizationRate", SKGServices::doubleToString(ui.kAnnualRateEdit->value()) );
+    root.setAttribute ( "amortizationLenght", SKGServices::intToString(ui.kLenghtEdit->value()) );
+    root.setAttribute ( "amortizationInsuranceRate", SKGServices::doubleToString(ui.kInsuranceRateEdit->value()) );
+
+
     //Memorize table settings
     root.setAttribute ( "view", ui.kInterestView->getState() );
     root.setAttribute ( "viewResult", ui.kInterestResultTable->getState() );
@@ -186,13 +231,24 @@ void SKGCalculatorPluginWidget::setState ( const QString& iState )
     QString account=root.attribute ( "account" );
     QString currentPage=root.attribute ( "currentPage" );
     QString year=root.attribute ( "year" );
-//         if ( !currentPage.isEmpty() ) setCurrentMode ( SKGServices::stringToInt ( currentPage ) );
+    QString amortizationLoan=root.attribute ( "amortizationLoan" );
+    QString amortizationUnit=root.attribute ( "amortizationUnit" );
+    QString amortizationRate=root.attribute ( "amortizationRate" );
+    QString amortizationInsuranceRate=root.attribute ( "amortizationInsuranceRate" );
+    QString amortizationLenght=root.attribute ( "amortizationLenght" );
+
+    if ( !currentPage.isEmpty() ) setCurrentMode ( SKGServices::stringToInt ( currentPage ) );
     if ( !account.isEmpty() )
     {
         bool previous=ui.kDisplayAccountCombo->blockSignals ( true );
         ui.kDisplayAccountCombo->setText ( account );
         ui.kDisplayAccountCombo->blockSignals ( previous );
     }
+    if ( !amortizationLoan.isEmpty() ) ui.kLoanEdit->setText(amortizationLoan);
+    if ( !amortizationUnit.isEmpty() ) ui.kUnitEdit->setText(amortizationUnit);
+    if ( !amortizationRate.isEmpty() ) ui.kAnnualRateEdit->setValue(SKGServices::stringToDouble(amortizationRate));
+    if ( !amortizationInsuranceRate.isEmpty() ) ui.kInsuranceRateEdit->setValue(SKGServices::stringToDouble(amortizationInsuranceRate));
+    if ( !amortizationLenght.isEmpty() ) ui.kLenghtEdit->setValue(SKGServices::stringToInt(amortizationLenght));
 
     if ( !year.isEmpty() ) ui.KYearEdit->setText ( year );
 
@@ -214,11 +270,6 @@ QString SKGCalculatorPluginWidget::getDefaultStateAttribute()
     return "SKGCALCULATOR_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGCalculatorPluginWidget::getWidgetForPrint()
-{
-    return this;
-}
-
 void SKGCalculatorPluginWidget::onSelectionChanged()
 {
     SKGTRACEIN ( 10, "SKGCalculatorPluginWidget::onSelectionChanged" );
@@ -240,7 +291,7 @@ void SKGCalculatorPluginWidget::onSelectionChanged()
             ui.kMode->setCurrentIndex ( ( int ) interest.getInterestComputationMode() );
         }
 
-        emit selectionChanged();
+        Q_EMIT selectionChanged();
     }
 }
 
@@ -257,7 +308,7 @@ void SKGCalculatorPluginWidget::dataModified ( const QString& iTableName, int iI
     if ( db!=NULL && ( iTableName=="interest" || iTableName.isEmpty() ) )
     {
         //Correction bug 2299394 vvv
-        if ( ui.kInterestView->isAutoResized() ) ui.kInterestView->resizeColumnsToContents();
+        if ( ui.kInterestView->isAutoResized() ) ui.kInterestView->resizeColumnsToContentsDelayed();
         //Correction bug 2299394 ^^^
 
         //Correction 215658: vvv because the table is modified, the selection is modified
@@ -341,7 +392,7 @@ void SKGCalculatorPluginWidget::computeInterest()
         ui.kInterestResultTable->setState ( ui.kInterestResultTable->getState() );
 
         //Set text
-        SKGDocumentBank* doc= ( SKGDocumentBank* ) getDocument();
+        SKGDocumentBank* doc= static_cast<SKGDocumentBank*>(getDocument());
         if ( doc )
         {
             SKGServices::SKGUnitInfo unit1=doc->getPrimaryUnit();
@@ -349,7 +400,7 @@ void SKGCalculatorPluginWidget::computeInterest()
 
             QString s1=doc->formatMoney ( oInterests, unit1 );
             ui.kInterestLbl->setText ( i18nc ( "Noun",  "Annual interest=%1", s1 ) );
-            if ( !unit2.Name.isEmpty() && unit2.Value )
+            if ( !unit2.Symbol.isEmpty() && unit2.Value )
             {
                 s1=doc->formatMoney ( oInterests, unit2 );
                 ui.kInterestLbl->setToolTip ( i18nc ( "Noun",  "Annual interest=%1", s1 ) );
@@ -382,12 +433,16 @@ void SKGCalculatorPluginWidget::onFilterChanged()
 
 SKGObjectBase::SKGListSKGObjectBase SKGCalculatorPluginWidget::getSelectedObjects()
 {
-    return ui.kInterestView->getSelectedObjects();
+    SKGObjectBase::SKGListSKGObjectBase output;
+    if (getCurrentMode()==0) output=ui.kInterestView->getSelectedObjects();
+    return output;
 }
 
 int SKGCalculatorPluginWidget::getNbSelectedObjects()
 {
-    return ui.kInterestView->getNbSelectedObjects();
+    int output=0;
+    if (getCurrentMode()==0) output=ui.kInterestView->getNbSelectedObjects();
+    return output;
 }
 
 // void SKGCalculatorPluginWidget::onCalculatorReturnPressed(const QString& iText)
@@ -418,7 +473,7 @@ void SKGCalculatorPluginWidget::onAdd()
         SKGInterestObject interestObj;
         {
             QString accountname=ui.kDisplayAccountCombo->currentText();
-            SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Interest parameter creation for account [%1]", accountname ), err );
+            SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Interest parameter creation for account '%1'", accountname ), err );
 
             //Get Parent account
             SKGAccountObject accountObj ( getDocument() );
@@ -464,9 +519,9 @@ void SKGCalculatorPluginWidget::onUpdate()
     SKGObjectBase::SKGListSKGObjectBase updatedInterest=getSelectedObjects();
     int nb=updatedInterest.count();
     {
-        SKGInterestObject interestObj;
         {
-            SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Interest parameter update for account [%1]", accountname ), err );
+            SKGInterestObject interestObj;
+            SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Interest parameter update for account '%1'", accountname ), err );
 
             for ( int i=0; err.isSucceeded() && i<nb; ++i )
             {
@@ -492,6 +547,85 @@ void SKGCalculatorPluginWidget::onUpdate()
     //Display error
     SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
 }
+
+void SKGCalculatorPluginWidget::onAmortizationComputationDelayed()
+{
+    if ( timer ) timer->start ( 300 );
+}
+
+void SKGCalculatorPluginWidget::onAmortizationComputation()
+{
+    SKGTRACEIN ( 10, "SKGCalculatorPluginWidget::onAmortizationComputation" );
+    QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
+
+    KLocale* locale=KGlobal::locale();
+    if ( locale )
+    {
+        //Get unit
+        SKGServices::SKGUnitInfo unitInfo;
+        unitInfo.Symbol=ui.kUnitEdit->text();
+
+        SKGUnitObject unit ( getDocument() );
+        unit.setSymbol ( unitInfo.Symbol );
+        unit.load();
+        unitInfo.NbDecimal=unit.getNumberDecimal();
+
+        int p=pow ( 10,unitInfo.NbDecimal );
+
+        //Computation
+        int periodInMonths=12;
+        int numberPayments=ui.kLenghtEdit->value() *periodInMonths;
+        double periodicRate=ui.kAnnualRateEdit->value() /100/periodInMonths;
+        double insurance=round ( ui.kLoanEdit->value()*ui.kInsuranceRateEdit->value() /100/periodInMonths*p ) /p;
+        double periodicAmount=round ( ui.kLoanEdit->value() *periodicRate/ ( 1-pow ( 1+periodicRate,-numberPayments ) ) *p ) /p;
+
+        //Fill table
+        double dueAmount=ui.kLoanEdit->value();
+        double sumInterest=0;
+        ui.kAmortizationTable->setRowCount ( numberPayments );
+        for ( int i=0; i<numberPayments; ++i )
+        {
+            //Compute
+            double roundedInterest=round ( dueAmount*periodicRate*p ) /p;
+            double principal=round ( ( i==numberPayments-1 ? dueAmount : periodicAmount-roundedInterest ) *p ) /p;
+            double amount=roundedInterest+principal;
+            dueAmount-=principal;
+            sumInterest+=roundedInterest;
+
+            //Add items
+            ui.kAmortizationTable->setItem ( i, 0, new QTableWidgetItem ( locale->formatMoney ( amount, unitInfo.Symbol, unitInfo.NbDecimal ) ) );
+            ui.kAmortizationTable->setItem ( i, 1, new QTableWidgetItem ( locale->formatMoney ( principal, unitInfo.Symbol, unitInfo.NbDecimal ) ) );
+            ui.kAmortizationTable->setItem ( i, 2, new QTableWidgetItem ( locale->formatMoney ( roundedInterest, unitInfo.Symbol, unitInfo.NbDecimal ) ) );
+            ui.kAmortizationTable->setItem ( i, 3, new QTableWidgetItem ( locale->formatMoney ( insurance, unitInfo.Symbol, unitInfo.NbDecimal ) ) );
+            ui.kAmortizationTable->setItem ( i, 4, new QTableWidgetItem ( locale->formatMoney ( dueAmount, unitInfo.Symbol, unitInfo.NbDecimal ) ) );
+        }
+
+        ui.kAmortizationResult->setText ( i18n ( "Number of payments:	%1\n"
+                                          "Monthly payment: 	%2\n"
+                                          "Monthly insurance: 	%3\n"
+                                          "Total principal paid: 	%4\n"
+                                          "Total interest paid: 	%5\n"
+                                          "Total insurance paid: 	%6\n"
+                                          "Total paid: 		%7" ,
+                                          SKGServices::intToString(numberPayments),
+                                          locale->formatMoney ( periodicAmount, unitInfo.Symbol, unitInfo.NbDecimal ),
+                                          locale->formatMoney ( insurance, unitInfo.Symbol, unitInfo.NbDecimal ),
+                                          locale->formatMoney ( ui.kLoanEdit->value(), unitInfo.Symbol, unitInfo.NbDecimal ),
+                                          locale->formatMoney ( sumInterest, unitInfo.Symbol, unitInfo.NbDecimal ),
+                                          locale->formatMoney ( numberPayments*insurance, unitInfo.Symbol, unitInfo.NbDecimal ),
+                                          locale->formatMoney ( ui.kLoanEdit->value()+sumInterest+numberPayments*insurance, unitInfo.Symbol, unitInfo.NbDecimal )
+                                               ));
+    }
+
+    QApplication::restoreOverrideCursor();
+}
+
+QWidget* SKGCalculatorPluginWidget::zoomableWidget() const
+{
+    if (mode==0) return ui.kInterestView;
+    else return ui.kAmortizationTable;
+}
+
 #include "skgcalculatorpluginwidget.moc"
 
 
