@@ -80,12 +80,6 @@ public:
      */
     virtual int getNbSelectedObjects();
 
-    /**
-     * Get the widget must be printed
-     * @return a widget
-     */
-    virtual QWidget* getWidgetForPrint();
-
     /**
      * Get the zoomable widget. MUST BE OVERWRITTEN
      * By Overwritting this function, you don't have to implement following ones.
@@ -102,7 +96,7 @@ protected:
      */
     virtual bool eventFilter ( QObject *object, QEvent *event );
 
-private slots:
+private Q_SLOTS:
     void dataModified ( const QString& iTableName, int iIdTransaction );
     void onBtnModeClicked();
     void onAmortizationComputationDelayed();
