@@ -66,7 +66,7 @@ public:
      */
     virtual QString getDefaultStateAttribute();
 
-private slots:
+private Q_SLOTS:
     void dataModified(const QString& iTableName="", int iIdTransaction=0);
     void onOpen(const QString& iLink);
 
