@@ -29,6 +29,7 @@
 #include "skgtransactionmng.h"
 
 #include <klocale.h>
+#include <KAction>
 
 #include <QDomDocument>
 #include <QtGui/QWidget>
@@ -133,17 +134,7 @@ void SKGCategoriesPluginWidget::onSelectionChanged()
     }
 
     onEditorModified();
-    emit selectionChanged();
-}
-
-SKGObjectBase::SKGListSKGObjectBase SKGCategoriesPluginWidget::getSelectedObjects()
-{
-    return ui.kCategoriesView->getSelectedObjects();
-}
-
-int SKGCategoriesPluginWidget::getNbSelectedObjects()
-{
-    return ui.kCategoriesView->getNbSelectedObjects();
+    Q_EMIT selectionChanged();
 }
 
 QString SKGCategoriesPluginWidget::getState()
@@ -183,7 +174,7 @@ QString SKGCategoriesPluginWidget::getDefaultStateAttribute()
     return "SKGCATEGORIES_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGCategoriesPluginWidget::getWidgetForPrint()
+QWidget* SKGCategoriesPluginWidget::mainWidget() const
 {
     return ui.kCategoriesView;
 }
@@ -262,24 +253,8 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
 
 void SKGCategoriesPluginWidget::onDeleteUnused()
 {
-    SKGError err;
-    _SKGTRACEINRC ( 10, "SKGCategoriesPluginWidget::onDeleteUnused", err );
-    QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
-    {
-        SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Delete unused categories" )  , err );
-
-        //Modification of category object
-        QString sql="DELETE FROM category WHERE id IN (SELECT id FROM v_category_display WHERE i_SUMNBOPERATIONS=0)";
-        err=SKGServices::executeSqliteOrder ( getDocument(), sql );
-
-        //status bar
-        if ( err.isSucceeded() ) err=SKGError ( 0, i18nc ( "Successful message after an user action", "Unused categories deleted" ) );
-        else err.addError ( ERR_FAIL, i18nc ( "Error message", "Unused categories deletion failed" ) );
-    }
-    QApplication::restoreOverrideCursor();
-
-    //Display error
-    SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
+    KAction* act=SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete_unused_categories");
+    if (act) act->trigger();
 }
 
 void SKGCategoriesPluginWidget::onDoubleClick()
@@ -360,8 +335,4 @@ bool SKGCategoriesPluginWidget::isEditor()
     return true;
 }
 
-QWidget* SKGCategoriesPluginWidget::zoomableWidget() const
-{
-    return ui.kCategoriesView;
-}
 #include "skgcategoriespluginwidget.moc"
