@@ -200,7 +200,7 @@ void SKGImportExportPlugin::processArguments ( const QStringList& iArgument )
     if ( nbArg )
     {
         QString filename=iArgument.at ( nbArg-1 );
-        if ( QFile ( filename ).exists() ) emit importFile ( filename );
+        if ( QFile ( filename ).exists() ) Q_EMIT importFile ( filename );
     }
 }
 
@@ -615,7 +615,7 @@ void SKGImportExportPlugin::openLastModifiedIfSetting()
     }
 }
 
-void SKGImportExportPlugin::openNotValidated()
+void SKGImportExportPlugin::openNotValidated() const
 {
     SKGTRACEIN ( 10, "SKGImportExportPlugin::openNotValidated" );
     QString wc="t_imported='P'";
@@ -640,4 +640,60 @@ void SKGImportExportPlugin::openNotValidated()
     if ( SKGMainPanel::getMainPanel() ) SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
 }
 
+QList< SKGInterfacePlugin::SKGAdvice > SKGImportExportPlugin::advices() const
+{
+    QList< SKGInterfacePlugin::SKGAdvice > output;
+
+    //Check operations not validated
+    int nbObject=0;
+    SKGObjectBase::getNbObjects(currentBankDocument, "operation", "t_imported='P'", nbObject);
+    if (nbObject>0)
+    {
+        SKGInterfacePlugin::SKGAdvice ad;
+        ad.uuid="skgimportexportplugin_notvalidated";
+        ad.priority=4;
+        ad.shortMessage=i18nc("Advice on making the best (short)", "Many operations imported and not yet validated");
+        ad.longMessage=i18nc("Advice on making the best (long)", "After importing operations, you should review them, make corrections on, for instance, category, payee. Once done, you should mark the imported operation as validated, so that you know the operation has been fully processed.");
+        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Open operations imported and not yet validated"));
+        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Validate operations that do not require further action"));
+        output.push_back(ad);
+    }
+
+    return output;
+}
+
+SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+{
+    if (iAdviceIdentifier=="skgimportexportplugin_notvalidated")
+    {
+        if (iSolution==0)
+        {
+            //Open operations imported and not yet validated
+            this->openNotValidated();
+        }
+        else
+        {
+            //Validate all operations
+            SKGError err;
+            {
+                SKGBEGINTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action","Validate all operations" ), err);
+
+                QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
+                err=SKGServices::executeSqliteOrder(currentBankDocument, "UPDATE operation SET t_imported='Y' WHERE t_imported='P'");
+                QApplication::restoreOverrideCursor();
+            }
+
+            //status bar
+            if (err.isSucceeded()) err=SKGError(0, i18nc("Message for successful user action","Operations validated."));
+            else err.addError(ERR_FAIL, i18nc("Error message","Validation failed"));
+
+            //Display error
+            SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
+        }
+        return SKGError();
+    }
+
+    return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
+}
+
 #include "skgimportexportplugin.moc"
