@@ -123,21 +123,37 @@ public:
      * @return true of false (default = false)
      */
     virtual bool isInContext() const;
-signals:
+
+    /**
+     * The advice list of the plugin.
+     * @return The advice list of the plugin
+     */
+    virtual QList<SKGInterfacePlugin::SKGAdvice> advices() const;
+
+    /**
+     * Must be implemented to execute the automatic correction for the advice.
+     * @param iAdviceIdentifier the identifier of the advice
+     * @param iSolution the identifier of the possible solution
+     * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
+     *   @see SKGError
+     */
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+
+Q_SIGNALS:
     /**
      * request to import a file
      * @param iFile file name
      */
     void importFile(const QString& iFile);
 
-private slots:
+private Q_SLOTS:
     void import(const QString& iFile="");
     void exportFile();
     void foundTransfer();
     void anonymize();
     void cleanBanks();
     void validateImportedOperations();
-    void openNotValidated();
+    void openNotValidated() const;
     void mergeImportedOperation();
 private:
     Q_DISABLE_COPY(SKGImportExportPlugin);
