@@ -32,7 +32,6 @@
 #include <QDomDocument>
 #include <QPrinter>
 #include <QPrintDialog>
-#include <QPainter>
 #include <QTextStream>
 #include <QFile>
 #include <QDir>
@@ -95,7 +94,7 @@ QString SKGMonthlyPluginWidget::getDefaultStateAttribute()
     return "SKGMONTHLY_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGMonthlyPluginWidget::getWidgetForPrint()
+QWidget* SKGMonthlyPluginWidget::mainWidget() const
 {
     return ui.kWebView;
 }
@@ -108,9 +107,7 @@ void SKGMonthlyPluginWidget::onPrint()
     QPointer<QPrintDialog> dialog=new QPrintDialog ( &printer, this );
     if ( dialog->exec() == QDialog::Accepted )
     {
-        QPainter painter ( &printer );
-        ui.kWebView->render ( &painter );
-        painter.end();
+        ui.kWebView->print ( &printer );
     }
 
     delete dialog;
@@ -506,9 +503,22 @@ QString SKGMonthlyPluginWidget::get5MainCategories ( SKGDocumentBank* iDocument,
     return html;
 }
 
-QString SKGMonthlyPluginWidget::get5MainCategoriesVariation ( SKGDocumentBank* iDocument, const QString& iMonth, const QString& iPreviousMonth )
+QString SKGMonthlyPluginWidget::get5MainCategoriesVariation ( SKGDocumentBank* iDocument, const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues )
 {
     QString html;
+    QStringList list=get5MainCategoriesVariationList (iDocument, iMonth, iPreviousMonth, iOnlyIssues );
+    int nbval=list.count();
+    for ( int i=0; i<nbval; ++i )
+    {
+        html+=list.at(i)+"<br>";
+    }
+
+    return html;
+}
+
+QStringList SKGMonthlyPluginWidget::get5MainCategoriesVariationList ( SKGDocumentBank* iDocument, const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues, QStringList* oCategoryList )
+{
+    QStringList output;
     if (iDocument)
     {
         SKGServices::SKGUnitInfo primary=iDocument->getPrimaryUnit();
@@ -523,6 +533,10 @@ QString SKGMonthlyPluginWidget::get5MainCategoriesVariation ( SKGDocumentBank* i
                      listTmp );
         if ( err.isSucceeded() )
         {
+            //Clear the list
+            if (oCategoryList) oCategoryList->clear();
+
+            //Fill list
             int nbval=listTmp.count();
             for ( int i=1; i<nbval; ++i ) //Ignore header
             {
@@ -539,28 +553,45 @@ QString SKGMonthlyPluginWidget::get5MainCategoriesVariation ( SKGDocumentBank* i
                 double a2=SKGServices::stringToDouble(listTmp.at ( i ).at ( 3 ));
                 double v=SKGServices::stringToDouble(listTmp.at ( i ).at ( 4 ));
 
-                QString a2f=iDocument->formatMoney(abs(a2), primary);
-                QString vf=iDocument->formatPercentage(abs(v));
+                QString a2f=iDocument->formatMoney(fabs(a2), primary);
+                QString vf=iDocument->formatPercentage(fabs(v));
                 if (a1<0 && a2<0)
                 {
-                    if (v<0) html+=i18n("Expenses in category <b>\"%1\"</b> increased by <b>%2</b> for a total of <b>%3</b>.", c1, vf, a2f)+"<br>";
-                    else html+=i18n("Expenses in category <b>\"%1\"</b> decreased by <b>%2</b> for a total of <b>%3</b>.", c1, vf, a2f)+"<br>";
+                    if (v<0)
+                    {
+                        output.push_back(i18n("Expenses in category <b>'%1'</b> increased by <b>%2</b> for a total of <b>%3</b>.", c1, vf, a2f));
+                        if (oCategoryList) oCategoryList->push_back(c1);
+                    }
+                    else
+                    {
+                        if (!iOnlyIssues)
+                        {
+                            output.push_back(i18n("Expenses in category <b>'%1'</b> decreased by <b>%2</b> for a total of <b>%3</b>.", c1, vf, a2f));
+                            if (oCategoryList) oCategoryList->push_back(c1);
+
+                        }
+                    }
                 }
                 else if (a1>0 && a2>0)
                 {
-                    if (v>0) html+=i18n("Incomes in category <b>\"%1\"</b> increased by <b>%2</b> for a total of <b>%3</b>.", c1, vf, a2f)+"<br>";
-                    else html+=i18n("Incomes in category <b>\"%1\"</b> decreased by <b>%2</b> for a total of <b>%3</b>.", c1, vf, a2f)+"<br>";
+                    if (v>0)
+                    {
+                        if (!iOnlyIssues) {
+                            output.push_back(i18n("Incomes in category <b>'%1'</b> increased by <b>%2</b> for a total of <b>%3</b>.", c1, vf, a2f));
+                            if (oCategoryList) oCategoryList->push_back(c1);
+
+                        }
+                    }
+                    else {
+                        output.push_back(i18n("Incomes in category <b>'%1'</b> decreased by <b>%2</b> for a total of <b>%3</b>.", c1, vf, a2f));
+                        if (oCategoryList) oCategoryList->push_back(c1);
+                    }
                 }
 
             }
         }
     }
-    return html;
-}
-
-QWidget* SKGMonthlyPluginWidget::zoomableWidget() const
-{
-    return ui.kWebView;
+    return output;
 }
 
 #include "skgmonthlypluginwidget.moc"
