@@ -27,6 +27,8 @@
 
 #include <QDomDocument>
 
+#include <kaction.h>
+
 SKGOperationBoardWidget::SKGOperationBoardWidget ( SKGDocument* iDocument )
         : SKGWidget ( iDocument )
 {
@@ -34,6 +36,15 @@ SKGOperationBoardWidget::SKGOperationBoardWidget ( SKGDocument* iDocument )
 
     ui.setupUi ( this );
 
+    //Create menu
+    setContextMenuPolicy ( Qt::ActionsContextMenu );
+
+    menuTransfert=new KAction ( i18nc ("Noun, a type of account", "Transfers" ), this );
+    menuTransfert->setCheckable ( true );
+    menuTransfert->setChecked ( true );
+    connect ( menuTransfert, SIGNAL ( triggered ( bool ) ), this, SLOT ( dataModified() ) );
+    addAction ( menuTransfert );
+
     //Refresh
     connect ( ( const QObject* ) getDocument(), SIGNAL ( tableModified ( QString, int ) ), this, SLOT ( dataModified ( QString, int ) ), Qt::QueuedConnection );
 }
@@ -41,17 +52,29 @@ SKGOperationBoardWidget::SKGOperationBoardWidget ( SKGDocument* iDocument )
 SKGOperationBoardWidget::~SKGOperationBoardWidget()
 {
     SKGTRACEIN ( 10, "SKGOperationBoardWidget::~SKGOperationBoardWidget" );
-
+    menuTransfert=NULL;
 }
 
 QString SKGOperationBoardWidget::getState()
 {
-    return "";
+    QDomDocument doc ( "SKGML" );
+    QDomElement root = doc.createElement ( "parameters" );
+    doc.appendChild ( root );
+
+    root.setAttribute ( "menuTransfert", menuTransfert && menuTransfert->isChecked() ? "Y" : "N" );
+    return doc.toString();
 }
 
 void SKGOperationBoardWidget::setState ( const QString& iState )
 {
-    Q_UNUSED(iState);
+    QDomDocument doc ( "SKGML" );
+    if ( doc.setContent ( iState ) )
+    {
+        QDomElement root = doc.documentElement();
+
+        if (menuTransfert) menuTransfert->setChecked ( root.attribute ( "menuTransfert" ) =="Y" );
+    }
+
     dataModified ( "", 0 );
 }
 
@@ -77,7 +100,7 @@ void SKGOperationBoardWidget::dataModified ( const QString& iTableName, int iIdT
 
             SKGStringListList listTmp;
             SKGError err=SKGServices::executeSelectSqliteOrder ( getDocument(),
-                         "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE d_DATEMONTH IN ('"+month+"', '"+previousmonth+"') AND i_group_id=0 group by d_DATEMONTH, t_TYPEEXPENSE",
+                         "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE d_DATEMONTH IN ('"+month+"', '"+previousmonth+"') "+(menuTransfert && menuTransfert->isChecked() ? "" : "AND i_group_id=0")+" group by d_DATEMONTH, t_TYPEEXPENSE",
                          listTmp );
             if ( err.isSucceeded() )
             {
