@@ -121,6 +121,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget ( SKGDocumentBank* iDocument
     ui.kResetInternalFilter->setIcon ( KIcon ( "dialog-cancel" ) );
     ui.kReconciliatorButton->setIcon ( KIcon ( "object-rotate-left" ) );
     ui.kValidate->setIcon ( KIcon ( "dialog-ok-apply" ) );
+    ui.kAutoPoint->setIcon ( KIcon ( "games-solve" ) );
 
     ui.kStandardBtn->setIcon ( KIcon ( "dialog-ok-apply" ) );
     ui.kTransferBtn->setIcon ( KIcon ( "skrooge_transfer" ) );
@@ -370,9 +371,20 @@ void SKGOperationPluginWidget::onSelectionChanged()
                 ui.kTrackerEdit->setText ( NOUPDATE );
                 ui.kCommentEdit->setText ( NOUPDATE );
                 ui.kPayeeEdit->setText ( NOUPDATE );
+
+                if (modeInfoZone != 1) displaySelectionAmount();
+
             }
             else
             {
+
+                if (obj.getStatus() == SKGOperationObject::POINTED) {
+                    displayReconciliationInfo();
+                }
+                else if (modeInfoZone != 1) {
+                    displayBalance();
+                }
+
                 //It is a single selection
                 //Is it a split ?
                 int nbSubOperations = obj.getNbSubOperations();
@@ -413,7 +425,7 @@ void SKGOperationPluginWidget::onSelectionChanged()
 
         onOperationCreatorModified();
 
-        emit selectionChanged();
+        Q_EMIT selectionChanged();
     }
 
     if ( modeInfoZone==2 ) onRefreshInformationZone();
@@ -737,7 +749,6 @@ SKGError SKGOperationPluginWidget::updateSelection ( const SKGObjectBase::SKGLis
                     operationQuantity=newval;
                     unit=unitTargetAccount;
                 }
-
             }
             //Correction bug 2299303 ^^^
 
@@ -837,6 +848,15 @@ void SKGOperationPluginWidget::onAddOperationClicked()
 
         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
 
+        //Check enties
+        if (ui.kAccountEdit->text()== NOUPDATE ||
+                ui.kTypeEdit->text()== NOUPDATE ||
+                ui.kUnitEdit->text()== NOUPDATE ||
+                ui.kCategoryEdit->text()== NOUPDATE ||
+                ui.kTrackerEdit->text()== NOUPDATE ||
+                ui.kCommentEdit->text()== NOUPDATE ||
+                ui.kPayeeEdit->text()== NOUPDATE) err=SKGError(ERR_FAIL, i18nc("Error message", "Impossible to create an operation with one attribute valuated with %1", NOUPDATE));
+
         //Get account
         SKGAccountObject accountObj ( getDocument() );
         if ( err.isSucceeded() ) err=accountObj.setName ( accountName );
@@ -970,16 +990,6 @@ void SKGOperationPluginWidget::onAddOperationClicked()
     SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
 }
 
-SKGObjectBase::SKGListSKGObjectBase SKGOperationPluginWidget::getSelectedObjects()
-{
-    return ui.kOperationView->getSelectedObjects();
-}
-
-int SKGOperationPluginWidget::getNbSelectedObjects()
-{
-    return ui.kOperationView->getNbSelectedObjects();
-}
-
 SKGTableView* SKGOperationPluginWidget::getTableView()
 {
     return ui.kOperationView;
@@ -1093,7 +1103,7 @@ void SKGOperationPluginWidget::setState ( const QString& iState )
     if ( objectModel )
     {
         bool previous=objectModel->blockRefresh ( true );
-        onFilterChanged();
+        onAccountChanged();
         objectModel->blockRefresh ( previous );
     }
 
@@ -1148,8 +1158,9 @@ void SKGOperationPluginWidget::fillComboBoxes()
     if ( db!=NULL )
     {
         //Disconnect combo filter account
-        disconnect ( ui.kDisplayAccountCombo, SIGNAL ( currentIndexChanged ( int ) ), this, SLOT ( onFilterChanged() ) );
+        disconnect ( ui.kDisplayAccountCombo, SIGNAL ( currentIndexChanged ( int ) ), this, SLOT ( onAccountChanged() ) );
         disconnect ( ui.kDisplayAccountCombo, SIGNAL ( currentIndexChanged ( int ) ), this, SLOT ( onRefreshInformationZone() ) );
+        disconnect ( ui.kUnitEdit, SIGNAL ( textChanged ( QString ) ), this, SLOT ( onOperationCreatorModified() ) );
         disconnect ( ui.kDisplayAccountCombo, SIGNAL ( textChanged ( QString ) ), this, SLOT ( onOperationCreatorModified() ) );
         disconnect ( ui.kAmountEdit, SIGNAL ( textChanged ( QString ) ), this, SLOT ( onOperationCreatorModified() ) );
         disconnect ( ui.kAmountSharesEdit, SIGNAL ( textChanged ( QString ) ), this, SLOT ( onOperationCreatorModified() ) );
@@ -1217,8 +1228,9 @@ void SKGOperationPluginWidget::fillComboBoxes()
         numberFieldIsNotUptodate=true;
 
         //Connect combo filter account
-        connect ( ui.kDisplayAccountCombo, SIGNAL ( currentIndexChanged ( int ) ), this, SLOT ( onFilterChanged() ), Qt::QueuedConnection );
+        connect ( ui.kDisplayAccountCombo, SIGNAL ( currentIndexChanged ( int ) ), this, SLOT ( onAccountChanged() ), Qt::QueuedConnection );
         connect ( ui.kDisplayAccountCombo, SIGNAL ( currentIndexChanged ( int ) ), this, SLOT ( onRefreshInformationZone() ), Qt::QueuedConnection );
+        connect ( ui.kUnitEdit, SIGNAL ( textChanged ( QString ) ), this, SLOT ( onOperationCreatorModified() ), Qt::QueuedConnection );
         connect ( ui.kDisplayAccountCombo, SIGNAL ( textChanged ( QString ) ), this, SLOT ( onOperationCreatorModified() ), Qt::QueuedConnection );
         connect ( ui.kAmountEdit, SIGNAL ( textChanged ( QString ) ), this, SLOT ( onOperationCreatorModified() ), Qt::QueuedConnection );
         connect ( ui.kAmountSharesEdit, SIGNAL ( textChanged ( QString ) ), this, SLOT ( onOperationCreatorModified() ), Qt::QueuedConnection );
@@ -1449,9 +1461,9 @@ void SKGOperationPluginWidget::onRefreshInformationZone()
                 SKGServices::executeSelectSqliteOrder ( getDocument(),
                                                         "SELECT TOTAL(f_CHECKED) from v_account_display WHERE t_name="+filter,
                                                         listTmp2 );
-                if ( listTmp.count() ==2 )
+                if ( listTmp2.count() ==2 )
                 {
-                    diff=SKGServices::stringToDouble ( listTmp2.at ( 1 ).at ( 0 ) ) /unit1.Value-ui.kReconcilitorAmountEdit->value();
+                    diff=SKGServices::stringToDouble ( listTmp2.at ( 1 ).at ( 0 ) ) -ui.kReconcilitorAmountEdit->value()*unit1.Value;
                 }
 
                 //Set tooltip
@@ -1567,6 +1579,24 @@ void SKGOperationPluginWidget::onRefreshInformationZone()
     QApplication::restoreOverrideCursor();
 }
 
+void SKGOperationPluginWidget::onAccountChanged()
+{
+    SKGTRACEIN ( 1, "SKGOperationPluginWidget::onFilterChanged" );
+    if (ui.kDisplayAccountCombo->currentIndex() != 0)
+    {
+        //Get account object
+        SKGAccountObject act(getDocument());
+        SKGError err=act.setName(ui.kDisplayAccountCombo->text());
+        if (err.isSucceeded()) err=act.load();
+
+        //Get unit
+        SKGUnitObject unit;
+        if (err.isSucceeded()) err=act.getUnit(unit);
+        if (err.isSucceeded() && !unit.getSymbol().isEmpty()) ui.kUnitEdit->setText(unit.getSymbol());
+    }
+    onFilterChanged();
+}
+
 void SKGOperationPluginWidget::onFilterChanged()
 {
     SKGTRACEIN ( 1, "SKGOperationPluginWidget::onFilterChanged" );
@@ -2067,28 +2097,76 @@ void SKGOperationPluginWidget::onRotateAccountTools()
     SKGTRACEIN ( 10, "SKGOperationPluginWidget::onRotateAccountTools" );
     if ( modeInfoZone==0 )
     {
-        //Switch to reconciliation mode
-        ui.kReconciliatorFrame2->show();
-        ui.kInfo->hide();
-        modeInfoZone=1;
+        displayReconciliationInfo();
     }
     else if ( modeInfoZone==1 )
     {
-        //Switch to information on selection mode
-        ui.kReconciliatorFrame2->hide();
-        ui.kInfo->show();
-        modeInfoZone=2;
+        displaySelectionAmount();
     }
     else
     {
-        //Switch to information mode
-        ui.kReconciliatorFrame2->hide();
-        ui.kInfo->show();
-        modeInfoZone=0;
+        displayBalance();
     }
+}
+
+
+void SKGOperationPluginWidget::displayBalance()
+{
+    ui.kReconciliatorFrame2->hide();
+    ui.kInfo->show();
+    modeInfoZone=0;
     onRefreshInformationZone();
 }
 
+void SKGOperationPluginWidget::displayReconciliationInfo()
+{
+    if (ui.kDisplayAccountCombo->currentIndex() != 0)
+    {
+        // Only show reconciliation info if only one account is displayed
+        ui.kReconciliatorFrame2->show();
+        ui.kInfo->hide();
+        modeInfoZone=1;
+        onRefreshInformationZone();
+    }
+    else
+    {
+        // If more than one account is displayed, skip reconciliation mode
+        // (it doesn't make sense to reconciliate several accounts at once)
+        // and move to the next modeInfoZone
+        modeInfoZone = 1;
+        onRotateAccountTools();
+    }
+}
+
+void SKGOperationPluginWidget::displaySelectionAmount()
+{
+    ui.kReconciliatorFrame2->hide();
+    ui.kInfo->show();
+    modeInfoZone=2;
+    onRefreshInformationZone();
+}
+
+void SKGOperationPluginWidget::onAutoPoint()
+{
+    SKGError err;
+    SKGTRACEINRC ( 10, "SKGOperationPluginWidget::onAutoPoint",err );
+
+    QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
+    {
+        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Auto point account" ), err);
+        SKGAccountObject act(getDocument());
+        err=act.setName(ui.kDisplayAccountCombo->currentText());
+        if ( err.isSucceeded() ) err=act.load();
+        if ( err.isSucceeded() ) err=act.autoReconcile(ui.kReconcilitorAmountEdit->value());
+    }
+    //status bar
+    if ( err.isSucceeded() ) err=SKGError(0, i18nc("Successful message after an user action", "Account auto pointed." ) );
+    QApplication::restoreOverrideCursor();
+
+    //Display error
+    SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
+}
+
 void SKGOperationPluginWidget::onValidatePointedOperations()
 {
     SKGError err;
@@ -2152,7 +2230,7 @@ void SKGOperationPluginWidget::addSubOperationLine ( int row, const QString& cat
     ui.kSubOperationsTable->resizeColumnsToContents();
 }
 
-QWidget* SKGOperationPluginWidget::getWidgetForPrint()
+QWidget* SKGOperationPluginWidget::mainWidget() const
 {
     return ui.kOperationView;
 }
@@ -2204,9 +2282,4 @@ void SKGOperationPluginWidget::activateEditor()
     ui.kPayeeEdit->setFocus();
 }
 
-QWidget* SKGOperationPluginWidget::zoomableWidget() const
-{
-    return ui.kOperationView;
-}
-
 #include "skgoperationpluginwidget.moc"
