@@ -51,18 +51,6 @@ public:
      */
     virtual ~SKGOperationPluginWidget();
 
-    /**
-     * Get the current selection
-     * @return selected objects
-     */
-    virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects();
-
-    /**
-     * Get the number of seleted object
-     * @return number of selected objects
-     */
-    virtual int getNbSelectedObjects();
-
     /**
      * Get the table view
      * @return the table view
@@ -92,10 +80,10 @@ public:
     virtual QString getDefaultStateAttribute();
 
     /**
-     * Get the widget must be printed
+     * Get the main widget
      * @return a widget
      */
-    virtual QWidget* getWidgetForPrint();
+    virtual QWidget* mainWidget() const;
 
     /**
      * Set or not the template mode
@@ -120,13 +108,6 @@ public:
      */
     virtual void activateEditor();
 
-    /**
-     * Get the zoomable widget. MUST BE OVERWRITTEN
-     * By Overwritting this function, you don't have to implement following ones.
-     * @return the tree view.
-     */
-    virtual QWidget* zoomableWidget() const;
-
 protected:
     /**
      * Event filtering
@@ -136,12 +117,13 @@ protected:
      */
     virtual bool eventFilter ( QObject *object, QEvent *event );
 
-private slots:
+private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
     void onOperationCreatorModified();
     void onAddOperationClicked();
     void onUpdateOperationClicked();
     void onFilterChanged();
+    void onAccountChanged();
     void onResetInternalFilter();
     void onSelectionChanged();
     void onFocusChanged();
@@ -155,7 +137,11 @@ private slots:
     void onValidatePointedOperations();
     void onBtnModeClicked();
     void onTemplateModeClicked();
+    void onAutoPoint();
     void cleanEditor();
+    void displaySelectionAmount();
+    void displayReconciliationInfo();
+    void displayBalance();
 
 private:
     Q_DISABLE_COPY ( SKGOperationPluginWidget );
