@@ -27,6 +27,8 @@
 class SKGReportPluginWidget;
 class SKGDocumentBank;
 
+class KAction;
+
 /**
  * This file is Skrooge plugin for bank management
  */
@@ -60,15 +62,18 @@ public:
      */
     virtual void setState(const QString& iState);
 
-private slots:
+private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
     void onOpen();
+    void onRenameTitle();
 
 private:
     Q_DISABLE_COPY ( SKGReportBoardWidget );
 
     Ui::skgreportboardwidget_board ui;;
     SKGReportPluginWidget* graph;
+
+    KAction* menuRename;
 };
 
 #endif // SKGREPORTBOARDWIDGET_H
