@@ -149,7 +149,7 @@ int SKGReportPlugin::getOrder() const
 QStringList SKGReportPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... you can double click on a value in \"%1\" to show corresponding operations.</p>", title() ) );
+    output.push_back(i18nc("Description of a tips", "<p>... you can double click on a value in '%1' to show corresponding operations.</p>", title() ) );
     output.push_back(i18nc("Description of a tips", "<p>... you can open reports for selections made in other pages.</p>" ) );
     output.push_back(i18nc("Description of a tips", "<p>... you can export reports in many formats.</p>" ) );
     return output;
@@ -285,8 +285,10 @@ void SKGReportPlugin::actionOpenReport()
             root.setAttribute ( "operationWhereClause", wc );
             root.setAttribute ( "title", title );
             root.setAttribute ( "title_icon", icon() );
+            root.setAttribute ( "period", "0" );
             SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge report plugin" ), -1, doc.toString() );
         }
     }
 }
+
 #include "skgreportplugin.moc"
