@@ -130,7 +130,7 @@ public:
      */
     virtual bool isInContext() const;
 
-private slots:
+private Q_SLOTS:
     void actionOpenReport();
 
 private:
