@@ -23,6 +23,7 @@
 #include "skgmainpanel.h"
 #include "skgbankincludes.h"
 #include "skgtraces.h"
+#include "skgcolorbutton.h"
 
 #include <klocale.h>
 #include <kmenu.h>
@@ -61,6 +62,7 @@ SKGReportPluginWidget::SKGReportPluginWidget ( SKGDocumentBank* iDocument, bool
     ui.kForecastCmb->addItem ( i18nc ( "Noun","None" ) );
     ui.kForecastCmb->addItem ( KIcon ( "chronometer" ), i18nc ( "Noun","Schedule" ) );
     ui.kForecastCmb->addItem ( KIcon ( "applications-education-mathematics" ), i18nc ( "Noun","Moving average" ) );
+    ui.kForecastCmb->addItem ( KIcon ( "applications-education-mathematics" ), i18nc ( "Noun","Weighted moving average" ) );
 
     //Build contextual menu
     KMenu* tableMenu=ui.kTableWithGraph->getTableContextualMenu();
@@ -83,7 +85,14 @@ SKGReportPluginWidget::SKGReportPluginWidget ( SKGDocumentBank* iDocument, bool
 
     //Init comboboxes
     AttsForColumns << "d_date" << "d_DATEWEEK" << "d_DATEMONTH" << "d_DATEQUARTER" << "d_DATESEMESTER" << "d_DATEYEAR" << "";
-    AttsForLines << "t_REALCATEGORY" << "t_payee" << "t_mode" << "t_TYPEEXPENSENLS" << "t_status" << "t_ACCOUNTTYPE" << "t_UNITTYPE" << "t_REALREFUND";
+    AttsForLines << "t_REALCATEGORY" << "t_PAYEE" << "t_mode" << "t_TYPEEXPENSENLS" << "t_status" << "t_ACCOUNTTYPE" << "t_UNITTYPE" << "t_REALREFUND";
+
+    //Adding properties
+    QStringList properties;
+    SKGServices::getDistinctValues(iDocument, "parameters", "t_name", "t_uuid_parent like '%-operation'", properties);
+    int nb=properties.count();
+    for (int i=0; i<nb; ++i)
+        AttsForLines.push_back("p_"+properties.at(i));
     AttsForColumns+=AttsForLines;
 
 
@@ -202,10 +211,10 @@ QString SKGReportPluginWidget::getState()
     root.setAttribute ( "lines", AttsForLines.value ( ui.kLines->currentIndex() ) );
     root.setAttribute ( "mode", SKGServices::intToString ( ui.kMode->currentIndex() ) );
     root.setAttribute ( "period", SKGServices::intToString ( ui.kPeriod->currentIndex() ) );
-    if(ui.kPeriod->currentIndex() ==4)
+    if (ui.kPeriod->currentIndex() ==4)
     {
-	root.setAttribute ( "date_begin", SKGServices::intToString ( ui.kDateBegin->date().toJulianDay() ) );
-	root.setAttribute ( "date_end", SKGServices::intToString ( ui.kDateEnd->date().toJulianDay() ) );
+        root.setAttribute ( "date_begin", SKGServices::intToString ( ui.kDateBegin->date().toJulianDay() ) );
+        root.setAttribute ( "date_end", SKGServices::intToString ( ui.kDateEnd->date().toJulianDay() ) );
     }
     root.setAttribute ( "interval", SKGServices::intToString ( ui.kInterval->currentIndex() ) );
     root.setAttribute ( "nb_intervals",SKGServices::intToString ( ui.kNbIntervals->value() ) );
@@ -311,16 +320,14 @@ void SKGReportPluginWidget::setState ( const QString& iState )
     }
 }
 
-
-
 QString SKGReportPluginWidget::getDefaultStateAttribute()
 {
     return "SKGREPORT_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGReportPluginWidget::getWidgetForPrint()
+QWidget* SKGReportPluginWidget::zoomableWidget() const
 {
-    return this;
+    return NULL;
 }
 
 void SKGReportPluginWidget::getWhereClauseAndTitleForSelection ( int row, int column, QString& oWc, QString& oTitle )
@@ -330,15 +337,20 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection ( int row, int co
     QString title;
     if ( ui.kTitle->isVisible() ) oTitle=ui.kTitle->text() +'\n';
 
-    SKGTableWithGraph::DisplayAdditionalFlag mode=ui.kTableWithGraph->getAdditionnalDisplayMode();
+    SKGTableWithGraph::DisplayAdditionalFlag mode=ui.kTableWithGraph->getAdditionalDisplayMode();
 
     //Condition on line attribute
     oTitle+=i18nc ( "Noun, a list of items", "Sub operations with " );
     if ( mode==SKGTableWithGraph::NONE || row+1!=ui.kTableWithGraph->table()->rowCount() )
     {
         QString att=AttsForLines[ui.kLines->currentIndex() ];
+        if (att.startsWith(QLatin1String("p_")))
+        {
+            QString propertyName=att.right(att.length()-2);
+            att="(SELECT t_value FROM parameters WHERE t_uuid_parent=v_operation_consolidated.id||'-operation' AND t_name='"+propertyName+"')";
+        }
         oWc=att;
-        QString lineVal=ui.kTableWithGraph->table()->item ( row, 0 )->text();
+        QString lineVal=((SKGColorButton*) ui.kTableWithGraph->table()->cellWidget ( row, 0 ))->text();
         if ( lineVal.isEmpty() )
         {
             oWc+=" IS NULL OR "+att+"=''";
@@ -358,6 +370,11 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection ( int row, int co
     if ( column!=0 && column<nbCol )
     {
         QString att=AttsForColumns[ui.kColumns->currentIndex() ];
+        if (att.startsWith(QLatin1String("p_")))
+        {
+            QString propertyName=att.right(att.length()-2);
+            att="(SELECT t_value FROM parameters WHERE t_uuid_parent=v_operation_consolidated.id||'-operation' AND t_name='"+propertyName+"')";
+        }
         if ( !att.isEmpty() )
         {
             if ( !oWc.isEmpty() )
@@ -426,7 +443,7 @@ void SKGReportPluginWidget::onDoubleClick ( int row, int column )
         doc.appendChild ( root );
         root.setAttribute ( "sqlOrder", "SELECT * from v_operation_consolidated WHERE "+wc );
 
-        SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge debug plugin" ), -1, doc.toString() );
+        SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Debug plugin" ), -1, doc.toString() );
     }
     else
     {
@@ -446,7 +463,7 @@ void SKGReportPluginWidget::onDoubleClick ( int row, int column )
         root.setAttribute ( "title_icon", "view-statistics" );
         root.setAttribute ( "currentPage", "-1" );
 
-        SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
+        SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
     }
 }
 
@@ -468,7 +485,7 @@ void SKGReportPluginWidget::onOpenReport()
         root.setAttribute ( "operationWhereClause", wc );
         root.setAttribute ( "title", title );
         root.setAttribute ( "title_icon", "view-statistics" );
-        SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge report plugin" ), -1, doc.toString() );
+        SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge report plugin" ), -1, doc.toString() );
     }
 }
 
@@ -584,10 +601,10 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause ( QString* oWhereClaus
         }
         ui.kDateBegin->setDate ( a );
         ui.kDateEnd->setDate ( b );
-        wc = "strftime("+ strfFormat + ",d_date)>=strftime(" + strfFormat + ",date('now', '-" + SKGServices::intToString ( val ) + ' ' + sqlInterval + "'))";
-	if(ui.kForecastCmb->currentIndex()!=1) wc+=" AND strftime("+ strfFormat + ",d_date)<=strftime(" + strfFormat + ",date('now', '-" + SKGServices::intToString ( one ) + ' ' + sqlInterval + "'))"; //For forecast based on scheduled operations
-        if ( oWhereClausForPreviousData ) *oWhereClausForPreviousData="strftime(" + strfFormat + ",d_date) < strftime(" + strfFormat + ",date('now', '-" + SKGServices::intToString ( val ) + ' ' + sqlInterval + "'))";
-        if ( oWhereClausForForecastData ) *oWhereClausForForecastData="strftime(" + strfFormat + ",d_date) > strftime(" + strfFormat + ",date('now', '-" + SKGServices::intToString ( one ) + ' ' + sqlInterval + "'))";
+        wc = "strftime("+ strfFormat + ",d_date)>=strftime(" + strfFormat + ",date('now','start of month', '-" + SKGServices::intToString ( val ) + ' ' + sqlInterval + "'))";
+        if (ui.kForecastCmb->currentIndex()!=1) wc+=" AND strftime("+ strfFormat + ",d_date)<=strftime(" + strfFormat + ",date('now','start of month', '-" + SKGServices::intToString ( one ) + ' ' + sqlInterval + "'))"; //For forecast based on scheduled operations
+        if ( oWhereClausForPreviousData ) *oWhereClausForPreviousData="strftime(" + strfFormat + ",d_date) < strftime(" + strfFormat + ",date('now','start of month', '-" + SKGServices::intToString ( val ) + ' ' + sqlInterval + "'))";
+        if ( oWhereClausForForecastData ) *oWhereClausForForecastData="strftime(" + strfFormat + ",d_date) > strftime(" + strfFormat + ",date('now','start of month', '-" + SKGServices::intToString ( one ) + ' ' + sqlInterval + "'))";
         break;
     case 3:
         //Last Interval
@@ -614,20 +631,20 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause ( QString* oWhereClaus
         ui.kDateBegin->setDate ( a );
         ui.kDateEnd->setDate ( b );
         wc = "d_date > date('now','-" + SKGServices::intToString ( val ) + ' ' + sqlInterval + "')";
-	if(ui.kForecastCmb->currentIndex()!=1) wc+=" AND d_date<=date('now')"; //For forecast based on scheduled operations
+        if (ui.kForecastCmb->currentIndex()!=1) wc+=" AND d_date<=date('now')"; //For forecast based on scheduled operations
         if ( oWhereClausForPreviousData ) *oWhereClausForPreviousData="d_date <= date('now','-" + SKGServices::intToString ( val ) + ' ' + sqlInterval + "')";
         if ( oWhereClausForForecastData ) *oWhereClausForForecastData="d_date > date('now')";
         break;
     case 4:
         // Custom Date
         wc="d_date>='"+SKGServices::dateToSqlString ( QDateTime ( ui.kDateBegin->date() ) ) + '\'';
-        if(ui.kForecastCmb->currentIndex()!=1) wc+="AND d_date<='"+SKGServices::dateToSqlString ( QDateTime ( ui.kDateEnd->date() ) ) + '\''; //For forecast based on scheduled operations
+        if (ui.kForecastCmb->currentIndex()!=1) wc+="AND d_date<='"+SKGServices::dateToSqlString ( QDateTime ( ui.kDateEnd->date() ) ) + '\''; //For forecast based on scheduled operations
         if ( oWhereClausForPreviousData ) *oWhereClausForPreviousData="d_date<'"+SKGServices::dateToSqlString ( QDateTime ( ui.kDateBegin->date() ) ) + '\'';
         if ( oWhereClausForForecastData ) *oWhereClausForForecastData="d_date>'"+SKGServices::dateToSqlString ( QDateTime ( ui.kDateEnd->date() ) ) + '\'';
         break;
     default:
         // Take all dates
-	a=a.addYears ( -1 );
+        a=a.addYears ( -1 );
         ui.kDateBegin->setDate ( a );
         ui.kDateEnd->setDate ( b );
         wc = "1=1";
@@ -754,40 +771,53 @@ void SKGReportPluginWidget::dataModified ( const QString& iTableName, int iIdTra
                 //Mode history ?
                 bool modeHistory= ( ui.kMode->currentIndex() >0 );
 
-		//Get condition (must be done before forecast on scheduled operations)
-		int nbVirtualColumn=0;
+                //Get condition (must be done before forecast on scheduled operations)
+                int nbVirtualColumn=0;
                 QString conditionPrevious;
                 QString conditionForecast;
                 QString condition=getConsolidatedWhereClause ( &conditionPrevious, &conditionForecast );
+                int forecastMode=ui.kForecastCmb->currentIndex();
 
-		//Compute forecast on scheduled operations
-		if (ui.kForecastCmb->currentIndex() ==1 )
-		{
-		  //Create scheduled operation
-		  getDocument()->beginTransaction ( "#INTERNAL#", 2 );
-		  int nbInserted=0;
-		  int nbDays=ui.kDateBegin->date().daysTo(QDate::currentDate());
-		  nbDays=(nbDays*ui.kForecastValue->value())/FORECASTMAX;
-		  QDate lastDate=QDate::currentDate().addDays(nbDays);
-		  SKGRecurrentOperationObject::process(getDocument(), nbInserted, lastDate);
-		  ui.kForecastValue->setToolTip(SKGServices::dateToSqlString(QDateTime(lastDate)));
-		}
-		else
-		{
-		  ui.kForecastValue->setToolTip("");
-		  conditionForecast="1=0";
-		}
+                //Compute forecast on scheduled operations
+                if (forecastMode ==1 )
+                {
+                    //Create scheduled operation
+                    getDocument()->beginTransaction ( "#INTERNAL#", 2 );
+                    int nbInserted=0;
+                    int nbDays=ui.kDateBegin->date().daysTo(QDate::currentDate());
+                    nbDays=(nbDays*ui.kForecastValue->value())/FORECASTMAX;
+                    QDate lastDate=QDate::currentDate().addDays(nbDays);
+                    SKGRecurrentOperationObject::process(getDocument(), nbInserted, lastDate);
+                    ui.kForecastValue->setToolTip(SKGServices::dateToSqlString(QDateTime(lastDate)));
+                }
+                else
+                {
+                    ui.kForecastValue->setToolTip("");
+                    conditionForecast="1=0";
+                }
 
                 //Execute sql order
                 SKGStringListList table;
-                QString tableName="v_operation_consolidated";
-                if ( modeHistory && !AttsForColumns.at ( col ).isEmpty() )
+                QString tableName="v_operation_consolidated as v_table";
+                QString attCol=AttsForColumns[col ];
+                if (attCol.startsWith(QLatin1String("p_")))
+                {
+                    QString propertyName=attCol.right(attCol.length()-2);
+                    attCol="(SELECT t_value FROM parameters WHERE t_uuid_parent=v_table.id||'-operation' AND t_name='"+propertyName+"')";
+                }
+                QString attLine=AttsForLines.at ( line );
+                if (attLine.startsWith(QLatin1String("p_")))
+                {
+                    QString propertyName=attLine.right(attLine.length()-2);
+                    attLine="(SELECT t_value FROM parameters WHERE t_uuid_parent=v_table.id||'-operation' AND t_name='"+propertyName+"')";
+                }
+                if ( modeHistory && !attCol.isEmpty() )
                 {
                     tableName="(SELECT ";
-                    if ( AttsForColumns.at ( col ) !="d_date" ) tableName+="(CASE WHEN "+conditionPrevious+" THEN '0000' ELSE d_date END) AS d_date, ";
-                    tableName+="(CASE WHEN "+conditionPrevious+" THEN '0000' ELSE "+AttsForColumns.at ( col ) +"||(CASE WHEN "+conditionForecast+" THEN '999' ELSE '' END) END) AS "+AttsForColumns.at ( col ) +",* FROM v_operation_consolidated)";
+                    if ( attCol !="d_date" ) tableName+="(CASE WHEN "+conditionPrevious+" THEN '0000' ELSE d_date END) AS d_date, ";
+                    tableName+="(CASE WHEN "+conditionPrevious+" THEN '0000' ELSE "+attCol +"||(CASE WHEN "+conditionForecast+" THEN '999' ELSE '' END) END) AS "+AttsForColumns[col ] +",* FROM v_operation_consolidated) as v_table";
                 }
-                err=getDocument()->getConsolidatedView ( tableName, AttsForColumns.at ( col ), AttsForLines.at ( line ), "f_REALCURRENTAMOUNT", "TOTAL", condition, table );
+                err=getDocument()->getConsolidatedView ( tableName, attCol, attLine, "f_REALCURRENTAMOUNT", "TOTAL", condition, table );
                 IFSKGTRACEL ( 10 )
                 {
                     QStringList dump=SKGServices::tableToDump ( table, SKGServices::DUMP_TEXT );
@@ -798,26 +828,26 @@ void SKGReportPluginWidget::dataModified ( const QString& iTableName, int iIdTra
                     }
                 }
 
-		if (ui.kForecastCmb->currentIndex() ==1 )
-		{
-		  //Rollback create operations
-		  getDocument()->endTransaction(false);
+                if (forecastMode ==1 )
+                {
+                    //Rollback create operations
+                    getDocument()->endTransaction(false);
 
-		  //Compute nb date in futur
-                  QStringList line1=table.at ( 0 );
-		  int nbCol=line1.count();
-		  for ( int i=0; i<nbCol; ++i )
-		  {
-		      QString title=line1.at(i);
-		      if(title.endsWith(QLatin1String("999")))
-		      {
-			title=title.left(title.count()-3);
-			line1.replace ( i, title );
-			++nbVirtualColumn;
-		      }
-		  }
-		  table.replace ( 0, line1 );
-		}
+                    //Compute nb date in futur
+                    QStringList line1=table.at ( 0 );
+                    int nbCol=line1.count();
+                    for ( int i=0; i<nbCol; ++i )
+                    {
+                        QString title=line1.at(i);
+                        if (title.endsWith(QLatin1String("999")))
+                        {
+                            title=title.left(title.count()-3);
+                            line1.replace ( i, title );
+                            ++nbVirtualColumn;
+                        }
+                    }
+                    table.replace ( 0, line1 );
+                }
 
                 if ( err.isSucceeded() )
                 {
@@ -831,51 +861,60 @@ void SKGReportPluginWidget::dataModified ( const QString& iTableName, int iIdTra
 
                     //Compute forecast on average
                     int nbLines=table.count();
-                    if ( nbLines && ui.kForecastCmb->currentIndex() ==2 )
+                    if ( nbLines && (forecastMode==2 || forecastMode==3) )
                     {
-			QStringList newLine=table.at ( 0 );
-			int nbVals=newLine.count()-1;
-		        int pourcent=ui.kForecastValue->value();
-			if(nbVals>=3 && pourcent>0)
-			{
-			    //Compute nb value to add
-			    nbVirtualColumn=pourcent*nbVals/FORECASTMAX;
+                        QStringList newLine=table.at ( 0 );
+                        int nbVals=newLine.count()-1;
+                        int pourcent=ui.kForecastValue->value();
+                        if (nbVals>=3 && pourcent>0)
+                        {
+                            //Compute nb value to add
+                            nbVirtualColumn=pourcent*nbVals/FORECASTMAX;
 
-			    //Build header
-			    for ( int i=0; i<nbVirtualColumn; ++i )
-			    {
-				newLine.push_back ( i18nc ( "Noun","N %1", (i+1) ) );
-			    }
-			    table.replace ( 0, newLine );
+                            //Build header
+                            for ( int i=0; i<nbVirtualColumn; ++i )
+                            {
+                                newLine.push_back ( i18nc ( "Noun","N %1", (i+1) ) );
+                            }
+                            table.replace ( 0, newLine );
 
-			    //Build values
-			    for ( int j=1; j<nbLines; ++j )
-			    {
-				QStringList newLine=table.at ( j );
-				for ( int i=0; i<nbVirtualColumn; ++i )
-				{
-				    //Moving average
-				    double nv=0;
-				    for(int k=0; k<nbVirtualColumn; ++k)
-				    {
-					nv+=SKGServices::stringToDouble ( newLine.at(nbVals+i-k) );
-				    }
-				    newLine.push_back (SKGServices::doubleToString(nv/nbVirtualColumn));
-				}
-				table.replace ( j, newLine );
-			    }
-			}
+                            //Build values
+                            for ( int j=1; j<nbLines; ++j )
+                            {
+                                QStringList newLine=table.at ( j );
+                                for ( int i=0; i<nbVirtualColumn; ++i )
+                                {
+                                    //Moving average
+                                    double nv=0;
+                                    double weight=0;
+                                    for (int k=0; k<nbVirtualColumn; ++k)
+                                    {
+                                        if (forecastMode==2)
+                                        {
+                                            //Simple mode
+                                            nv+=SKGServices::stringToDouble ( newLine.at(nbVals+i-k) );
+                                            ++weight;
+                                        }
+                                        else
+                                        {
+                                            //Weighted mode
+                                            nv+=(nbVirtualColumn-k)*SKGServices::stringToDouble ( newLine.at(nbVals+i-k) );
+                                            weight+=nbVirtualColumn-k;
+                                        }
+                                    }
+                                    newLine.push_back (SKGServices::doubleToString(nv/weight));
+                                }
+                                table.replace ( j, newLine );
+                            }
+                        }
                     }
 
-                    //Create history
-                    if ( modeHistory ) table=SKGReportPluginWidget::getHistorizedTable ( table );
-
                     //Create grouped by lines table
                     int nbLevelLineMax=0;
                     {
-                        int nbCols=-1;
                         SKGStringListList groupedByLineTable=table;
                         {
+                            int nbCols=-1;
                             QString previousLineName="###";
                             if ( groupedByLineTable.count() )
                             {
@@ -911,9 +950,9 @@ void SKGReportPluginWidget::dataModified ( const QString& iTableName, int iIdTra
                                         QString valstring1=line.at ( k );
                                         QString valstring2=groupedByLineTable.at ( i-1 ).at ( k );
 
-                                        double sum2=0;
                                         if ( !valstring1.isEmpty() || !valstring2.isEmpty() )
                                         {
+                                            double sum2=0;
                                             if ( !valstring1.isEmpty() ) sum2+=SKGServices::stringToDouble ( valstring1 );
                                             if ( !valstring2.isEmpty() ) sum2+=SKGServices::stringToDouble ( valstring2 );
                                             newLine.push_back ( SKGServices::doubleToString ( sum2 ) );
@@ -988,9 +1027,9 @@ void SKGReportPluginWidget::dataModified ( const QString& iTableName, int iIdTra
                                         QString valstring1=newLine.at ( i );
                                         QString valstring2=newLine.at ( i-1 );
 
-                                        double sum2=0;
                                         if ( !valstring1.isEmpty() || !valstring2.isEmpty() )
                                         {
+                                            double sum2=0;
                                             if ( !valstring1.isEmpty() ) sum2+=SKGServices::stringToDouble ( valstring1 );
                                             if ( !valstring2.isEmpty() ) sum2+=SKGServices::stringToDouble ( valstring2 );
                                             newLine.replace ( i-1, SKGServices::doubleToString ( sum2 ) );
@@ -1020,9 +1059,12 @@ void SKGReportPluginWidget::dataModified ( const QString& iTableName, int iIdTra
                         table=groupedByColTable;
                     }
 
+                    //Create history (must be done after groups)
+                    if ( modeHistory ) table=SKGReportPluginWidget::getHistorizedTable ( table );
+
                     //Set data
-                    SKGServices::SKGUnitInfo primaryUnit= ( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit();
-                    SKGServices::SKGUnitInfo secondaryUnit= ( ( SKGDocumentBank* ) getDocument() )->getSecondaryUnit();
+                    SKGServices::SKGUnitInfo primaryUnit= static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+                    SKGServices::SKGUnitInfo secondaryUnit= static_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
 
                     SKGTableWithGraph::DisplayAdditionalFlag dmode=SKGTableWithGraph::NONE;
                     if ( AttsForColumns.at ( col ).startsWith ( QLatin1String ( "d_" ) ) ) dmode|=SKGTableWithGraph::AVERAGE|SKGTableWithGraph::LIMITS;
