@@ -73,10 +73,11 @@ public:
     virtual QString getDefaultStateAttribute();
 
     /**
-     * Get the widget must be printed
-     * @return a widget
+     * Get the zoomable widget. MUST BE OVERWRITTEN
+     * By Overwritting this function, you don't have to implement following ones.
+     * @return the tree view.
      */
-    virtual QWidget* getWidgetForPrint();
+    virtual QWidget* zoomableWidget() const;
 
     /**
      * Create an historized table.
@@ -85,7 +86,7 @@ public:
      */
     static SKGStringListList getHistorizedTable ( const SKGStringListList& iTable );
 
-public slots:
+public Q_SLOTS:
     /**
      * Refresh the panel
      */
@@ -99,7 +100,7 @@ public slots:
     */
     virtual void dataModified ( const QString& iTableName, int iIdTransaction );
 
-private slots:
+private Q_SLOTS:
     void onDoubleClick ( int row, int column );
     void onOpenReport();
     void onSelectionChanged();
