@@ -73,7 +73,14 @@ void SKGScheduledBoardWidget::dataModified ( const QString& iTableName, int iIdT
                 for ( int i=0; i<nb; ++i )
                 {
                     SKGRecurrentOperationObject obj=objs.at ( i );
-                    html+=SKGServices::stringToHtml ( obj.getDisplayName() ) +"<br>";
+
+                    bool bold=false;
+                    if (obj.isWarnEnabled() &&  QDate::currentDate()>=obj.getDate().addDays(-obj.getWarnDays())) bold=true;
+
+                    if (bold) html+="<b>";
+                    html+=SKGServices::stringToHtml ( obj.getDisplayName() );
+                    if (bold) html+="</b>";
+                    html+="<br>";
                 }
             }
             else
