@@ -29,42 +29,42 @@
  */
 class SKGScheduledBoardWidget : public SKGWidget
 {
-        Q_OBJECT
+    Q_OBJECT
 
 public:
-        /**
-         * Default Constructor
-         */
-        SKGScheduledBoardWidget (SKGDocument* iDocument );
+    /**
+     * Default Constructor
+     */
+    SKGScheduledBoardWidget (SKGDocument* iDocument );
 
-        /**
-         * Default Destructor
-         */
-        virtual ~SKGScheduledBoardWidget();
+    /**
+     * Default Destructor
+     */
+    virtual ~SKGScheduledBoardWidget();
 
-        /**
-         * Get the current state
-         * MUST BE OVERWRITTEN
-         * @return a string containing all information needed to set the same state.
-         * Could be an XML stream
-         */
-        virtual QString getState();
+    /**
+     * Get the current state
+     * MUST BE OVERWRITTEN
+     * @return a string containing all information needed to set the same state.
+     * Could be an XML stream
+     */
+    virtual QString getState();
 
-        /**
-         * Set the current state
-         * MUST BE OVERWRITTEN
-         * @param iState must be interpreted to set the state of the widget
-         */
-        virtual void setState(const QString& iState);
+    /**
+     * Set the current state
+     * MUST BE OVERWRITTEN
+     * @param iState must be interpreted to set the state of the widget
+     */
+    virtual void setState(const QString& iState);
 
-private slots:
-        void dataModified(const QString& iTableName, int iIdTransaction);
-        void onOpen(const QString& iLink);
+private Q_SLOTS:
+    void dataModified(const QString& iTableName, int iIdTransaction);
+    void onOpen(const QString& iLink);
 
 private:
-        Q_DISABLE_COPY ( SKGScheduledBoardWidget );
+    Q_DISABLE_COPY ( SKGScheduledBoardWidget );
 
-        Ui::skgscheduledplugin_board ui;;
+    Ui::skgscheduledplugin_board ui;;
 };
 
 #endif // SKGSCHEDULEDBOARDWIDGET_H
