@@ -157,7 +157,7 @@ public:
      */
     virtual bool isEnabled() const;
 
-private slots:
+private Q_SLOTS:
     void actionScheduleOperation();
 
 private:
