@@ -97,16 +97,6 @@ bool SKGScheduledPluginWidget::eventFilter ( QObject *object, QEvent *event )
     return false;
 }
 
-SKGObjectBase::SKGListSKGObjectBase SKGScheduledPluginWidget::getSelectedObjects()
-{
-    return ui.kView->getSelectedObjects();
-}
-
-int SKGScheduledPluginWidget::getNbSelectedObjects()
-{
-    return ui.kView->getNbSelectedObjects();
-}
-
 QString SKGScheduledPluginWidget::getState()
 {
     SKGTRACEIN ( 10, "SKGScheduledPluginWidget::getState" );
@@ -144,7 +134,7 @@ QString SKGScheduledPluginWidget::getDefaultStateAttribute()
     return "SKGSCHEDULED_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGScheduledPluginWidget::getWidgetForPrint()
+QWidget* SKGScheduledPluginWidget::mainWidget() const
 {
     return ui.kView;
 }
@@ -242,7 +232,7 @@ void SKGScheduledPluginWidget::onSelectionChanged()
         ui.kNbTimes->setCheckState ( recOp.hasTimeLimit() ? Qt::Checked : Qt::Unchecked );
     }
 
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 }
 
 void SKGScheduledPluginWidget::onNbOccurrenceChanged()
@@ -362,10 +352,6 @@ void SKGScheduledPluginWidget::onProcess()
     SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
 }
 
-QWidget* SKGScheduledPluginWidget::zoomableWidget() const
-{
-    return ui.kView;
-}
 #include "skgscheduledpluginwidget.moc"
 
 
