@@ -31,44 +31,44 @@ class KAction;
  */
 class SKGAlarmBoardWidget : public SKGWidget
 {
-        Q_OBJECT
+    Q_OBJECT
 
 public:
-        /**
-         * Default Constructor
-         */
-        SKGAlarmBoardWidget (SKGDocument* iDocument );
+    /**
+     * Default Constructor
+     */
+    SKGAlarmBoardWidget (SKGDocument* iDocument );
 
-        /**
-         * Default Destructor
-         */
-        virtual ~SKGAlarmBoardWidget();
+    /**
+     * Default Destructor
+     */
+    virtual ~SKGAlarmBoardWidget();
 
-        /**
-         * Get the current state
-         * MUST BE OVERWRITTEN
-         * @return a string containing all information needed to set the same state.
-         * Could be an XML stream
-         */
-        virtual QString getState();
+    /**
+     * Get the current state
+     * MUST BE OVERWRITTEN
+     * @return a string containing all information needed to set the same state.
+     * Could be an XML stream
+     */
+    virtual QString getState();
 
-        /**
-         * Set the current state
-         * MUST BE OVERWRITTEN
-         * @param iState must be interpreted to set the state of the widget
-         */
-        virtual void setState(const QString& iState);
+    /**
+     * Set the current state
+     * MUST BE OVERWRITTEN
+     * @param iState must be interpreted to set the state of the widget
+     */
+    virtual void setState(const QString& iState);
 
-private slots:
-        void dataModified(const QString& iTableName="", int iIdTransaction=0);
-        void onOpen(const QString& iLink="___");
+private Q_SLOTS:
+    void dataModified(const QString& iTableName="", int iIdTransaction=0);
+    void onOpen(const QString& iLink="___");
 
 private:
-        Q_DISABLE_COPY ( SKGAlarmBoardWidget );
+    Q_DISABLE_COPY ( SKGAlarmBoardWidget );
 
-        Ui::skgalarmplugin_board ui;;
+    Ui::skgalarmplugin_board ui;;
 
-        KAction* menuFavorite;
+    KAction* menuFavorite;
 };
 
 #endif // SKGALARMBOARDWIDGET_H
