@@ -121,10 +121,7 @@ bool SKGSearchPlugin::setupActions ( SKGDocument* iDocument, const QStringList&
     }
 
     //Search
-    searchAction = new KAction(KIcon("edit-find"), i18nc("Verb, delete an item","Find"), this);
-    connect(searchAction, SIGNAL(triggered(bool)), this, SLOT(find()));
-    actionCollection()->addAction( QLatin1String("edit_find"), searchAction );
-    searchAction->setShortcut(Qt::CTRL+Qt::Key_F);
+    searchAction=actionCollection()->addAction(KStandardAction::Find, "edit_find", this, SLOT(find()));
 
     if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_find", searchAction);
 
@@ -405,4 +402,54 @@ bool SKGSearchPlugin::isInContext() const
     return true;
 }
 
+QList< SKGInterfacePlugin::SKGAdvice > SKGSearchPlugin::advices() const
+{
+    QList< SKGInterfacePlugin::SKGAdvice > output;
+
+    //Alarms
+    SKGObjectBase::SKGListSKGObjectBase rules;
+    SKGError err=SKGObjectBase::getObjects ( currentBankDocument, "v_rule", "t_action_type='A' ORDER BY i_ORDER", rules );
+    int nb=rules.count();
+    if ( nb )
+    {
+        SKGDocumentBank* doc=(SKGDocumentBank*) currentBankDocument;
+        SKGServices::SKGUnitInfo primary=doc->getPrimaryUnit();
+
+        for ( int i=0; err.isSucceeded() && i<nb; ++i )
+        {
+            SKGRuleObject rule=rules.at ( i );
+            SKGRuleObject::SKGAlarmInfo alarm=rule.getAlarmInfo();
+
+            double pourcent=100*alarm.Amount/alarm.Limit;
+            if (pourcent>=80)
+            {
+                SKGInterfacePlugin::SKGAdvice ad;
+                ad.uuid="skgsearchplugin_alarm_"+SKGServices::intToString(rule.getID());
+                ad.priority=9;
+                ad.shortMessage=alarm.Message;
+                ad.longMessage=i18nc("Advice on making the best (long)", "Take care to your alarms.<br> %1.<br>%2 / %3", alarm.Message, doc->formatMoney ( alarm.Amount, primary ), doc->formatMoney ( alarm.Limit, primary ));
+                ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Open operations corresponding to this alarm"));
+
+                output.push_back(ad);
+            }
+        }
+    }
+
+    return output;
+}
+
+SKGError SKGSearchPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+{
+    if (currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgsearchplugin_alarm_")))
+    {
+        //Get parameters
+        QString id=iAdviceIdentifier.right(iAdviceIdentifier.length()-22);
+        SKGRuleObject rule(currentBankDocument, SKGServices::stringToInt(id));
+        rule.load();
+        SKGSearchPluginWidget::open(rule);
+        return SKGError();
+    }
+
+    return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
+}
 #include "skgsearchplugin.moc"
