@@ -229,9 +229,9 @@ QString SKGSearchPluginWidget::getDefaultStateAttribute()
     return "SKGSEARCH_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGSearchPluginWidget::getWidgetForPrint()
+QWidget* SKGSearchPluginWidget::mainWidget() const
 {
-    return this;
+    return ui.kView;
 }
 
 SKGObjectBase::SKGListSKGObjectBase SKGSearchPluginWidget::getSelectedObjects()
@@ -389,7 +389,7 @@ void SKGSearchPluginWidget::onSelectionChanged()
 
     onEditorModified();
 
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 }
 
 void SKGSearchPluginWidget::onActionTypeChanged()
@@ -562,7 +562,7 @@ void SKGSearchPluginWidget::onBottom()
     SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
 }
 
-void SKGSearchPluginWidget::open(const SKGRuleObject& iRule) const
+void SKGSearchPluginWidget::open(const SKGRuleObject& iRule)
 {
     _SKGTRACEIN ( 10, "SKGSearchPluginWidget::open" );
 
@@ -585,7 +585,7 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule) const
     {
         //Call operation plugin
         QDomDocument doc ( "SKGML" );
-        doc.setContent ( getDocument()->getParameter ( "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS" ) );
+        doc.setContent ( SKGMainPanel::getMainPanel()->getDocument()->getParameter ( "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS" ) );
         QDomElement root = doc.documentElement();
         if ( root.isNull() )
         {
@@ -612,7 +612,7 @@ void SKGSearchPluginWidget::onDoubleClick()
     if ( selection.count() ==1 )
     {
         SKGRuleObject rule ( selection.at ( 0 ) );
-        open(rule);
+        SKGSearchPluginWidget::open(rule);
     }
 }
 
@@ -702,10 +702,6 @@ void SKGSearchPluginWidget::activateEditor()
     if (getCurrentMode()==-1) setCurrentMode(0);
 }
 
-QWidget* SKGSearchPluginWidget::zoomableWidget() const
-{
-    return ui.kView;
-}
 #include "skgsearchpluginwidget.moc"
 
 
