@@ -41,7 +41,7 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget ( SKGDocument* iDocument )
     ui.kAddButton->setIcon ( KIcon ( "list-add" ) );
     ui.kModifyButton->setIcon ( KIcon ( "dialog-ok-apply" ) );
 
-    objectModel = new SKGObjectModel ( ( SKGDocumentBank* ) getDocument(), "v_refund_display", "1=0", this, "", false );
+    objectModel = new SKGObjectModel ( static_cast<SKGDocumentBank*>(getDocument()), "v_refund_display", "1=0", this, "", false );
     SKGSortFilterProxyModel* modelproxy = new SKGSortFilterProxyModel ( this );
     modelproxy->setSourceModel ( objectModel );
     modelproxy->setSortRole ( Qt::UserRole );
@@ -53,11 +53,10 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget ( SKGDocument* iDocument )
     //Add registered global action in contextual menu
     if ( SKGMainPanel::getMainPanel() )
     {
-        ui.kView->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_delete" ) );
-        QAction* sep=new QAction ( this );
-        sep->setSeparator ( true );
-        ui.kView->insertAction ( 0, sep );
-        ui.kView->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "open_report" ) );
+        ui.kView->insertGlobalAction ( "edit_delete" );
+        ui.kView->insertGlobalAction ();
+        ui.kView->insertGlobalAction ( "edit_find" );
+        ui.kView->insertGlobalAction ( "open_report" );
 
         ui.kView->resizeColumnToContents ( 0 );
     }
@@ -111,7 +110,7 @@ void SKGTrackerPluginWidget::dataModified ( const QString& iTableName, int iIdTr
     if ( iTableName=="refund" || iTableName.isEmpty() )
     {
         //Correction bug 2299394 vvv
-        if ( ui.kView->isAutoResized() ) ui.kView->resizeColumnsToContents();
+        if ( ui.kView->isAutoResized() ) ui.kView->resizeColumnsToContentsDelayed();
         //Correction bug 2299394 ^^^
         onEditorModified();
     }
@@ -130,17 +129,7 @@ void SKGTrackerPluginWidget::onSelectionChanged()
     }
 
     onEditorModified();
-    emit selectionChanged();
-}
-
-SKGObjectBase::SKGListSKGObjectBase SKGTrackerPluginWidget::getSelectedObjects()
-{
-    return ui.kView->getSelectedObjects();
-}
-
-int SKGTrackerPluginWidget::getNbSelectedObjects()
-{
-    return ui.kView->getNbSelectedObjects();
+    Q_EMIT selectionChanged();
 }
 
 QString SKGTrackerPluginWidget::getState()
@@ -187,7 +176,7 @@ QString SKGTrackerPluginWidget::getDefaultStateAttribute()
     return "SKGREFUND_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGTrackerPluginWidget::getWidgetForPrint()
+QWidget* SKGTrackerPluginWidget::mainWidget() const
 {
     return ui.kView;
 }
@@ -220,7 +209,7 @@ void SKGTrackerPluginWidget::onFilterChanged()
         objectModel->refresh();
 
         //Correction bug 2299394 vvv
-        if ( ui.kView->isAutoResized() ) ui.kView->resizeColumnsToContents();
+        if ( ui.kView->isAutoResized() ) ui.kView->resizeColumnsToContentsDelayed();
         //Correction bug 2299394 ^^^
     }
 
@@ -236,16 +225,16 @@ void SKGTrackerPluginWidget::onAddTracker()
     QString name=ui.kNameInput->text();
     SKGTrackerObject tracker;
     {
-        SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Tracker creation [%1]", name )  , err );
+        SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Tracker creation '%1'", name )  , err );
 
-        err=SKGTrackerObject::createTracker ( ( const SKGDocumentBank* ) getDocument(), name, tracker );
+        err=SKGTrackerObject::createTracker ( static_cast<SKGDocumentBank*>(getDocument()), name, tracker );
         if ( err.isSucceeded() ) err=tracker.setComment ( ui.kCommentEdit->text() );
         if ( err.isSucceeded() ) err=tracker.save();
     }
     //status bar
     if ( err.isSucceeded() )
     {
-        err=SKGError ( 0, i18nc ( "Successful message after an user action", "Tracker [%1] created", name ) );
+        err=SKGError ( 0, i18nc ( "Successful message after an user action", "Tracker '%1' created", name ) );
         ui.kView->selectObject ( tracker.getUniqueID() );
     }
     else err.addError ( ERR_FAIL, i18nc ( "Error message", "Tracker creation failed" ) );
@@ -266,7 +255,7 @@ void SKGTrackerPluginWidget::onModifyTracker()
     int nb=selection.count();
     if ( nb==1 )
     {
-        SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Tracker [%1] update", ui.kNameInput->text() )  , err );
+        SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Tracker '%1' update", ui.kNameInput->text() )  , err );
 
         //Modification of category object
         SKGTrackerObject tracker=selection[0];
@@ -275,7 +264,7 @@ void SKGTrackerPluginWidget::onModifyTracker()
         if ( err.isSucceeded() ) err=tracker.save();
 
         //status bar
-        if ( err.isSucceeded() ) err=SKGError ( 0, i18nc ( "Successful message after an user action", "Tracker [%1] updated", ui.kNameInput->text() ) );
+        if ( err.isSucceeded() ) err=SKGError ( 0, i18nc ( "Successful message after an user action", "Tracker '%1' updated", ui.kNameInput->text() ) );
         else err.addError ( ERR_FAIL, i18nc ( "Error message", "Tracker update failed" ) );
     }
     QApplication::restoreOverrideCursor();
@@ -308,7 +297,7 @@ void SKGTrackerPluginWidget::onDoubleClick()
             doc.appendChild ( root );
             root.setAttribute ( "sqlOrder", "SELECT * from v_operation_consolidated WHERE "+wc );
 
-            SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge debug plugin" ), -1, doc.toString() );
+            SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Debug plugin" ), -1, doc.toString() );
         }
         else
         {
@@ -328,7 +317,7 @@ void SKGTrackerPluginWidget::onDoubleClick()
             root.setAttribute ( "title_icon", "skrooge_tracker" );
             root.setAttribute ( "currentPage", "-1" );
 
-            SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
+            SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
         }
     }
 }
@@ -342,6 +331,14 @@ void SKGTrackerPluginWidget::cleanEditor()
     }
 }
 
+void SKGTrackerPluginWidget::activateEditor()
+{
+    ui.kNameInput->setFocus();
+}
+
+bool SKGTrackerPluginWidget::isEditor()
+{
+    return true;
+}
+
 #include "skgtrackerpluginwidget.moc"
-
-
