@@ -31,46 +31,46 @@ class KAction;
  */
 class SKGUnitBoardWidget : public SKGWidget
 {
-        Q_OBJECT
+    Q_OBJECT
 
 public:
-        /**
-         * Default Constructor
-         */
-        SKGUnitBoardWidget (SKGDocument* iDocument );
+    /**
+     * Default Constructor
+     */
+    SKGUnitBoardWidget (SKGDocument* iDocument );
 
-        /**
-         * Default Destructor
-         */
-        virtual ~SKGUnitBoardWidget();
+    /**
+     * Default Destructor
+     */
+    virtual ~SKGUnitBoardWidget();
 
-        /**
-         * Get the current state
-         * MUST BE OVERWRITTEN
-         * @return a string containing all information needed to set the same state.
-         * Could be an XML stream
-         */
-        virtual QString getState();
+    /**
+     * Get the current state
+     * MUST BE OVERWRITTEN
+     * @return a string containing all information needed to set the same state.
+     * Could be an XML stream
+     */
+    virtual QString getState();
 
-        /**
-         * Set the current state
-         * MUST BE OVERWRITTEN
-         * @param iState must be interpreted to set the state of the widget
-         */
-        virtual void setState(const QString& iState);
+    /**
+     * Set the current state
+     * MUST BE OVERWRITTEN
+     * @param iState must be interpreted to set the state of the widget
+     */
+    virtual void setState(const QString& iState);
 
-private slots:
-        void dataModified(const QString& iTableName="", int iIdTransaction=0);
-        void onOpen(const QString& iLink);
+private Q_SLOTS:
+    void dataModified(const QString& iTableName="", int iIdTransaction=0);
+    void onOpen(const QString& iLink);
 
 private:
-        Q_DISABLE_COPY ( SKGUnitBoardWidget );
+    Q_DISABLE_COPY ( SKGUnitBoardWidget );
 
-        Ui::skgunitplugin_board ui;;
+    Ui::skgunitplugin_board ui;;
 
-	KAction* menuIndexes;
-	KAction* menuShares;
-	KAction* menuSharesOwnedOnly;
+    KAction* menuIndexes;
+    KAction* menuShares;
+    KAction* menuSharesOwnedOnly;
 };
 
 #endif // SKGUNITBOARDWIDGET_H
