@@ -205,7 +205,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
         //Correction bug 2299394 ^^^
 
         onUnitCreatorModified();
-        emit selectionChanged();
+        Q_EMIT selectionChanged();
     }
 }
 
@@ -236,7 +236,7 @@ void SKGUnitPluginWidget::onSelectionValueChanged()
             ui.kDateEdit->setDate ( QDate::currentDate() );
             ui.kAmountEdit->setText ( "" );
         }
-        emit selectionChanged();
+        Q_EMIT selectionChanged();
     }
 }
 
@@ -305,7 +305,7 @@ void SKGUnitPluginWidget::onUnitCreatorModified()
     ui.kUnitAdd->setEnabled ( activated || getCurrentMode() ==0 );
     ui.kUnitUpdate->setEnabled ( activated && nbSelect>0 && getCurrentMode() ==1 );
 
-    ui.kValuesBtn->setEnabled ( activated && nbSelect==1 );
+    ui.kValuesBtn->setEnabled ( nbSelect==1 );
     if ( ! ( activated && nbSelect>0 ) && getCurrentMode() ==2 ) setCurrentMode ( 0 );
 }
 
@@ -479,7 +479,7 @@ SKGError SKGUnitPluginWidget::downloadUnitValue (const SKGUnitObject& iUnit)
     if ( !code.isEmpty() && doc )
     {
         SKGBEGINTRANSACTION ( *doc, i18nc ( "Noun, name of the user action", "Download values for [%1 (%2)]", unitname, code ), err );
-        err=iUnit.downloadUnitValue(mode, skgunit_settings::nb_loaded_values());
+        err=iUnit.downloadUnitValue(mode, skgunit_settings::nb_loaded_values(), skgunit_settings::download_additional_info());
     }
 
     return err;
@@ -625,8 +625,10 @@ void SKGUnitPluginWidget::refreshUnitList()
     ui.kCurrencyList->addItems ( SKGUnitObject::getListofKnownCurrencies(ui.kObsolete->isChecked()) );
 }
 
-QWidget* SKGUnitPluginWidget::zoomableWidget() const
+QWidget* SKGUnitPluginWidget::mainWidget() const
 {
+    if ( ui.kUnitValueTableViewEdition->hasFocus() )
+        return ui.kUnitValueTableViewEdition;
     return ui.kUnitTableViewEdition;
 }
 
