@@ -103,11 +103,10 @@ public:
     virtual void activateEditor();
 
     /**
-     * Get the zoomable widget. MUST BE OVERWRITTEN
-     * By Overwritting this function, you don't have to implement following ones.
-     * @return the tree view.
+     * Get the main widget
+     * @return a widget
      */
-    virtual QWidget* zoomableWidget() const;
+    virtual QWidget* mainWidget() const;
 
 protected:
     /**
@@ -118,7 +117,7 @@ protected:
      */
     virtual bool eventFilter ( QObject *object, QEvent *event );
 
-private slots:
+private Q_SLOTS:
     void dataModified ( const QString& iTableName, int iIdTransaction );
     void onSelectionChanged();
     void onSelectionValueChanged();
