@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -51,10 +51,11 @@ public:
 
         /**
          * Called to initialise the plugin
-         * @param iDocument the SKGDocumentBank main document
+         * @param iDocument the main document
          * @param iArgument the arguments
+         * @return true if the plugin is compatible with the document
          */
-        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);
+        virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -82,7 +83,7 @@ public:
          * The context widget of the plugin.
          * @return The context widget of the plugin
          */
-        virtual SKGTabWidget* getWidget();
+        virtual SKGTabPage* getWidget();
 
         /**
          * This function is called when preferences have been modified. Must be used to save some parameters into the document.
@@ -104,12 +105,6 @@ public:
          */
         virtual QString icon() const;
 
-        /**
-         * The statusTip of the plugin.
-         * @return The toolTip of the plugin
-         */
-        virtual QString statusTip () const;
-
         /**
          * The toolTip of the plugin.
          * @return The toolTip of the plugin
@@ -134,13 +129,13 @@ public:
          */
         virtual bool isInContext() const;
 
-private slots:
+private Q_SLOTS:
 
 private:
         Q_DISABLE_COPY(SKGXXXPlugin);
 
 
-        SKGDocument* currentBankDocument;
+        SKGDocument* currentDocument;
 
         Ui::skgxxxplugin_pref ui;
 };
