@@ -5,7 +5,7 @@ def main():
     initAllPlugins()
 
     waitForObject(":all_plugins.skg - skrooge_KTabBar")
-    type(":all_plugins.skg - skrooge_KTabBar", "<Ctrl+9>")
+    type(":all_plugins.skg - skrooge_KTabBar", "<Ctrl+Alt+0>")
     waitForObject(":Skrooge monthly plugin.kRefresh_QToolButton")
     clickButton(":Skrooge monthly plugin.kRefresh_QToolButton")
     
